SECTION "BANK00", HOME

;*****************************************
;* IRQ_0
;*****************************************
SECTION "IRQ_0", HOME[$0000]
	pop HL
Addr_000001:
	rst $20
	ld H,D
	ld L,E
	jp [HL]

;*****************************************
;* IRQ_8
;* HL=DE
;*****************************************
SECTION "IRQ_8", HOME[$0008]
	pop HL
	push DE
	jp Addr_000001

;*****************************************
;* IRQ_10
;* HL+=A
;*****************************************
SECTION "IRQ_10", HOME[$0010]
	add A,L
	ld L,A
	ret NC
	inc H
	ret

;*****************************************
;* IRQ_18
;* HL+=A
;* A = [HL]
;*****************************************
SECTION "IRQ_18", HOME[$0018]
	add A,L                     ; A=A+L
	ld L,A                      ; L=A
	jr NC,Addr_00001D           ; IF(A!=0) Addr_00001D
	inc H                       ; H++
Addr_00001D:
	ld A,[HL]                   ; A = [HL]
	ret                         ;

;*****************************************
;* IRQ_20
;*****************************************
SECTION "IRQ_20", HOME[$0020]
	add A,A
	rst $10
	ld E,[HL]
	inc HL
	ld D,[HL]
	ret

;*****************************************
;* IRQ_28
;*****************************************
SECTION "IRQ_28", HOME[$0028]
	add A,E
	ld E,A
	ret NC
	inc D
	ret

;*****************************************
;* IRQ_40
;*****************************************
SECTION "VBLANK", HOME[$0040]           ;    .
	jp VBLANK_00018A

;*****************************************
;* IRQ_48
;*****************************************
SECTION "LCDC", HOME[$0048]	            ;  .
	jp LCDC_000246

;*****************************************
SECTION "TIMER_OVERFLOW", HOME[$0050]   ;   .
	reti                                ;*;
;*****************************************
SECTION "SERIAL", HOME[$0058]           ;   .
	reti                                ;*;
;*****************************************
SECTION "P1THRU4", HOME[$0060]          ;  .
	reti                                ;*;
;*****************************************

;*****************************************
;*        HEADER: DO NOT CHANGE          *
;*****************************************

SECTION "START",HOME[$0100]

START:
    nop
    jp MAIN

;NINTENDO SCROLLING TITLE GRAPHIC
DB $CE,$ED,$66,$66,$CC,$0D,$00,$0B,$03,$73,$00,$83,$00,$0C,$00,$0D
DB $00,$08,$11,$1F,$88,$89,$00,$0E,$DC,$CC,$6E,$E6,$DD,$DD,$D9,$99
DB $BB,$BB,$67,$63,$6E,$0E,$EC,$CC,$DD,$DC,$99,$9F,$BB,$B9,$33,$3E

DB "DUCK TALES 2",0,0,0 ; FILLED IN BY RGBFIX
DB $C0;$00                  ; $143 COLOR 80 OR CO
DB 0,0                  ; $144 - Licensee code (not important)
DB $00                  ; $146 - SGB Support indicator / 00 = GameBoy, 03 = Super GameBoy functions 
DB $19                  ; $147 - Cart type / MBC5;1      ; 1 - ROM+MBC1
DB $03                  ; $148 - ROM Size / 256KByte (16 banks);2      ; 2 -   1MBIT = 128KB =  8 BANKS
DB 0                    ; $149 - RAM Size / 0 - RAM SIZE NONE
DB 1,$33                ; $14a - MANUFACTURER CODE (WORD):
DB 0                    ; $14c - VERSION NUMBER (BYTE):
DB $0A                  ; $14d - COMPLEMENT CHECK
DW 0                    ; $14e - Checksum (not important)


;*****************************************
;* MAIN                                  *
;*****************************************
SECTION "MAIN", HOME[$0150]

MAIN:: ;0X000150
	di                              ;  
    
    ld SP,$DFFF                     ;     
    
	call F_Addr_000311
    
    call SetSpeedCPU_2x
    
	call SETPRGDMA
    
	ld HL,$C000
	ld BC,$1FF0
	call CLEARMEM                   ;  
    
    
    ld SP,MEM_STACK                     ;     
    
    
    
	ld HL,$FF8A
	ld BC,$0075
	call CLEARMEM                   ;  _HRAM

	ld A,$00
	call CLEARSCREEN                ;  
    
	call INITSOUND                  ;   

	xor A
	ld [STATEGAME],A
    ld [MEM_VBK_BANK],A
    
    ld A,$FF    
    ld [FADE_FLAG],A
    
	ldh [R_IF],A
	ld A,$01
	ldh [R_IE],A
	ldh [SYSTEM_R_IE],A
	ei                              ;  
    
    
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    call SetWhitePalette
    
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    
	jp Addr_0008F7



;*****************************************
;* VBLANK
;*****************************************
VBLANK_00018A:
	push AF                               
	push BC                               
	push DE                               
	push HL                               
    ld HL,$C0A3                           
	ld A,[HL]                             
	and A                                 
	jp NZ,Addr_000241 ;05:0241            
	inc [HL]                              
	ei                                    
	ldh A,[R_LCDC]                        
	bit 7, A                              
	jr Z,Addr_0001D7                      

	call $FF80 ;                    

	call F_Addr_00050A ;05:050A           
	;ldh A,[R_LCDC]                        
	;ldh [R_LCDC],A                        
	ld A,[STATEGAME] ;05:C0A0                 
	cp $03                                
	jr NZ,Addr_0001B5                     
	ldh A,[R_LCDC]                        
	or $08                                
	ldh [R_LCDC],A                        
Addr_0001B5:
	ld C,$00                              
	call F_Addr_000382 ;05:0382           
	ld HL,$FFB0                           
	ld A,[HL+]                            
	and A                                 
	jr Z,Addr_0001D7                      
	ld [HL],A                             
	xor A                                 
	ldh [$FFB2],A  
    
	ld A,[MEM_CA50]                 
	ldh [R_LYC],A
	ld A,$40                              
	ldh [R_STAT],A    
    
	xor A                                 
	ldh [$FF0F],A                         
	ldh A,[R_IE]                          
	or $02                                
	ldh [R_IE],A  
    
Addr_0001D7:
	ld A,BANK_03                              
	ld [$2000],A ;05:2000                 
	call Addr_00C055 ;F_Addr_00C003 ;03:4003           
	ldh A,[MEM_CURRENT_BANK]              
	ld [$2000],A ;03:2000                 
	ld A,[MEM_SND_DF2E] ;05:DF2E                 
	cp $FF                                
	jr NZ,Addr_0001EF                     
	xor A                                 
	ld [MEM_SND_DF2E],A ;05:DF2E                 
Addr_0001EF:
	ld HL,$C9CD                           
	ld A,[$C9CE] ;05:C9CE                 
	and A                                 
	jr Z,Addr_000202                      
Addr_0001F8:
	ld A,[HL]                             
	sub $01                               
	ld [HL+],A                            
	ld A,[HL]                             
	sbc A,$00                             
	ld [HL],A                             
	jr Addr_000231                        
Addr_000202:
	ld A,[HL]                             
	and A                                 
	jr Z,Addr_000231                      
	cp $01                                
	jr NZ,Addr_0001F8                     
	dec [HL]                              
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	add A,$03                             
	call F_Addr_0002E7 ;01:02E7             
	ld A,[$C9C9] ;01:C9C9                 
	and A                                 
	jr NZ,Addr_000222                     
	xor A                                 
	ld [$C9CA],A ;01:C9CA                 
	ld [$C9CC],A ;01:C9CC                 
	jr Addr_000231                        
Addr_000222:
	xor A                                 
	ld [$C9C9],A ;01:C9C9                 
	ld [$C805],A ;01:C805                 
	ld A,[$C700] ;01:C700                 
	res 7, A                              
	ld [$C700],A ;01:C700                 
Addr_000231:
	ld HL,$C0A4                           
	inc [HL]                              
	jr NZ,Addr_000239                     
	inc HL                                
	inc [HL]                              
Addr_000239:
	ld HL,$C0A6                           
	inc [HL]                              
	xor A                                 
	ld [$C0A3],A ;05:C0A3                 
Addr_000241:
	pop HL                                
	pop DE                                
	pop BC                                
	pop AF                                
	reti                                  

;*****************************************
;* LCDC
;*****************************************
LCDC_000246:
	push AF                               
	push BC                               
	push DE                               
	push HL                               
	ld HL,$FF41                           
	bit 2, [HL]                           
	jr Z,Addr_000298                      
	xor A                                 
	ldh [$FF0F],A                     
	ldh A,[R_IE]                     
	and $FD                               
	ldh [R_IE],A                     
	ld A,[STATEGAME] ;03:C0A0                 
	cp $03                                
	jr Z,Addr_000284                      
	res 2, [HL]                           
	ld HL,$FFB2                           
	inc [HL]                              
	ld C,[HL]                             
	call F_Addr_000382 ;03:0382             
	ld HL,$FFB1                           
	dec [HL]                              
	jr Z,Addr_00027D                      
	ld HL,MEM_CA50                            
	ldh A,[$FFB2]                            
	add A,L                            
	ld L,A                            
	ld A,[HL]                            
	ldh [R_LYC],A                            
	jr Addr_00028F 
    
Addr_00027D:
	ld HL,$FF41                           
	res 6, [HL]                           
	jr Addr_00028F  
    
Addr_000284:
	ld C,$01                              
	call F_Addr_000382 ;01:0382             
	ldh A,[R_LCDC]                     
	and $F7                               
	ldh [R_LCDC],A                     
Addr_00028F:
	xor A                                 
	ldh [$FF0F],A                     
	ldh A,[R_IE]                     
	or $02                                
	ldh [R_IE],A                     
Addr_000298:
	pop HL                                
	pop DE                                
	pop BC                                
	pop AF                                
	reti                                  

;*****************************************
;* 
;*****************************************
SetSpeedCPU_2x:
	ldh	A,[R_KEY1]
	rlca
	ret	C			;mode was already 2x.
SetSpeed:
	di
	ldh	A,[R_IE]
	push AF
	xor	A
	ldh	[R_IE],A
	ldh	[R_IF],A
	ld	A,$30
	ldh	[R_P1],A
	ld	A, %00000001
	ldh	[R_KEY1],A
	stop
	nop
	pop	AF
	ldh	[R_IE],A
	ei
	ret

;*****************************************
;* INIT SOUND ENGINE
;*****************************************
INITSOUND:
	ld A,BANK_03                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;01:2000                 
	jp F_Addr_00C006 ;Addr_00C000 ;03:4000               

;*****************************************
;* 
;*****************************************
Data_0_02A7:
	DB $60     ;00
	DB $50     ;01
	DB $50     ;02
	DB $80     ;03
	DB $50     ;04
	DB $C0     ;05
	DB $D0     ;06
	DB $60     ;07
    DB $F0     ;08
    DB $E0     ;09
    DB $60     ;0A
    DB $00     ;0B
    DB $D0     ;0C
    DB $F0     ;0D
    DB $F0     ;0E
    DB $30     ;0F
    DB $F0     ;10
    DB $80     ;11
    DB $10     ;12
    DB $10     ;13
    DB $10     ;14
    DB $10     ;15
    DB $10     ;16
    DB $F0     ;17
    DB $00     ;18
    DB $10     ;19
    DB $10     ;1A
    DB $10     ;1B
    DB $A0     ;1C
    DB $10     ;1D
    DB $10     ;1E
    DB $10     ;1F
    DB $10     ;20
    DB $A0     ;21
    DB $F0     ;22
    DB $10     ;23
    DB $10     ;24
    DB $A0     ;25
    DB $10     ;26
    DB $30     ;27
    DB $A0     ;28
    DB $A0     ;29
    DB $A0     ;2A
    DB $A0     ;2B
    DB $30     ;2C
    DB $A0     ;2D
    DB $30     ;2E
    DB $A0     ;2F
    DB $10     ;30
    DB $10     ;31
    DB $F0     ;32
    DB $20     ;33
    DB $20     ;34
    DB $E0     ;35
    DB $10     ;36
    DB $10     ;37
    DB $10     ;38
    DB $30     ;39
    DB $20     ;3A
    DB $30     ;3B
    DB $E0     ;3C
    DB $20     ;3D
    DB $30     ;3E
    DB $30     ;3F
    
;*****************************************
;* PLAY SOUND
;* A <- SOUND
;*****************************************
F_Addr_0002E7: 
    push BC                               
	push DE                               
	push HL                               
	ld B,A                                
	ld C,$FF                              
	cp $80                                
	jr NC,Addr_00030D                     
	cp $7A                                
	jr NC,Addr_000306                     
	cp $20                                
	jr C,Addr_000306                      
	sub $20                               
	ld HL,Data_0_02A7                           
	rst $18                               
	ld HL,MEM_SND_DF2E                           
	cp [HL]                               
	jr C,Addr_00030D                      
	ld C,A                                
Addr_000306:
	ld A,C                                
	ld [MEM_SND_DF2E],A ;05:DF2E                 
	ld A,B                                
	ldh [$FF8F],A                     
Addr_00030D:
	pop HL                                
	pop DE                                
	pop BC                                
	ret                                   

;*****************************************
;* 
;*****************************************
F_Addr_000311:
	ldh A,[R_LCDC]                  
	bit 7, A                              
	ret Z                                 
	call F_Addr_000332                      
	ldh A,[R_LCDC]                  
	and $7F                               
	ldh [R_LCDC],A                  
	ldh A,[SYSTEM_R_IE]                     
	ldh [R_IE],A                     
	ret                                   

;*****************************************
;* 
;*****************************************
F_Addr_000324:
	ldh A,[R_LCDC]                     
	or $80             ;           
	ldh [R_LCDC],A                     
	call F_Addr_000332 ;04:0332             
	ldh A,[SYSTEM_R_IE]                     
	ldh [R_IE],A                     
	ret                                   

;*****************************************
;* 
;*****************************************
F_Addr_000332:
	ldh A,[R_IE]                     
	ldh [SYSTEM_R_IE],A                     
	res 0, A                              
	ldh [R_IE],A                     
.LOOP_00033A
	ldh A,[R_LY]                     
	cp $91                                
	jr C,.LOOP_00033A                      
	ret                                   

;*****************************************
;* 
;*****************************************
F_Addr_000341:
	call F_Addr_000332 ;01:0332             
	ldh A,[R_LCDC]                     
	and $FC                               
	ldh [R_LCDC],A                     
	ldh A,[SYSTEM_R_IE]                     
	ldh [R_IE],A                     
	ret                                   

;*****************************************
;* 
;*****************************************
F_Addr_00034F:
	call F_Addr_000332 ;05:0332             
	ldh A,[R_LCDC]                     
	or $03           ;                       
	ldh [R_LCDC],A                     
	ldh A,[SYSTEM_R_IE]                     
	ldh [R_IE],A                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_00035D:
	ldh A,[R_LCDC]                             
	and $DF                              
	ldh [R_LCDC],A                             
	ret                            
    
;*****************************************
;* 
;*****************************************
Addr_000364:
	ldh A,[R_LCDC]                              
	and $9F                              
	or C                              
	ldh [R_LCDC],A                               
	ret                              

;*****************************************
;* c < 
;*****************************************
F_Delay_00036C:
    ;DB $76 ;HALT ??????????????????????????????? 
    HALT 
    NOP
    
	ld A,[$C0A6] ;05:C0A6                 
	cp C                                  
	jr C,F_Delay_00036C                      
	xor A                                 
	ld [$C0A6],A ;05:C0A6                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_000382:
	ld HL,MEM_CA51                           
	ld A,C                                
	rst $18                               
	ldh [R_SCX],A                         
	ld HL,MEM_WINDOW_X                    
	ld A,C                                
	rst $18                               
	ldh [R_SCY],A                         
	ret                                   
    
;*****************************************
;* JOYPAD
;*****************************************
JOYPAD_000391:
	ld A,$20                              
	ldh [R_P1],A                     
	ldh A,[R_P1]                     
	ldh A,[R_P1]                     
	cpl                                   
	and $0F                               
	swap A                                
	ld B,A                                
	ld A,$10                              
	ldh [R_P1],A                     
	ldh A,[R_P1]                     
	ldh A,[R_P1]                     
	ldh A,[R_P1]                     
	ldh A,[R_P1]                     
	ldh A,[R_P1]                     
	ldh A,[R_P1]                     
	ldh A,[R_P1]                     
	ldh A,[R_P1]                     
	cpl                                   
	and $0F                               
	or B                                  
	ld C,A                                
	ldh A,[$FF92]                     
	xor C                                 
	and C                                 
	ldh [$FF93],A                     
	ld A,C                                
	ldh [$FF92],A                     
	ld A,$30                              
	ldh [R_P1],A                     
	ret                                   

;************************************************
;*    
;*  
;************************************************
SETPRGDMA:
	ld C,$80                              ; $FF80
	ld B, $0A                             ;
	ld HL,Data_0003D4                     ;
Addr_0003CD:
	ld A,[HL+]                            ;
	ld [$FF00+C],A                        ;
	inc C                                 ;
	dec B                                 ;
	jr NZ,Addr_0003CD                     ;
	ret                                   ;

Data_0003D4:
	DB $3E                                ;     ld A,$C0
	DB $C0                                ;
	DB $E0                                ;     ldh [R_DMA],A
	DB $46                                ;
	DB $3E                                ;     ld A,$28
	DB $28                                ; .LOOP
	DB $3D                                ;     dec A
	DB $20                                ;     jr NZ, .LOOP
	DB $FD                                ;
	DB $C9                                ;     ret

	DB $86                              ;*; 
	DB $22                              ;*;
	DB $D0                              ;*; 
	DB $34                              ;*; 
	DB $C9                              ;*; 

;************************************************
;*
;************************************************
;F_Addr_0003E3:
;	ld HL,$C000                           ; 
;	ld BC, $00A0                          ; 
;	jp CLEARMEM                           ; 
    
    
;*****************************************
;* 
;*****************************************
Addr_000416:                            ;*;
	push DE                             ;*; 
	ldh A,[$FF96]                       ;*;
    and $03                             ;*;
    ld D,A                              ;*;
    ldh A,[$FF97]                       ;*;
    and $E0                             ;*;
	ld E,A                              ;*;
	SRL D                               ;*;
	RR E                                ;*;
	SRL D                               ;*;
	RR E                                ;*;
	ld A,E                              ;*;
	ldh [$FF95],A                       ;*;
	ldh A,[$FF97]                       ;*;
	and $1F                             ;*;
	rla                                 ;*;
	rla                                 ;*;
	rla                                 ;*;
	ldh [$FF94],A                       ;*;
	pop DE                              ;*;
	ret                                 ;*;


;*****************************************
;* FUNCTION CLEARMEM
;* HL - ADDRESS
;* BC - SIZE
;*****************************************
CLEARMEM:                                 ; 
	xor A
	ld [HL+],A
	dec BC
	ld A,C
	or B
	jr NZ,CLEARMEM
	ret
    
;*****************************************
;* FUNCTION SETMEM
;* HL - ADDRESS
;* BC - SIZE
;*  A - CHAR
;*****************************************
SETMEM:                                 ; 
	ld [HL+],A
	dec BC
	ld A,C
	or B
	jr NZ,CLEARMEM
	ret

;*****************************************
;* FUNCTION COPYMEM
;* HL - SRC
;* DE - DEST
;* BC - SIZE
;*****************************************
COPYMEM:                                  ; 0X00043F 00:043F 2A 12 13
	ld A,[HL+]
	ld [DE],A
	inc DE
	dec BC
	ld A,B
	or C
	jr NZ,COPYMEM
	ret

;*****************************************
;* FUNCTION CLEARSCREEN
;* A - CHAR
;*****************************************
CLEARSCREEN:                            ; 0X000448 00:0448 57 21 00
	ld D,A
	ld HL,SCRN9800
	ld BC, $0800
; LOOP_00044F:
	; ld A,D
	; ld [HL+],A
	; dec BC
	; ld A,C
	; or B
	; jr NZ,LOOP_00044F
	; ret
    
	inc	B
	inc	C
	jr .skip
.loop   
    di
    WaitForVRAM
    ld A,$00                                
	ldh [R_VBK],A 
    ld A,D
    ld [HL],A
    
    WaitForVRAM
    ld A,$01                                
	ldh [R_VBK],A 
    ld A,D
    ld [HL+],A
    
    ei
.skip
    dec	C
	jr NZ,.loop
	dec	B
	jr NZ,.loop
	ret
    
    

;*****************************************
;* 
;*****************************************
F_Addr_000457:                         ;*;
	ld A,[HL+]                         ;*; 0X000457 00:0457 2A A7 C8;
	and A                              ;*; 0X000458 00:0458 A7 C8 E0;
	ret Z                              ;*; 0X000459 00:0459 C8 E0 96;
	ldh [$FF96],A                      ;*; 0X00045A 00:045A E0 96 2A;
	ld A,[HL+]                         ;*; 0X00045C 00:045C 2A E0 97;
	ldh [$FF97],A                      ;*; 0X00045D 00:045D E0 97 2A;
	ld A,[HL+]                         ;*; 0X00045F 00:045F 2A 47 CD;
	ld B,A                             ;*; 0X000460 00:0460 47 CD 66;
	call F_Addr_000466                 ;*; 0X000461 00:0461 CD 66 04;
	jr F_Addr_000457                   ;*; 0X000464 00:0464 18 F1 F0;


  

;*****************************************
;* 	BC < $9F80                          
;* 	HL < Data_0_0E4C  
;*****************************************
F_Addr_0004D0:
	ld A,B                                ; 
	ldh [$FF96],A                         ; 
	ld A,C                                ; 
	ldh [$FF97],A                         ; 
;*****************************************
;* 
;*****************************************
F_Addr_0004D6:
	ld A,[HL+]                            ; 
	ld B,A                                ;B < WIDTH 
	ld A,[HL+]                            ; 
	ld C,A                                ;C < HEIGHT 
;*****************************************
;* 
;*****************************************
F_Addr_0004DA:
	push BC                               ; 0X0004DA 00:04DA C5 CD 66
	call F_Addr_000466 ;05:0466           ; 0X0004DB 00:04DB CD 66 04
	ld A,[$FF97]                        ; 0X0004E0 00:04E0 F2 C6 20
	add A,$20                             ; 0X0004E1 00:04E1 C6 20 E2
	ld [$FF97],A                        ; 0X0004E3 00:04E3 E2 30 06
	jr NC,.L_0004EC                       ; 0X0004E4 00:04E4 30 06 0D
	ld A,[$FF96]                        ; 0X0004E7 00:04E7 F2 3C E6
	inc A                                 ; 0X0004E8 00:04E8 3C E6 9F
	and $9F                               ; 0X0004E9 00:04E9 E6 9F E2
	ld [$FF96],A                        ; 0X0004EB 00:04EB E2 C1 CB
.L_0004EC:
	pop BC                                ; 0X0004EC 00:04EC C1 CB 79
	bit 7, C                              ; 0X0004ED 00:04ED CB 79 28
	jr Z,.L_000503                        ; 0X0004EF 00:04EF 28 12 CB
	bit 7, B                              ; 0X0004F1 00:04F1 CB 78 28
	jr Z,.L_0004F8                        ; 0X0004F3 00:04F3 28 03 2B
	dec HL                                ; 0X0004F5 00:04F5 2B 18 0B
	jr .L_000503                          ; 0X0004F6 00:04F6 18 0B 78
.L_0004F8:
	ld A,B                                ; 0X0004F8 00:04F8 78 E6 7F
	and $7F                               ; 0X0004F9 00:04F9 E6 7F 5F
	ld E,A                                ; 0X0004FB 00:04FB 5F 7D 93
	ld A,L                                ; 0X0004FC 00:04FC 7D 93 6F
	sub E                                 ; 0X0004FD 00:04FD 93 6F 7C
	ld L,A                                ; 0X0004FE 00:04FE 6F 7C DE
	ld A,H                                ; 0X0004FF 00:04FF 7C DE 00
	sbc A,$00                             ; 0X000500 00:0500 DE 00 67
	ld H,A                                ; 0X000502 00:0502 67 0D 79
.L_000503:
	dec C                                 ; 0X000503 00:0503 0D 79 E6
	ld A,C                                ; 0X000504 00:0504 79 E6 7F
	and $7F                               ; 0X000505 00:0505 E6 7F 20
	jr NZ,F_Addr_0004DA                   ; 0X000507 00:0507 20 D1 C9
	ret                                   ; 0X000509 00:0509 C9 FA 00


;*****************************************
;* 
;*****************************************
F_Addr_00050A:
    ld A,[$C500] ;05:C500                 ; 
	and A                                 ; 
	ret NZ                                ;   A   
	ld HL,$C502                           ; HL=$C502
.L_000512:
	ld A,[HL+]                            ; A=[HL+]
	and A                                 ; 
	jr NZ,.L_000522                       ;  A   
    ld [$C501],A ;05:C501                 ; [$C501]=0
	ld [$C502],A ;05:C502                 ; [$C502]=0
	ld A,$01                              ; 
	ld [$C500],A ;05:C500                 ; [$C500]=$01
	ret                                   ; 
    
.L_000522:
	ld D,A                                ; D=A
	ld A,[HL+]                            ; 
	ld E,A                                ; E=[HL+]
	ld A,[HL+]                            ; 
	ld B,A                                ; B=[HL+]
.L_000527:
	ld A,[HL+]                            ; 
	ld [DE],A                             ; [DE]=[HL+]
	inc DE                                ; DE++
	dec B                                 ; B--
	jr NZ,.L_000527                       ;  B   
    jr .L_000512                          ; 
  
;*****************************************
;* draw rect????
;*****************************************
F_Addr_00052F:
	ld A,D                                
	ldh [$FF96],A                     
	ld A,E                                
	ldh [$FF97],A                     
;*****************************************
F_Addr_000535:
	push BC                               
	call F_Addr_00055F ;01:055F             
	ld C,$01                              
	push HL                               
	ld HL,$C5AB                           
	call F_Addr_0004DA ;01:04DA             
	pop HL                                
	pop BC                                
	push BC                               
	call F_Addr_00055F ;01:055F             
	dec C                                 
	dec C                                 
	set 7, C                              
	push HL                               
	ld HL,$C5AB                           
	call F_Addr_0004DA ;01:04DA             
	pop HL                                
	pop BC                                
	call F_Addr_00055F ;01:055F             
	ld HL,$C5AB                           
	call F_Addr_000466 ;01:0466             
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_00055F:
	push BC                               
	ld DE,$C5AB                           
	ld A,[HL+]                            
	ld [DE],A                             
	inc DE                                
	ld C,B                                
	dec C                                 
	dec C                                 
	ld A,[HL+]                            
.L_00056A:
	ld [DE],A                             
	inc DE                                
	dec C                                 
	jr NZ,.L_00056A                     
	ld A,[HL+]                            
	ld [DE],A                             
	pop BC                                
	ret                                   
    

    
    
    
    
    
    
    
;*****************************************
;* 
;*****************************************
F_Addr_000650:
	ld DE,$FF9A                           
	ld A,[DE]                             
	cp B                                  
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_000697:
	and A                                 
	ld B, $04                             
.L_00069A:
	ld A,[DE]                             
	adc A,[HL]                            
	DAA                                   
	ld [DE],A                             
	dec DE                                
	dec HL                                
	dec B                                 
	jr NZ,.L_00069A                     
	jr NC,.L_0006B0                     
	inc DE                              
	ld B, $04                           
	ld A,$99                            
.L_0006AA:
	ld [DE],A                           
	inc DE                              
	dec B                               
	jr NZ,.L_0006AA                   
	scf                                 
.L_0006B0:
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_0006B1:
	and A                                 
	ld B, $04                             
.L_0006B4:
	ld A,[DE]                             
	sbc A,[HL]                            
	DAA                                   
	ld [DE],A                             
	dec DE                                
	dec HL                                
	dec B                                 
	jr NZ,.L_0006B4                     
	jr NC,.L_0006C9                     
	inc DE                              
	ld B, $04                           
	xor A                               
.L_0006C3:
	ld [DE],A                           
	inc DE                              
	dec B                               
	jr NZ,.L_0006C3                   
	scf                                 
.L_0006C9:
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_0006CA:
	ld A,B                                
	and $0F                               
	ld C,A                                
	ret Z                                 
	ld HL,$C5AB                           
.L_0006D2:
	push HL                               
	ld HL,Data_000716                           
	ld A,[DE]                             
	swap A                                
	and $0F                               
	jr NZ,.L_0006E5                     
	bit 7, B                              
	jr Z,.L_0006E7                      
	ld A,$10                              
	jr .L_0006E7                        
.L_0006E5:
	res 7, B                              
.L_0006E7:
	rst $18                               
	pop HL                                
	ld [HL+],A                            
	dec C                                 
	jr Z,.L_00070C                      
	push HL                               
	ld HL,Data_000716                           
	ld A,[DE]                             
	and $0F                               
	jr NZ,.L_000703                     
	ld A,C                                
	dec A                                 
	jr Z,.L_000705                      
	xor A                                 
	bit 7, B                              
	jr Z,.L_000705                      
	ld A,$10                              
	jr .L_000705                        
.L_000703:
	res 7, B                              
.L_000705:
	rst $18                               
	pop HL                                
	ld [HL+],A                            
	inc DE                                
	dec C                                 
	jr NZ,.L_0006D2                     
.L_00070C:
	ld A,B                                
	and $0F                               
	ld B,A                                
	ld HL,$C5AB                           
	jp F_Addr_000466 ;05:0466               
    
;*****************************************
;* 
;*****************************************
Data_000716:
	DB $F0 ;0
    DB $F1 ;1
    DB $F2 ;2
    DB $F3 ;3
    DB $F4 ;4
    DB $F5 ;5
    DB $F6 ;6
    DB $F7 ;7
    DB $F8 ;8
    DB $F9 ;9
    
	DB $01 ;a                             ;*; 0X000720 00:0720 01 02 03; ld BC, $0302
	DB $02 ;b                             ;*; 0X000721 00:0721 02 03 04; ld [BC],A
	DB $03 ;c                             ;*; 0X000722 00:0722 03 04 05; inc BC
	DB $04 ;d                             ;*; 0X000723 00:0723 04 05 06; inc B
	DB $05 ;e                             ;*; 0X000724 00:0724 05 06 00; dec B
	DB $06 ;f                             ;*; 0X000725 00:0725 06 00 47; ld B, $00
	
    DB $00 ;                        ; 0X000726 00:0726 00 47 7A; nop
	
    DB $47                              ;*; 0X000727 00:0727 47 7A E0; ld B,A
	DB $7A                              ;*; 0X000728 00:0728 7A E0 96; ld A,D
	DB $E0                              ;*; 0X000729 00:0729 E0 96 7B; ldh [$FF96],A
	DB $96                              ;*; 0X00072A 00:072A 96 7B E0; sub [HL]
	DB $7B                              ;*; 0X00072B 00:072B 7B E0 97; ld A,E
	DB $E0                              ;*; 0X00072C 00:072C E0 97 78; ldh [$FF97],A
	DB $97                              ;*; 0X00072D 00:072D 97 78 21; sub A
	DB $78                              ;*; 0X00072E 00:072E 78 21 16; ld A,B
    
;*****************************************
;* 
;*****************************************
F_Addr_00072F:
	ld HL,Data_000716                           
	and $0F                               
	rst $18                               
	ld [$C5AB],A ;01:C5AB                 
	ld B, $01                             
	ld HL,$C5AB                           
	jp F_Addr_000466 ;01:0466               
    
;*****************************************
;* 
;*****************************************
Addr_000740: ;*;
	ld B,A                             
	ld A,D                             
	ldh [$FF96],A                             
	ld A,E                             
	ldh [$FF97],A                              
;*****************************************
F_Addr_000747:
	push DE                              
	ld HL,Data_000716                             
	ld A,B                             
	swap A                             
	and $0F                             
	rst $18                              
	ld [$C5AB],A ;00:C5AB                              
	ld HL,Data_000716                              
	ld A,B                             
	and $0F                              
	rst $18                              
	ld [$C5AC],A ;00:C5AC                              
	ld B, $02                             
	ld HL,$C5AB                               
	call F_Addr_000466 ;00:0466                             
	pop DE                              
	inc DE                              
	inc DE                             
	ret                             
    
;*****************************************
;* 
;*****************************************
Addr_00076A:
	xor A                                 
	ld [$C5CB],A ;05:C5CB                 
	ld [$C5CD],A ;05:C5CD                 
	ld [$C5CC],A ;05:C5CC                 
	ld [$C5CE],A ;05:C5CE                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_000778:
	ld A,$2C                              
	call F_Addr_0002E7 ;05:02E7             
	scf                                   
	ret
    
;*****************************************
;* 
;*****************************************
Addr_00077F:
	and A                                 
	ret                                   

;*****************************************
;* 
;*****************************************
F_Addr_000781: ;*;
	ld HL,$C5CB                              
	ld A,[HL+]                              
	ld [HL-],A                              
	ld C,$93                             
	ld A,[$FF00+C]                              
	and $20                              
	jr Z,.L_000795                               
	ld A,[HL]                              
	and A                              
	jr NZ,.L_000792                               
	ld [HL],B                              
.L_000792:
	dec [HL]                              
	jr Addr_000778                                
.L_000795:
	ld A,[$FF00+C]                              
	and $10                             
	jr Z,Addr_00077F                               
	inc [HL]                              
	ld A,[HL]                              
	cp B                              
	jr C,Addr_000778                               
	xor A                             
	ld [HL],A                              
	jr Addr_000778                              
    
;*****************************************
;* 
;*****************************************
F_Addr_0007A3:
	ld HL,$C5CD                           
	ld A,[HL+]                            
	ld [HL-],A                            
	ld C,$93                              
	ld A,[$FF00+C]                        
	and $40                               
	jr Z,.L_0007B7                      
	ld A,[HL]                           
	and A                               
	jr NZ,.L_0007B4                   
	ld [HL],B                           
.L_0007B4:
	dec [HL]                            
	jr Addr_000778                      
.L_0007B7:
	ld A,[$FF00+C]                        
	and $80                               
	jr Z,Addr_00077F                      
	inc [HL]                              
	ld A,[HL]                             
	cp B                                  
	jr C,Addr_000778                      
	xor A                               
	ld [HL],A                           
	jr Addr_000778                      
    
;*****************************************
;* 
;*****************************************
F_Addr_0007C5:
	ld C,[HL]                             
	inc HL                                
	inc HL                                
	push HL                               
	push BC                               
	push HL                               
	inc HL                                
	inc HL                                
	ld A,[$C5CE] ;05:C5CE                 
	call F_Addr_000802 ;05:0802             
	ld A,[$C5CC] ;05:C5CC                 
	sla A                                 
	rst $10                               
	ld A,[HL+]                            
	ldh [$FF97],A                     
	ld A,[HL]                             
	ldh [$FF96],A                     
	pop HL                                
	ld B, $01                             
	call F_Addr_000466 ;05:0466             
	pop BC                                
	pop HL                                
	inc HL                                
	push HL                               
	inc HL                                
	ld A,[$C5CD] ;05:C5CD                 
	call F_Addr_000802 ;05:0802             
	ld A,[$C5CB] ;05:C5CB                 
	sla A                                 
	rst $10                               
	ld A,[HL+]                            
	ldh [$FF97],A                     
	ld A,[HL]                             
	ldh [$FF96],A                     
	pop HL                                
	ld B, $01                             
	jp F_Addr_000466 ;05:0466               
    
;*****************************************
;* 
;*****************************************
F_Addr_000802:
	and A                                 
	jr Z,.L_00080E                      
	ld B,A                                
	sla C                                 
	xor A                                 
.L_000809:
	add A,C                               
	dec B                                 
	jr NZ,.L_000809                     
	rst $10                               
.L_00080E:
	ret                                   

;*****************************************
;* 
;*****************************************
Addr_00080F: ;*;
	ld C,$01                              
	call F_Delay_00036C ;00:036C                              
	ldh A,[$FF92]                              
	and $03                             
	jr Z,Addr_00080F                             
	ret                             
    
    
;*****************************************
;* 
;*****************************************
F_Addr_000854:
	ld A,[$C5A9] ;05:C5A9                 
	cp $FF                                
	ret Z                                 
	ld HL,$C5A4                           
	ld A,[HL]                             
	cp $FF                                
	jr Z,.L_00086C                      
	dec [HL]                              
	ret NZ                                
	ld A,$2E                              
	call F_Addr_0002E7 ;05:02E7             
	dec HL                                
	ld A,[HL+]                            
	ld [HL],A                             
.L_00086C:
	ld HL,$C5A9                           
	ld A,[HL]                             
	inc [HL]                              
	ld HL,$C5A7                           
	ld E,[HL]                             
	inc HL                                
	ld D,[HL]                             
	ld H,D                                
	ld L,E                                
	rst $18                               
	cp $FE                                
	jr NZ,.L_00088F                     
	ld HL,$C5A5                           
	ld A,[HL]                             
	add A,$20                             
	ld [HL+],A                            
	ld A,[HL]                             
	adc A,$00                             
	ld [HL],A                             
	xor A                                 
	ld [$C5AA],A ;05:C5AA                 
	jr .L_0008B8                        
.L_00088F:
	cp $FF                                
	jr NZ,.L_000899                     
	ld A,$FF                              
	ld [$C5A9],A ;05:C5A9                 
	ret                                   
.L_000899:
	ld HL,$C5AD                           
	ld [HL-],A                            
	ld A,$01                              
	ld [HL-],A                            
	ld [HL],A                             
	ld HL,$C5AA                           
	ld A,[$C5A5] ;05:C5A5                 
	add A,[HL]                            
	ldh [$FF97],A                     
	ld A,[$C5A6] ;05:C5A6                 
	adc A,$00                             
	ldh [$FF96],A                     
	inc [HL]                              
	ld HL,$C5AB                           
	call F_Addr_0004D6 ;05:04D6             
.L_0008B8:
	ld HL,$C5A4                           
	ld A,[HL]                             
	cp $FF                                
	ret NZ                                
	jr F_Addr_000854                      
    
    
;*****************************************
;* 
;*****************************************
Addr_0008EE:
	ld SP,MEM_STACK                           
	call F_Addr_000341 ;01:0341             
	call F_Addr_000311 ;01:0311             
Addr_0008F7:
	ldh A,[R_IE]                     
	and $FD                               
	ldh [R_IE],A                     
	ld A,$01                              
	ld [$C500],A ;01:C500                 
	xor A                                 
	ld HL,$C501                           
	ld [HL+],A                            
	ld [HL+],A                            
	ldh [$FFB0],A                     
	ldh [R_SCX],A                     
	ldh [R_SCY],A                     
	ld A,$FF                              
	ld [$C5A9],A ;01:C5A9                 

	ld HL,$C600                           
	ld BC, $0300                          
	call CLEARMEM ;01:0437             

	ld B, $98                             
	ld HL,$C9B7                           
	call CLEARMEMSMALL ;01:096A  
    
    
	ld B, $FF                             
	ld HL,MEM_CA50                           
	call CLEARMEMSMALL ;01:096A             
	
    ld HL,$C000                           
	ld BC, $00A0                          
	call CLEARMEM                           


	;   4 
	ld A,BANK_04                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;01:2000                 

	call Addr_013A77
    
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ;;TMP;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	; ld B, $98                             
	; ld HL,$DE00                           
	; call CLEARMEMSMALL ;01:096A  
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    ; LD D,0
    ; LD HL,PAL_BG
    ; CALL SetPalettes_Immediate
    ; LD D,1
    ; LD HL,PAL_OBJ
    ; CALL SetPalettes_Immediate
    ;LD A,0;$FF
    ;ld [FADE_FLAG],A

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    
    ld A,[STATEGAME] ;04:C0A0                 
	cp $03                                
	call NZ,F_Addr_000324 ;04:0324          
	ld A,[STATEGAME] ;04:C0A0                 
	and $0F                               
    ;--------	
    rst $00                               
	DW F_StateLicense           ;00 State License                             
	DW F_StateStart             ;01 State Start                             
	DW F_StateMap               ;02 State Map                             
	DW F_StateLevel             ;03 State Level                              
	DW F_StateMap2              ;04 State Map 2                              
	DW F_StateStageClear        ;05 State StageClear                              
	DW F_StateGameOver          ;06 State GameOver                            
	DW F_StateMap3              ;07 State Map 3                             
	DW F_StateIslandLifted      ;08 State Island Lifted                              
	DW F_StateFlightOfZigZag    ;09 State Flight Of ZigZag                              
	DW F_StateEndComics         ;0a State End Comics                              
	DW F_StateFirstComics       ;0b State First Comics                              
	DW $0000;F_StateStartRus           ;0c State Not Uses                    
	DW F_StateNotUses           ;0d State Not Uses                    
	DW F_StateSelectLevel       ;0e State Select Level                    
	DW $0000;F_StateSelectLanguage       ;0f State Select Language                   
;--------	

;*****************************************
;* CLEARMEMSMALL
;* HL - ADDRESS
;* B - SIZE
;*****************************************
CLEARMEMSMALL:
	xor A                                 
.L_00096B:
	ld [HL+],A                            
	dec B                                 
	jr NZ,.L_00096B                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_StateSelectLevel:   ;;;;;;
	ld A,BANK_05                            
	ldh [MEM_CURRENT_BANK],A                             
	ld [$2000],A ;00:2000                             
	ld DE,SCR_STATE_SELECT_LEVEL                             
	jr Addr_000984                             

;*****************************************
;* 
;*****************************************
; F_StateStartRus:   ;;;;;;
	; ld A,BANK_05                            
	; ldh [MEM_CURRENT_BANK],A                             
	; ld [$2000],A ;00:2000                             
	; ld DE,SCR_STATE_START_RUS                             
	; jr Addr_000984                             

;*****************************************
;* 
;*****************************************
; F_StateSelectLanguage:   ;;;;;;
	; ld A,BANK_05                            
	; ldh [MEM_CURRENT_BANK],A                             
	; ld [$2000],A ;00:2000                             
	; ld DE,SCR_STATE_LANGUAGE                             
	; jr Addr_000984                             
    
;*****************************************
;* 
;*****************************************
F_StateNotUses:   ;;;;;;
	ld A,$01                             
	ld [STATEGAME],A ;00:C0A0                             
	jp Addr_0008EE ;00:08EE                             
    
;*****************************************
;* 
;*****************************************
Addr_000984:
	ld B, $01                             
	call F_Addr_00147B ;05:147B             
	xor A                                 
	ld [$C0A6],A ;05:C0A6                 
.L_000992:
	ld C,$01                              
	call F_Delay_00036C ;05:036C             
	call JOYPAD_000391 ;JOYPAD             
	call F_Addr_000854 ;05:0854             
	call F_Addr_0012C1 ;05:12C1             
	jr .L_000992                        
    
;*****************************************
;* 
;*****************************************
F_StateLicense:
	;   5 
	ld A,BANK_05                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;04:2000                 
	ld DE,SCR_STATE_LOGO                           
	jr Addr_000984                        
    
;*****************************************
;* 
;*****************************************
F_StateStart:
	;   5 
	ld A,BANK_05                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;04:2000                 
	ld DE,SCR_STATE_START_ENG                           
	jr Addr_000984                        
    
;*****************************************
;* 
;*****************************************
F_StateMap:
	;   5 
	ld A,BANK_05                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;04:2000                 
	ld DE,SCR_STATE_02_MAP                           
	jr Addr_000984                        
    
;*****************************************
;* 
;*****************************************
F_StateMap2:
	;   5 
	ld A,BANK_05                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;04:2000                 
	ld DE,SCR_STATE_04_MAP                           
	jr Addr_000984                        
    
;*****************************************
;* 
;*****************************************
F_StateStageClear:
	;   5 
	ld A,BANK_05                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;04:2000                 
	ld DE,SCR_STATE_STAGECLEAR                           
	jr Addr_000984                        
    
;*****************************************
;* 
;*****************************************
F_StateGameOver:
	;   5 
	ld A,BANK_05                            
	ldh [MEM_CURRENT_BANK],A                   
	ld [$2000],A ;00:2000               
	ld DE,SCR_STATE_GAMEOVER                         
	jr Addr_000984                      
    
;*****************************************
;* 
;*****************************************
F_StateMap3:
	;   5 
	ld A,BANK_05                             
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;04:2000                 
	ld DE,SCR_STATE_07_MAP                           
	jr Addr_000984                        
    
;*****************************************
;* 
;*****************************************
F_StateIslandLifted:
	;   5 
	ld A,BANK_05                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;04:2000                 
	ld DE,SCR_STATE_ISLAND_LIFTED                           
	jr Addr_000984                        
    
;*****************************************
;* 
;*****************************************
F_StateFlightOfZigZag:
	;   5 
	ld A,BANK_05                             
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;04:2000                 
	ld DE,SCR_STATE_FLIGHT_ZIGZAG                           
	jp Addr_000984 ;05:0984               
    
;*****************************************
;* 
;*****************************************
F_StateEndComics:
	;   5 
	ld A,BANK_05                             
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;04:2000                 
	ld DE,SCR_STATE_END_COMICS                           
	jp Addr_000984 ;05:0984               
    
;*****************************************
;* 
;*****************************************
F_StateFirstComics:
	;   5 
	ld A,BANK_05                             
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;04:2000                 
	ld DE,SCR_STATE_FIRST_COMICS                           
	jp Addr_000984 ;05:0984               
    
;*****************************************
;* 
;*****************************************
F_StateLevel:
    ld B, $FF                             
	ld HL,MEM_C200                           
	call CLEARMEMSMALL ;04:096A             
	ld B, $FF                             
	ld HL,MEM_C300                           
	call CLEARMEMSMALL ;04:096A             
	ld B, $FF                             
	ld HL,MEM_C400                           
	call CLEARMEMSMALL ;04:096A             
	xor A                                 
	ld [$C0A6],A ;04:C0A6                 
	ldh [$FF93],A                     
	ldh [$FF92],A    
    
    ;  
	ld BC, $9F80 
	ld A,B                                ; 
	ldh [$FF96],A                         ; 
	ld A,C                                ; 
	ldh [$FF97],A                         ; 
	ld HL,Data_0_0E4C  
	call DrawPic ;call F_Addr_0004D0   
    
    call F_Addr_002264 ;////////////
    
    
	ld B, $14                             
	ld C,$0E                              
	ld DE,$9C00                           
	ld HL,Data_0_0E9E                           
	call F_Addr_00052F ;04:052F 
    
	call F_Addr_001D84 ;04:1D84             
	ld HL,$C9CF                           
	set 2, [HL]                           
	call F_Addr_000EE5 ;04:0EE5             
	call F_Addr_001957 ;01:1957             
	call F_Addr_0012C1 ;01:12C1             
	call F_Addr_000324 ;03:0324             
	ld A,$1B                              
	;ldh [R_BGP],A                     
	ld A,$6C                              
	;ldh [R_OBP1],A                     
	ld A,$1E                              
	;ldh [R_OBP0],A                     
	call F_FadeIn_00112C ;03:112C             
	ld A,[MEM_CURRENT_LEVEL] ;03:C900                 
	add A,$03                             
	call F_Addr_0002E7 ;03:02E7             
	ld A,[$C91C] ;03:C91C                 
	cp $02                                
	jr NZ,Addr_000A99                     
	ld A,$01                            
	ld [$C9B9],A ;00:C9B9               
	jp Addr_000BEC ;00:0BEC             
    
Addr_000A99:
	ld HL,$C90E                           
	inc [HL]                              
	ld C,$01                              
	call F_Delay_00036C ;01:036C             
	call JOYPAD_000391 ;01:0391             
	ld A,[MEM_LIFE] ;01:C911                 
	and A                                 
	jp Z,Addr_000B7D ;01:0B7D             
	ld A,[$C9CF] ;01:C9CF                 
	and A                                 
	jp NZ,Addr_000B7D ;01:0B7D            
	ld A,[$C9C9] ;01:C9C9                 
	and A                                 
	jp NZ,Addr_000B7D ;01:0B7D            
	ld A,[$C9CA] ;01:C9CA                 
	and A                                 
	jp NZ,Addr_000B7D ;01:0B7D            
	ld A,[$C9CC] ;01:C9CC                 
	and A                                 
	jp NZ,Addr_000B7D ;01:0B7D            
	ld HL,$C0A1                           
	ldh A,[$FF93]                     
	and $08                               
	jp Z,Addr_000B7D ;01:0B7D             
	ld A,[HL]                             
	xor $01                               
	ld [HL],A                             
	jr NZ,Addr_000B0B                     
	
    ld B, $14                             
	ld C,$0E                              
	ld DE,$9C00                           
	ld HL,Data_0_0E9E                     
	call F_Addr_00052F ;01:052F 
    
	call F_Addr_000DA3 ;01:0DA3             
	ld A,$31                              
	call F_Addr_0002E7 ;01:02E7             
Addr_000AED:
	ldh A,[$FF4A]                     
	add A,$04                             
	ldh [$FF4A],A                     
	ld C,$01                              
	call F_Delay_00036C ;01:036C             
	ldh A,[$FF4A]                     
	cp $8C                                
	jr NZ,Addr_000AED                     
	ldh A,[R_LCDC]                     
	and $DF                               
	ldh [R_LCDC],A                     
	ld C,$01                              
	call F_Delay_00036C ;01:036C             
	jr Addr_000B7D                        
    
Addr_000B0B:
	xor A                                 
	ldh [$FFA0],A                     
	call F_Addr_001336 ;01:1336             
	ld A,$30                              
	call F_Addr_0002E7 ;01:02E7             
	ld A,[$CA03] ;01:CA03                 
	ld [$CA09],A ;01:CA09                 
	ld A,[$CA04] ;01:CA04                 
	ld [$CA0A],A ;01:CA0A                 
	ld A,$07                              
	ldh [$FF4B],A                     
	ld A,$8C                              
	ldh [$FF4A],A                     
	ldh A,[R_LCDC]                     
	or $20                                
	ldh [R_LCDC],A                     
	ld C,$01                              
	call F_Delay_00036C ;01:036C             
    
Addr_000B35:
	ldh A,[$FF4A]                     
	sub $04                               
	ldh [$FF4A],A                     
	ld C,$01                              
	call F_Delay_00036C ;01:036C             
	ldh A,[$FF4A]                     
	cp $20                                
	jr NZ,Addr_000B35 

    ld A,0
    ld [MEM_VBK_BANK],A 
    
	ld B, $9E                           
	ld C,$04                              
	call SetTiles ;01:0591             
	ld B, $94                         
	ld C,$05                              
	call SetTiles ;01:0591  
    
	ld A,BANK_06                              
	call SWITHBANK1 ;01:108F             
	ld HL,Data_6_7D7E;Data_6_4026                           
	ld BC, $9C21 
	ld A,B                                ; 
	ldh [$FF96],A                         ; 
	ld A,C                                ; 
	ldh [$FF97],A
    call DrawPic ;F_Addr_0004D0 ;06:04D0 


	call F_Addr_00109B ;06:109B             
	ld A,$9C                              
	ldh [$FF96],A                     
	ld A,$2A                              
	ldh [$FF97],A                     
	call F_Addr_000DD0 ;01:0DD0             
	call F_Addr_000E0E ;01:0E0E             
	xor A                                 
	ld [$C5CB],A ;01:C5CB                 
	ld [$C5CC],A ;01:C5CC                 
Addr_000B7D:
	ld HL,$C0A1                           
	bit 0, [HL]                           
	jr Z,Addr_000B95                      
	ld A,BANK_05                              
	call SWITHBANK1 ;01:108F             
	;ld HL,Data_5_401C                           
	call Addr_0148C5;GOTOHL ;05:10A3             
	call F_Addr_00109B ;05:109B             
	jp Addr_000A99 ;01:0A99               
    
Addr_000B95:
	call F_Addr_0012C1 ;01:12C1             
	ld A,[$C700] ;01:C700                 
	and $0F                               
	jp Z,Addr_000C63 ;01:0C63             
	call F_Addr_00194C ;01:194C             
	call F_Addr_000EA7 ;01:0EA7             
	ld A,[$C91C] ;01:C91C                 
	cp $03                                
	jp Z,Addr_000CBD ;01:0CBD             
	ld A,[$C9F2] ;01:C9F2                 
	and A                                 
	jp NZ,Addr_000D11 ;01:0D11            
	ld A,[MEM_LIFE] ;01:C911                 
	and A                                 
	jp Z,Addr_000A99 ;01:0A99  

	ld A,BANK_14      ;?????????????????????               
	ld [$2000],A ;01:2000  

    ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	ld HL,Data_0_1065                           
	rst $20                               
 
    ld L,E                                
	ld H,D                                
	inc HL                                
	inc HL                                
	ld A,[LVLPOS_YL] ;01:C0A9                 
	ld B,A                                
	ld A,[HL+]                            
	cp B                                  
	jp NZ,Addr_000A99 ;01:0A99            
	ld A,[LVLPOS_YH] ;01:C0AA                 
	ld B,A                                
	ld A,[HL-]                            
	cp B                                  
	jp NZ,Addr_000A99 ;01:0A99            
	dec HL                                
	ld A,[LVLPOS_XH] ;01:C0AC                 
	ld B,A                                
	ld A,[HL-]                            
	cp B                                  
	jp NZ,Addr_000A99 ;01:0A99            
	ld A,[LVLPOS_XL] ;01:C0AB                 
	ld B,A                                
	ld A,[HL-]                            
	cp B                                  
	jp NZ,Addr_000A99 ;01:0A99            
Addr_000BEC:
	xor A                                 
	ld [$C9CD],A ;01:C9CD                 
	ld [$C9CE],A ;01:C9CE                 
	ld [$C9C9],A ;01:C9C9                 
	ld [$C9CA],A ;01:C9CA                 
	ld [$C9CC],A ;01:C9CC                 
	ld [$C805],A ;01:C805                 
	ld A,[$C700] ;01:C700                 
	res 7, A                              
	ld [$C700],A ;01:C700                 
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	cp $06  ;BERMUDA end                              
	jr Z,Addr_000C13                      
	ld A,$0A                              
	call F_Addr_0002E7 ;03:02E7             
Addr_000C13:
	ld A,[$C9B9] ;01:C9B9                 
	or $01                                
	ld [$C9B9],A ;01:C9B9                 
	ld A,$02                              
	ld [$C91C],A ;01:C91C                 
	ld [$CA40],A ;01:CA40    
    
	ld A,BANK_14      ;?????????????????????               
	ld [$2000],A ;01:2000  
    
	ld A,[MEM_CURRENT_LEVEL] ;01:C900  
    ld HL,Data_0_1009                           
	rst $18                               
	ld HL,$CA0F                           
	and A                                 
	jr NZ,Addr_000C38                     
	res 0, [HL]                           
	ld A,$F4                              
	ld C,$01                              
	jr Addr_000C3E                        
Addr_000C38:
	set 0, [HL]                           
	ld A,$0C                              
	ld C,$FF                              
Addr_000C3E:
	ld [$C709],A ;01:C709                 
	ld B, $50                             
Addr_000C43:
	ld A,C                                
	ldh [$FFB9],A                     
	push BC                               
	ld C,$01                              
	call F_Delay_00036C ;01:036C             
	call F_Addr_0012C1 ;01:12C1             
	call F_Addr_000EA7 ;01:0EA7             
	call F_Addr_001966 ;01:1966             
	call F_Addr_001957 ;01:1957             
	pop BC                                
	dec B                                 
	jr NZ,Addr_000C43                     
	xor A                                 
	ld [$CA40],A ;01:CA40                 
	jp Addr_000A99 ;01:0A99               
    
;*****************************************
;*         
;*****************************************
Addr_000C63:
	xor A                                 
	ld [$C929],A ;01:C929                 
	ld [$C92A],A ;01:C92A                 
	ld [$C92B],A ;01:C92B                 
	ld [$C92C],A ;01:C92C                 
	ld [$C9CD],A ;01:C9CD                 
	ld [$C9CE],A ;01:C9CE                 
	ld [$C919],A ;01:C919                 
	ld [$C91A],A ;01:C91A                 
	ld HL,MEM_GLOBAL_LIFE                           
	dec [HL]                              
	jr Z,Addr_000C97                      
	ld A,$11                              
	call F_Addr_0002E7 ;01:02E7             
	ld B, $78                             
	call F_Addr_000CEE ;01:0CEE             
	call F_FadeOut_0010B3 ;01:10B3             
	ld A,$00                              
	call F_Addr_0002E7 ;01:02E7             
	jp Addr_0008EE ;01:08EE               
    
;*****************************************
;*  .    "game over"
;*****************************************
Addr_000C97:
	ld A,$12                            
	call F_Addr_0002E7 ;00:02E7           
	ld B, $F0                           
	call F_Addr_000CEE ;00:0CEE           
	call F_FadeOut_0010B3 ;00:10B3           
	ld A,$00                            
	call F_Addr_0002E7 ;00:02E7           
	xor A                               
	ld [$C91C],A ;00:C91C               
	ld B, $FF                           
	ld HL,MEM_C100                         
	call CLEARMEMSMALL ;00:096A           
	ld A,$06                            
	ld [STATEGAME],A ;00:C0A0               
	jp Addr_0008EE ;00:08EE             
    
;*****************************************
;* 
;*****************************************
Addr_000CBD:
	ld A,$0D                              
	call F_Addr_0002E7 ;01:02E7             
	xor A                                 
	ldh [$FF93],A                     
	ldh [$FF92],A                     
	ld B, $B4                             
	call F_Addr_000CEE ;01:0CEE             
	call F_FadeOut_0010B3 ;03:10B3             
	ld A,$00                              
	call F_Addr_0002E7 ;03:02E7             
	xor A                                 
	ld [$C91C],A ;03:C91C                 
	ld [$C919],A ;03:C919                 
	ld [$C91A],A ;03:C91A                 
	ld B, $FF                             
	ld HL,MEM_C100                           
	call CLEARMEMSMALL ;03:096A             
	ld A,$09                              
	ld [STATEGAME],A ;03:C0A0                 
	jp Addr_0008EE ;03:08EE               
    
;*****************************************
;* 
;*****************************************
F_Addr_000CEE:
	push BC                               
	ld HL,$C90E                           
	inc [HL]                              
	ld C,$01                              
	call F_Delay_00036C ;03:036C             
	call F_Addr_0012C1 ;03:12C1             
	call F_Addr_000EA7 ;03:0EA7             
	pop BC                                
	dec B                                 
	jr NZ,F_Addr_000CEE                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_000D03:
	push BC                               
	ld C,$01                              
	call F_Delay_00036C ;01:036C             
	call F_Addr_000EA7 ;01:0EA7             
	pop BC                                
	dec B                                 
	jr NZ,F_Addr_000D03                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_000D11:
	ld B, $10                             
	call F_Addr_000D03 ;01:0D03             
	xor A                                 
	ldh [$FFA0],A                     
	call F_Addr_001336 ;01:1336             
	ld A,$30                              
	call F_Addr_0002E7 ;01:02E7             
	ld A,[$CA03] ;01:CA03                 
	ld [$CA09],A ;01:CA09                 
	ld A,[$CA04] ;01:CA04                 
	ld [$CA0A],A ;01:CA0A                 
	ld A,$A3                              
	ldh [$FF4B],A                     
	ld A,$20                              
	ldh [$FF4A],A                     
	ldh A,[R_LCDC]                     
	or $20                                
	ldh [R_LCDC],A                     
	ld C,$01                              
	call F_Delay_00036C ;01:036C             
Addr_000D40:
	ldh A,[$FF4B]                     
	sub $04                               
	ldh [$FF4B],A                     
	ld C,$01                              
	call F_Delay_00036C ;01:036C             
	ldh A,[$FF4B]                     
	cp $07                                
	jr NZ,Addr_000D40                     
	ld A,$1B                              
	;ldh [R_BGP],A                     
	ld A,$6C                              
	;ldh [R_OBP1],A                     
	ld A,$1E                              
	;ldh [R_OBP0],A                     
	
    ld A,BANK_05                              
	call SWITHBANK1 ;01:108F             
	call FL_016634 ; ld HL,Data_5_401A ;call GOTOHL ;05:10A3             
	
    call F_Addr_00109B ;05:109B 
    
	ld B, $14                             
	ld C,$0E                              
	ld DE,$9C00                           
	ld HL,Data_0_0E9E                           
    call F_Addr_00052F ;01:052F             
    
	call F_Addr_000DA3 ;01:0DA3             
	ld A,$31                              
	call F_Addr_0002E7 ;01:02E7             
Addr_000D80:
	ldh A,[$FF4B]                     
	add A,$04                             
	ldh [$FF4B],A                     
	ld C,$01                              
	call F_Delay_00036C ;01:036C             
	ldh A,[$FF4B]                     
	cp $A3                                
	jr NZ,Addr_000D80                     
	ldh A,[R_LCDC]                     
	and $DF                               
	ldh [R_LCDC],A                     
	ld C,$01                              
	call F_Delay_00036C ;01:036C             
	xor A                                 
	ld [$C9F2],A ;01:C9F2                 
	jp Addr_000A99 ;01:0A99               
    
;*****************************************
;* 
;*****************************************
F_Addr_000DA3:
    ret ;?????????????????????????????????????????????????????????/
    ; ld A,0
    ; ld [MEM_VBK_BANK],A 
    
    ; ld A,[$CA09] ;01:CA09                 
	; ld B,A                                
	; ld C,$04                              
	; call SetTiles ;01:0591             
	; ld A,[$CA0A] ;01:CA0A                 
	; ld B,A                                
	; ld C,$05                              
	; call SetTiles ;01:0591 
    
    
    ; ld A,1
    ; ld [MEM_VBK_BANK],A 
	; ld A,BANK_14                              
	; call SWITHBANK1 ;01:108F             
	; call F_Addr_000FC4 ;07:0FC4             
	; jp F_Addr_00109B ;07:109B               
    
;*****************************************
;* 
;*****************************************
F_Addr_000DC0:
	ld A,$9F                              
	ldh [$FF96],A                     
	ld A,$A6;//A   ///////////////////////////////////////////////////////////////////////                            
	ldh [$FF97],A                     
;*****************************************
F_Addr_000DC8:
	ld DE,$C929                           
	ld B, $08; 88   8 .   8                           
	jp F_Addr_0006CA ;01:06CA               
    
;*****************************************
;* 
;*****************************************
F_Addr_000DD0:
	ld DE,$C925                           
	ld B, $88                             
	jp F_Addr_0006CA               
    
;*****************************************
;* 
;*****************************************
F_Addr_000DD8:
	push HL                               
	ld DE,$C928                           
	ld HL,$C92C                           
	call F_Addr_000697 ;05:0697             
	xor A                                 
	ld [$C929],A ;05:C929                 
	ld [$C92A],A ;05:C92A                 
	ld [$C92B],A ;05:C92B                 
	ld [$C92C],A ;05:C92C                 
	pop HL                                
	ld A,[HL+]                            
	ldh [$FF97],A                     
	ld A,[HL+]                            
	ldh [$FF96],A                     
	push HL                               
	ld DE,$C925                           
	ld B, $88                             
	call F_Addr_0006CA ;05:06CA             
	pop HL                                
	ld A,[HL+]                            
	ldh [$FF97],A                     
	ld A,[HL+]                            
	ldh [$FF96],A                     
	ld DE,$C929                           
	ld B, $88                             
	jp F_Addr_0006CA ;05:06CA               
    
;*****************************************
;* 
;*****************************************
F_Addr_000E0E:
	ld A,[MEM_FERRULE_1] ;01:C91D                 
	and A                                 
	jr Z,.L_000E1D                      
	ld BC, $9CAA                          
	ld HL,Data_0_0E3A                           
	call F_Addr_0004D0 ;01:04D0             
.L_000E1D:
	ld A,[MEM_FERRULE_2] ;01:C91E                 
	and A                                 
	jr Z,.L_000E2C                      
	ld BC, $9CAD                        
	ld HL,Data_0_0E40                   
	call F_Addr_0004D0 ;00:04D0           
.L_000E2C:
	ld A,[MEM_FERRULE_3] ;01:C91F                 
	and A                                 
	ret Z                                 
	ld BC, $9CB0                        
	ld HL,Data_0_0E46                   
	jp F_Addr_0004D0 ;00:04D0             
    
;*****************************************
;*   ??????????????
;*****************************************
Data_0_0E3A:
	DB $02                                ; 0X000E3A 00:0E3A 02 02 46; ld [BC],A
	DB $02                                ; 0X000E3B 00:0E3B 02 46 47; ld [BC],A
	DB $46,$47                                ; 0X000E3D 00:0E3D 47 56 57; ld B,A
	DB $56,$57                                ; 0X000E3F 00:0E3F 57 02 02; ld D,A
;*****************************************
Data_0_0E40:
	DB $02                              ;*; 0X000E40 00:0E40 02 02 48; ld [BC],A
	DB $02                              ;*; 0X000E41 00:0E41 02 48 49; ld [BC],A
	DB $48,$49                              ;*; 0X000E43 00:0E43 49 58 59; ld C,C
	DB $58,$59                              ;*; 0X000E45 00:0E45 59 02 02; ld E,C
;*****************************************
Data_0_0E46:
	DB $02                              ;*; 0X000E46 00:0E46 02 02 60; ld [BC],A
	DB $02                              ;*; 0X000E47 00:0E47 02 60 61; ld [BC],A
	DB $60,$61                              ;*; 0X000E49 00:0E49 61 70 71; ld H,C
	DB $70,$71                              ;*; 0X000E4B 00:0E4B 71 14 04; ld [HL],C

;*****************************************
;*  
;*****************************************
PLS EQU $07 ; 
Data_0_0E4C:
	DB $14   ;WIDTH    ;  00:0E4C
	DB $04   ;HEIGHT   ;  00:0E4D
	DB $00,$00,$00,$00,$78,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$79,$00,$00,$00,$00  ; 00:0E61
    DB PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS
    DB $78,$7D,$7D,$7D,$7B,$00,$00,$00,$00,$00,$00,$00,$00,$F0,$00,$7A,$7D,$7D,$7D,$79  ; 00:0E75
    DB PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS
    DB $7C,$00,$FD,$FE,$00,$00,$7E,$7E,$7E,$00,$00,$00,$00,$00,$ED,$FE,$00,$00,$00,$7C  ; 00:0E89
    DB PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS
    DB $7A,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7D,$7B  ; 00:0E9D
    DB PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS,PLS


;*****************************************
;*       "pause"
;*****************************************
Data_0_0E9E:
	DB $78                                ; 0X000E9E 00:0E9E 78 7D 79; ld A,B
	DB $7D                                ; 0X000E9F 00:0E9F 7D 79 7C; ld A,L
	DB $79                                ; 0X000EA0 00:0EA0 79 7C 00; ld A,C
	DB $7C                                ; 0X000EA1 00:0EA1 7C 00 7C; ld A,H
	DB $00                                ; 0X000EA2 00:0EA2 00 7C 7A; nop
	DB $7C                                ; 0X000EA3 00:0EA3 7C 7A 7D; ld A,H
	DB $7A                                ; 0X000EA4 00:0EA4 7A 7D 7B; ld A,D
	DB $7D                                ; 0X000EA5 00:0EA5 7D 7B FA; ld A,L
	DB $7B                                ; 0X000EA6 00:0EA6 7B FA A0; ld A,E
    
;*****************************************
;* 
;*****************************************
F_Addr_000EA7:
	ld A,[STATEGAME] ;05:C0A0                 
	cp $03                                
	ret NZ                                
	ld A,[MEM_CURRENT_LEVEL] ;01:C900  
;jr .L_000EC0;DELETE???????????????????????????????????????????????????????????????????    
	cp $06                                
	jr Z,.L_000EC0                      
	cp $03                                
	ret NC                                
	cp $01                                
	jr NZ,.L_000EC0                     
	ld A,[LVLPOS_YH] ;03:C0AA                 
	and A                                 
	ret NZ                                
.L_000EC0:
	ld A,BANK_06                              
	call SWITHBANK1 ;01:108F             
	ld HL,Data_6_7A70                          
	ld A,[MEM_CURRENT_LEVEL] ;06:C900                 
	rst $20                               
	ld HL,$C90F                           
	inc [HL]                              
	ld A,[HL]                             
	cp $18                                
	jr C,.L_000EDA                      
	xor A                                 
	ld [HL],A                             
.L_000EDA:
	ld L,E                                
	ld H,D                                
	rst $20                               
	ld H,D                                
	ld L,E                                
	call SetupTile ;06:05ED             
	jp F_Addr_00109B ;06:109B               
    
;*****************************************
;* 
;*****************************************
F_Addr_000EE5:
	ld A,[$C916] ;04:C916                 
	and A                                 
	jr Z,.L_000F05                      
	ld A,$40                              
	ld [LVLPOS_XL],A ;04:C0AB                 
	ld A,$06                              
	ld [LVLPOS_XH],A ;04:C0AC                 
	ld A,$00                              
	ld [LVLPOS_YL],A ;04:C0A9                 
	ld A,$02                              
	ld [LVLPOS_YH],A ;04:C0AA                 
	xor A                                 
	ld [$C916],A ;04:C916                 
	jr L_000F24                        
.L_000F05:
	ld A,BANK_14                     
	ld [$2000],A ;01:2000  

	ld A,[$C91C] ;04:C91C                 
	ld HL,Data_0_1017                           
	rst $20                               
	ld L,E                                
	ld H,D                                
	ld A,[MEM_CURRENT_LEVEL] ;04:C900                 
	rst $20                               
	ld L,E                                
	ld H,D                                
	ld A,[HL+]                            
	ld [LVLPOS_XL],A ;04:C0AB                 
	ld A,[HL+]                            
	ld [LVLPOS_XH],A ;04:C0AC                 
	ld A,[HL+]                            
	ld [LVLPOS_YL],A ;04:C0A9                 
	ld A,[HL]                             
	ld [LVLPOS_YH],A ;04:C0AA 
    
L_000F24:
	ld A,BANK_14                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;04:2000                 
	ld HL,Data_7_7B20;Data_7_4020                           
	ld A,[MEM_CURRENT_LEVEL] ;07:C900                 
	rst $20                               
	ld L,E                                
	ld H,D 
    
    ld A,0
    ld [MEM_VBK_BANK],A 
	call SetFullTiles ;07:0573             
    ld A,1
    ld [MEM_VBK_BANK],A 
	call SetFullTiles 
    ld A,0
    ld [MEM_VBK_BANK],A 
    
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
	ld HL,Data_LevelPallete                          
	ld A,[MEM_CURRENT_LEVEL]                 
	rst $20                               
	ld L,E                                
	ld H,D                                
	call SetupPalDat 
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    
    ld HL,Data_7_7BF2;Data_7_4028                           
	ld A,[MEM_CURRENT_LEVEL] ;07:C900                 
	rst $20                               
	ld L,E                                
	ld H,D                                
	call SetupTile ;07:05ED             
	call F_Addr_000F8F ;07:0F8F             
	
    ld A,BANK_01                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;07:2000                 
	
    ld HL,Data_1_5CC6                           
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	rst $20                               
	ld A,E                                
	ld [$CA42],A ;01:CA42                 
	ld A,D                                
	ld [$CA43],A ;01:CA43  
    
	ld HL,Data_1_5D1C                           
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	rst $20                               
	ld A,E                                
	ld [$CA44],A ;01:CA44                 
	ld A,D                                
	ld [$CA45],A ;01:CA45                 
	
    call F_Addr_0018CA ;01:18CA             
	ld A,[LVLPOS_YL] ;05:C0A9                 
	ld L,A                                
	ld [$CA49],A ;05:CA49                 
	ld A,[LVLPOS_YH] ;05:C0AA                 
	ld H,A                                
	ld [$CA4A],A ;05:CA4A                 
	call F_Addr_001BBC ;05:1BBC             
	call F_Addr_0011E3 ;01:11E3             
	call F_Addr_00128D ;01:128D             
	call F_Addr_000DC0 ;01:0DC0             
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_000F8F:
	ld A,BANK_14                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;01:2000  
    
	ld HL,Data_7_7B52;Data_7_4022                           
	ld A,[MEM_CURRENT_LEVEL] ;07:C900                 
	rst $20                               
	ld L,E                                
	ld H,D                                
	call F_Addr_000FE5 ;07:0FE5             
	rst $20                               
	ld L,E                                
	ld H,D                                
	call SetupTile ;07:05ED 
    
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    
 	ld HL,Data_L_Palettes                           
	ld A,[MEM_CURRENT_LEVEL]                  
	rst $20                               
	ld L,E                                
	ld H,D                                
	call F_Addr_000FE5              
	rst $20                               
	ld L,E                                
	ld H,D                                
	call SetupPalDat  
    
    ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
    
	ld A,[MEM_CURRENT_LEVEL] ;07:C900                 
	cp $05                                
	jr NC,F_Addr_000FC4  
  
	ld HL,Data_7_7BA8;Data_7_4024                           
	rst $20                               
	ld L,E                                
	ld H,D                                
	call F_Addr_000FE5 ;07:0FE5             
	rst $20                               
	ld L,E                                
	ld H,D                                
	call SetupTile ;07:05ED 
    
F_Addr_000FC4:
	ld A,[MEM_CURRENT_LEVEL] ;07:C900                 
	cp $01                                
	jr Z,Addr_000FD3  ;  BERMUDA                    
	cp $03                                
	ret NZ  ;   MU 
    
	ld B,A                                
	ld A,[$C915] ;07:C915                 
	add A,B  
    
Addr_000FD3:
	ld HL,Data_7_7C00;Data_7_402A                           
	rst $20                               
	ld L,E                                
	ld H,D                                
	call F_Addr_000FE5 ;07:0FE5             
	rst $20                               
	ld L,E                                
	ld H,D                                
	jp SetupTile ;07:05ED  
    
F_Addr_000FE5:
	ld B, $01                             
	ld A,[LVLPOS_YL] ;07:C0A9                 
	and A                                 
	jr NZ,Addr_000FEE                     
	ld B,A                                
Addr_000FEE:
	ld A,[LVLPOS_YH] ;07:C0AA                 
	sla A                                 
	add A,B                               
	ret                                   
    
;*****************************************
;* FUNCTION SWITHBANK1
;* A - BANK
;*****************************************
SWITHBANK1:
	push AF                               
	ldh A,[MEM_CURRENT_BANK]                     
	ldh [MEM_OLD_BANK],A                     
	pop AF                                
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;05:2000                 
	ret                                   

;*****************************************
;* FUNCTION SWITHBANK2
;*****************************************
SWITHBANK2:
F_Addr_00109B:
	ldh A,[MEM_OLD_BANK]                     
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;01:2000                 
	ret                                   

;*****************************************
;* FUNCTION GOTOHL
;* HL <- ADDRESS
;*****************************************
GOTOHL:
	push DE                               
	ld E,[HL]                             
	inc HL                                
	ld D,[HL]                             
	ld L,E                                
	ld H,D                                
	pop DE                                
	jp [HL]                               

;*****************************************
;* FUNCTION GETADDRHL
;* HL <- ADDRESS
;* HL -> ADDRESS
;*****************************************
;GETADDRHL:
;	push DE                               
;	ld E,[HL]                             
;	inc HL                                
;	ld D,[HL]                             
;	ld L,E                                
;	ld H,D                                
;	pop DE                                
;	ret                                   
    
;*****************************************
;* FADE OUT
;*****************************************
; F_FadeOut_0010B3:
	; ldh A,[R_OBP0]                     
	; ld [$C9F5],A ;05:C9F5                 
	; ldh A,[R_OBP1]                     
	; ld [$C9F6],A ;05:C9F6                 
	; ldh A,[R_BGP]                     
	; ld [$C9F7],A ;05:C9F7                 
	; ld B, $03                             
; .L_0010C4:
	; push BC                               
	; ld B, $08                             
; .L_0010C7:
	; push BC                               
	; ld C,$01                              
	; call F_Delay_00036C ;05:036C             
	; call F_Addr_000EA7 ;05:0EA7             
	; pop BC                                
	; dec B                                 
	; jr NZ,.L_0010C7                     
	; ldh A,[R_OBP0]                     
	; call F_Addr_0010EE ;05:10EE             
	; ldh [R_OBP0],A                     
	; ldh A,[R_OBP1]                     
	; call F_Addr_0010EE ;05:10EE             
	; ldh [R_OBP1],A                     
	; ldh A,[R_BGP]                     
	; call F_Addr_0010EE ;05:10EE             
	; ldh [R_BGP],A                     
	; pop BC                                
	; dec B                                 
	; jr NZ,.L_0010C4                     
	; ret                                   
    
;*****************************************
;* 
;*****************************************
; F_Addr_0010EE:
	; ld B, $00                             
	; ld C,A                                
	; and $03                               
	; jr Z,.L_0010F6                      
	; dec A                                 
; .L_0010F6:
	; or B                                  
	; ld B,A                                
	; ld A,C                                
	; SRL A                                 
	; SRL A                                 
	; and $03                               
	; jr Z,.L_001102                      
	; dec A                                 
; .L_001102:
	; sla A                                 
	; sla A                                 
	; or B                                  
	; ld B,A                                
	; ld A,C                                
	; SRL A                                 
	; SRL A                                 
	; SRL A                                 
	; SRL A                                 
	; and $03                               
	; jr Z,.L_001116                      
	; dec A                                 
; .L_001116:
	; sla A                                 
	; sla A                                 
	; sla A                                 
	; sla A                                 
	; or B                                  
	; ld B,A                                
	; ld A,C                                
	; RLCA                                  
	; RLCA                                  
	; and $03                               
	; jr Z,.L_001128                      
	; dec A                                 
; .L_001128:
	; RRCA                                  
	; RRCA                                  
	; or B                                  
	; ret                                   
    
    
    
    
    
;*****************************************
;* FADE IN
;*****************************************
; F_FadeIn_00112C:
	; ldh A,[R_BGP]                     
	; and A                                 
	; jr Z,.L_001147                      
	; ldh A,[R_OBP0]                     
	; ld [$C9F5],A ;05:C9F5                 
	; ldh A,[R_OBP1]                     
	; ld [$C9F6],A ;05:C9F6                 
	; ldh A,[R_BGP]                     
	; ld [$C9F7],A ;05:C9F7                 
	; xor A                                 
	; ldh [R_OBP0],A                     
	; ldh [R_OBP1],A                     
	; ldh [R_BGP],A                     
; .L_001147:
	; call F_Addr_00034F ;05:034F             
	; ld B, $03                             
; .L_00114C:
	; push BC                               
	; ld B, $08                             
; .L_00114F:
	; push BC                               
	; ld C,$01                              
	; call F_Delay_00036C ;05:036C             
	; call F_Addr_000EA7 ;05:0EA7             
	; pop BC                                
	; dec B                                 
	; jr NZ,.L_00114F                     
	; ld A,[$C9F5] ;05:C9F5                 
	; ld D,A                                
	; ldh A,[R_OBP0]                     
	; call F_Addr_001182 ;05:1182             
	; ldh [R_OBP0],A                     
	; ld A,[$C9F6] ;05:C9F6                 
	; ld D,A                                
	; ldh A,[R_OBP1]                     
	; call F_Addr_001182 ;05:1182             
	; ldh [R_OBP1],A                     
	; ld A,[$C9F7] ;05:C9F7                 
	; ld D,A                                
	; ldh A,[R_BGP]                     
	; call F_Addr_001182 ;05:1182             
	; ldh [R_BGP],A                     
	; pop BC                                
	; dec B                                 
	; jr NZ,.L_00114C                     
	; ret                                   
    
;*****************************************
;* 
;*****************************************
; F_Addr_001182:
	; ld B, $00                             
	; ld C,A                                
	; ld A,D                                
	; and $03                               
	; ld E,A                                
	; ld A,C                                
	; and $03                               
	; cp E                                  
	; jr Z,.L_001190                      
	; inc A                                 
; .L_001190:
	; or B                                  
	; ld B,A                                
	; ld A,D                                
	; SRL A                                 
	; SRL A                                 
	; and $03                               
	; ld E,A                                
	; ld A,C                                
	; SRL A                                 
	; SRL A                                 
	; and $03                               
	; cp E                                  
	; jr Z,.L_0011A5                      
	; inc A                                 
; .L_0011A5:
	; sla A                                 
	; sla A                                 
	; or B                                  
	; ld B,A                                
	; ld A,D                                
	; SRL A                                 
	; SRL A                                 
	; SRL A                                 
	; SRL A                                 
	; and $03                               
	; ld E,A                                
	; ld A,C                                
	; SRL A                                 
	; SRL A                                 
	; SRL A                                 
	; SRL A                                 
	; and $03                               
	; cp E                                  
	; jr Z,.L_0011C6                      
	; inc A                                 
; .L_0011C6:
	; sla A                                 
	; sla A                                 
	; sla A                                 
	; sla A                                 
	; or B                                  
	; ld B,A                                
	; ld A,D                                
	; RLCA                                  
	; RLCA                                  
	; and $03                               
	; ld E,A                                
	; ld A,C                                
	; RLCA                                  
	; RLCA                                  
	; and $03                               
	; cp E                                  
	; jr Z,.L_0011DF                      
	; inc A                                 
; .L_0011DF:
	; RRCA                                  
	; RRCA                                  
	; or B                                  
	; ret                                   
    
;*****************************************
;*    
;*****************************************
F_Addr_0011E3:
    ld A,[$C910] ;01:C910                 
	bit 0, A                              
	jr Z,.L_0011EB                      
	inc A                             
.L_0011EB:
	SRL A                                 
	ld HL,Data_0_1207                           
	rst $20                               
	ld L,E                                
	ld H,D                                
	ld A,[MEM_LIFE] ;01:C911                 
	bit 0, A                              
	jr Z,.L_0011FB                      
	inc A                             
.L_0011FB:
	SRL A                                 
	rst $20                               
	ld L,E                                
	ld H,D                                
	ld B, $9F                             
	ld C,$C6                              
	jp F_Addr_0004D0 ;01:04D0               
    
;*****************************************
;* 
;*****************************************
Data_0_1207:
	DW D_1213                              ;*; 0X001207 00:1207 13 12 13; inc DE
	DW D_1213                              ;*; 0X001209 00:1209 13 12 13; inc DE
	DW D_1213                              ;*; 0X00120B 00:120B 13 12 13; inc DE
	DW D_1213                                ; 0X00120D 00:120D 13 12 1B; inc DE
	DW D_121B                                ; 0X00120F 00:120F 1B 12 25; dec DE
	DW D_1225                                ; 0X001211 00:1211 25 12 88; dec H
D_1213:
	DW D_1288                              ;*; 0X001213 00:1213 88 12 83; adc A,B
	DW D_1283                              ;*; 0X001215 00:1215 83 12 7E; add A,E
	DW D_127E                                ; 0X001217 00:1217 7E 12 79; ld A,[HL]
	DW D_1279                              ;*; 0X001219 00:1219 79 12 73; ld A,C
D_121B:
	DW D_1273                              ;*; 0X00121B 00:121B 73 12 6D; ld [HL],E
	DW D_126D                              ;*; 0X00121D 00:121D 6D 12 67; ld L,L
	DW D_1267                                ; 0X00121F 00:121F 67 12 61; ld H,A
	DW D_1261                              ;*; 0X001221 00:1221 61 12 5B; ld H,C
	DW D_125B                              ;*; 0X001223 00:1223 5B 12 54; ld E,E
D_1225:
	DW D_1254                              ;*; 0X001225 00:1225 54 12 4D; ld D,H
	DW D_124D                              ;*; 0X001227 00:1227 4D 12 46; ld C,L
	DW D_1246                                ; 0X001229 00:1229 46 12 3F; ld B,[HL]
	DW D_123F                              ;*; 0X00122B 00:122B 3F 12 38; CCF
	DW D_1238                              ;*; 0X00122D 00:122D 38 12 31; jr C,Addr_001241
	DW D_1231                              ;*; 0X00122F 00:122F 31 12 05; ld SP,$0512
;*****************************************
D_1231:
	DB $05                              ;*; 0X001231 00:1231 05 01 7E; dec B
	DB $01                              ;*; 0X001232 00:1232 01 7E 7E; ld BC, $7E7E
	DB $7E,$7E,$7E,$7E,$7E                              ;*; 0X001237 00:1237 7E 05 01; ld A,[HL]
D_1238:
	DB $05                              ;*; 0X001238 00:1238 05 01 7E; dec B
	DB $01                              ;*; 0X001239 00:1239 01 7E 7E; ld BC, $7E7E
	DB $7E,$7E,$7E,$7E,$7F                              ;*; 0X00123E 00:123E 7F 05 01; ld A,A
D_123F:
	DB $05                              ;*; 0X00123F 00:123F 05 01 7E; dec B
	DB $01                              ;*; 0X001240 00:1240 01 7E 7E; ld BC, $7E7E
	DB $7E,$7E,$7E,$7F,$7F                              ;*; 0X001245 00:1245 7F 05 01; ld A,A
D_1246:
	DB $05                                ; 0X001246 00:1246 05 01 7E; dec B
	DB $01                                ; 0X001247 00:1247 01 7E 7E; ld BC, $7E7E
	DB $7E,$7E,$7F,$7F,$7F                                ; 0X00124C 00:124C 7F 05 01; ld A,A
D_124D:
	DB $05                              ;*; 0X00124D 00:124D 05 01 7E; dec B
	DB $01                              ;*; 0X00124E 00:124E 01 7E 7F; ld BC, $7F7E
	DB $7E,$7F,$7F,$7F,$7F                              ;*; 0X001253 00:1253 7F 05 01; ld A,A
D_1254:
	DB $05                              ;*; 0X001254 00:1254 05 01 7F; dec B
	DB $01                              ;*; 0X001255 00:1255 01 7F 7F; ld BC, $7F7F
	DB $7F,$7F,$7F,$7F,$7F                              ;*; 0X00125A 00:125A 7F 04 01; ld A,A
D_125B:
	DB $04                              ;*; 0X00125B 00:125B 04 01 7E; inc B
	DB $01                              ;*; 0X00125C 00:125C 01 7E 7E; ld BC, $7E7E
	DB $7E,$7E,$7E,$7E                              ;*; 0X001260 00:1260 7E 04 01; ld A,[HL]
D_1261:
	DB $04                              ;*; 0X001261 00:1261 04 01 7E; inc B
	DB $01                              ;*; 0X001262 00:1262 01 7E 7E; ld BC, $7E7E
	DB $7E,$7E,$7E,$7F                              ;*; 0X001266 00:1266 7F 04 01; ld A,A
D_1267:
	DB $04                                ; 0X001267 00:1267 04 01 7E; inc B
	DB $01                                ; 0X001268 00:1268 01 7E 7E; ld BC, $7E7E
	DB $7E,$7E,$7F,$7F                                ; 0X00126C 00:126C 7F 04 01; ld A,A
D_126D:
	DB $04                              ;*; 0X00126D 00:126D 04 01 7E; inc B
	DB $01                              ;*; 0X00126E 00:126E 01 7E 7F; ld BC, $7F7E
	DB $7E,$7F,$7F,$7F                              ;*; 0X001272 00:1272 7F 04 01; ld A,A
D_1273:
	DB $04                              ;*; 0X001273 00:1273 04 01 7F; inc B
	DB $01                              ;*; 0X001274 00:1274 01 7F 7F; ld BC, $7F7F
	DB $7F,$7F,$7F,$7F                              ;*; 0X001278 00:1278 7F 03 01; ld A,A
D_1279:
	DB $03                              ;*; 0X001279 00:1279 03 01 7E; inc BC
	DB $01                              ;*; 0X00127A 00:127A 01 7E 7E; ld BC, $7E7E
	DB $7E,$7E,$7E                              ;*; 0X00127D 00:127D 7E 03 01; ld A,[HL]
D_127E:
	DB $03                                ; 0X00127E 00:127E 03 01 7E; inc BC
	DB $01                                ; 0X00127F 00:127F 01 7E 7E; ld BC, $7E7E
	DB $7E,$7E,$7F                                ; 0X001282 00:1282 7F 03 01; ld A,A
D_1283:
	DB $03                              ;*; 0X001283 00:1283 03 01 7E; inc BC
	DB $01                              ;*; 0X001284 00:1284 01 7E 7F; ld BC, $7F7E
	DB $7E,$7F,$7F                              ;*; 0X001287 00:1287 7F 03 01; ld A,A
D_1288:
	DB $03                              ;*; 0X001288 00:1288 03 01 7F; inc BC
	DB $01                              ;*; 0X001289 00:1289 01 7F 7F; ld BC, $7F7F
	DB $7F,$7F,$7F                              ;*; 0X00128C 00:128C 7F 3E 9F; ld A,A
    
;*****************************************
;*    
;*****************************************
F_Addr_00128D:
	ld A,$9F                              ; 0X00128D 00:128D 3E 9F E0
	ldh [$FF96],A                     ; 0X00128F 00:128F E0 96 3E
	ld A,$C4;CF                              ; 0X001291 00:1291 3E CF E0
	ldh [$FF97],A                     ; 0X001293 00:1293 E0 97 FA
	ld A,[MEM_GLOBAL_LIFE] ;01:C912                 ; 0X001295 00:1295 FA 12 C9
	dec A                                 ; 0X001298 00:1298 3D C3 2F
	jp F_Addr_00072F ;01:072F               ; 0X001299 00:1299 C3 2F 07
    
;*****************************************
;* 
;*****************************************
F_Addr_00129C:
	ld A,[MEM_CURRENT_LEVEL] ;05:C900                 ; 0X00129C 00:129C FA 00 C9
	ld HL,Data_0_12A7                           ; 0X00129F 00:129F 21 A7 12
	rst $18                               ; 0X0012A2 00:12A2 DF EA 1B
	ld [$C91B],A ;05:C91B                 ; 0X0012A3 00:12A3 EA 1B C9
	ret                                   ; 0X0012A6 00:12A6 C9 29 1F
    
    
;*****************************************
;*    ?
;*****************************************
Data_0_12A7:
	DB 45 ; NIAGARA       ///// 
	DB 29 ; BERMUDA
    DB 45 ; EGYPT
    DB 40 ; MU
    DB 26 ; SCOTLAND 
    DB 47 ; UNDERGROUND 
    DB 0  ; LAST 
    
;*****************************************
;* 
;*****************************************
F_Addr_0012AE:
	push BC                               
	ld A,[$C901] ;01:C901                 
	ld B,A                                
	add A,A                               
	add A,A                               
	add A,B                               
	inc A                                 
	ld B,A                                
	ld A,[$C0A4] ;01:C0A4                 
	add A,B                               
	ld [$C901],A ;01:C901                 
	pop BC                                
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_0012C1:
	xor A                                 
	ldh [$FFA1],A                     
	ldh [$FFA0],A  
    
Addr_0012C6:
	ld L,A                                
	ld H,$C7   
	ld A,[HL]                             
	and $0F                               
	jr Z,Addr_00132D                      
	call F_Addr_0013F4 ;05:13F4             
	ld A,[$CA3F] ;05:CA3F                 
	and A                                 
	jr Z,Addr_0012E4                      
	ldh A,[$FFCA]                     
	and $0F                               
	cp $03                                
	jr C,Addr_0012E4                      
	call F_Addr_0013CC ;03:13CC             
	jr Addr_001315                        

Addr_0012E4:
	ld DE,Addr_00130F                           
	push DE                               
	ld HL,Data_0_12F2                           
	ldh A,[$FFCA]                     
	and $0F                               
	rst $20                               
	push DE                               
	ret                                   

;*****************************************
;* 
;*****************************************
Data_0_12F2:
	DW Addr_00130E                              
	DW Addr_001545                                
	DW Addr_001346                                
	DW Addr_001353                                
	DW Addr_00135D                                
	DW Addr_001367                                
	DW Addr_001367                                
	DW Addr_001371                                
	DW Addr_00137B                              
	DW Addr_001385                                
	DW Addr_001367                                
	DW Addr_001371                                
	DW Addr_00137B                                
	DW Addr_001385                                
    
;*****************************************
;* 
;*****************************************
Addr_00130E:
	ret                              
    
;*****************************************
;* 
;*****************************************
Addr_00130F:
	call F_Addr_0013C6 ;05:13C6             
	call F_Addr_00138F ;05:138F             
Addr_001315:
	call F_Addr_001436 ;05:1436             
	ldh A,[$FFCA]                     
	bit 7, A                              
	jr NZ,Addr_00132D                     
	and $0F                               
	jr Z,Addr_00132D                      
	ld A,BANK_12;//$01                              
	call SWITHBANK1 ;05:108F             
	call F_Addr_004EB2 ;01:4EB2             
	call F_Addr_00109B ;01:109B             
Addr_00132D:
	ld HL,$FFA1                           
	ld A,[HL]                             
	add A,$10                             
	ld [HL],A                             
	jr NC,Addr_0012C6      
    
;*****************************************
F_Addr_001336:
	ld H,$C0   ; $C000                           
	ldh A,[$FFA0]                     
	ld L,A                                
	ld B, $00                             
Addr_00133D:
	cp $A0                                
	ret NC                                
	ld [HL],B                             
	add A,$04                             
	ld L,A                                
	jr Addr_00133D                        
    
;*****************************************
;* 
;*****************************************
Addr_001346:
	ld A,BANK_12                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;01:2000                 
	jp Addr_00F402 ;03:10A3
    
;*****************************************
;* 
;*****************************************
Addr_001353:
	ld A,BANK_01                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;01:2000                 
	jp Addr_004BA1 ;01:4BA1               
    
;*****************************************
;* 
;*****************************************
Addr_00135D:
	ld A,BANK_01                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;01:2000                 
	jp Addr_001545 ;01:1545               
    
;*****************************************
;* 
;*****************************************
Addr_001367:
	ld A,BANK_01                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;03:2000                 
	jp Addr_004BA7 ;01:4BA7               
    
;*****************************************
;* 
;*****************************************
Addr_001371:
	ld A,BANK_01                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;03:2000                 
	jp Addr_004BC0 ;01:4BC0               
    
;*****************************************
;* 
;*****************************************
Addr_00137B:
	ld A,BANK_01                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;01:2000                 
	jp Addr_004BC6 ;01:4BC6               
    
;*****************************************
;* 
;*****************************************
Addr_001385:
	ld A,BANK_01                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;03:2000                 
	jp Addr_004BCC ;01:4BCC               
    
;*****************************************
;* 
;*****************************************
F_Addr_00138F:
	ld HL,$FFDD                           
	bit 0, [HL]                           
	ret Z                                 
	ld HL,$FFCE                           
	ld A,[HL-]                            
	and A                                 
	jr Z,Addr_0013A9                      
	cp $FF                                
	jp NZ,Func00_00158C ;01:158C            
	ld A,[HL-]                            
	cp $D0                                
	jp C,Func00_00158C ;01:158C             
	jr Addr_0013AF                        
Addr_0013A9:
	ld A,[HL-]                            
	cp $C8                                
	jp NC,Func00_00158C ;01:158C            
Addr_0013AF:
	ld A,[HL-]                            
	and A                                 
	jr Z,Addr_0013BF                      
	cp $FF                                
	jp NZ,Func00_00158C ;01:158C            
	ld A,[HL]                             
	cp $E0                                
	jp C,Func00_00158C ;01:158C             
	ret                                   
    
Addr_0013BF:
	ld A,[HL]                             
	cp $A0                                
	jp NC,Func00_00158C ;01:158C            
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_0013C6:
	ld HL,$FFDD                           
	bit 1, [HL]                           
	ret Z                                 
F_Addr_0013CC:
	ld HL,$FFCA                           
	ld A,[HL+]                            
	and $0F                               
	ret Z                                 
	ld C,$00                              
	ldh A,[$FFB8]                     
	bit 7, A                              
	jr Z,Addr_0013DC                      
	dec C                                 
Addr_0013DC:
	ld B,A                                
	ld A,[HL]                             
	sub B                                 
	ld [HL+],A                            
	ld A,[HL]                             
	sbc A,C                               
	ld [HL+],A                            
	ld C,$00                              
	ldh A,[$FFB9]                     
	bit 7, A                              
	jr Z,Addr_0013EC                      
	dec C                                 
Addr_0013EC:
	ld B,A                                
	ld A,[HL]                             
	sub B                                 
	ld [HL+],A                            
	ld A,[HL]                             
	sbc A,C                               
	ld [HL+],A                            
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_0013F4:
	ld H,$C6                              
	ld E,L                                
	ld C,$BA                              
	call F_Addr_001405 ;05:1405             
	inc H                                 
	ld L,E                                
	call F_Addr_001405 ;05:1405             
	inc H                                 
	ld L,E                                
	jr Addr_001414                        
    
;*****************************************
;* 
;*****************************************
F_Addr_001405:
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
Addr_001414:
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[HL+]                            
	ld [$FF00+C],A                        
	inc C                                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_001436:
	ld H,$C6                              
	ldh A,[$FFA1]                     
	ld L,A                                
	ld E,A                                
	ld C,$BA                              
	call F_Addr_00144A ;05:144A             
	inc H                                 
	ld L,E                                
	call F_Addr_00144A ;05:144A             
	inc H                                 
	ld L,E                                
	jr Addr_001459                        
;*****************************************
;* 
;*****************************************
F_Addr_00144A:
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
Addr_001459:
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ld A,[$FF00+C]                        
	ld [HL+],A                            
	inc C                                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_00147B:
	ld HL,$FFA8                           
	xor A                                 
	ld [HL+],A                            
	ld [HL+],A                            
	ld [HL+],A                            
	ld [HL+],A                            
	ld [HL+],A                            
	ld [HL+],A                            
	jr F_Addr_00149B    
    
Addr_001487:
	ld HL,$FFA8                           
	ldh A,[$FFCB]                     
	ld [HL+],A                            
	ldh A,[$FFCC]                     
	ld [HL+],A                            
	ldh A,[$FFCD]                     
	ld [HL+],A                            
	ldh A,[$FFCE]                     
	ld [HL+],A                            
	ldh A,[$FFD1]                     
	ld [HL+],A                            
	xor A                                 
	ld [HL+],A                            
;*****************************************
F_Addr_00149B:
	call Addr_01BA0C 
    ret              
    
;*****************************************
;* 
;*****************************************
Addr_01BA0C:
	call F_Addr_01BA51 ;06:7A51
	jr C,Addr_01BA50
	ld C,L
	ld H,$C6
	ld [HL],E
	inc HL
	ld [HL],D
	inc HL
	xor A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ld L,C
	inc H
	ld A,B
	or $80
	ld [HL+],A
	ldh A,[$FFA8]
	ld [HL+],A
	ldh A,[$FFA9]
	ld [HL+],A
	ldh A,[$FFAA]
	ld [HL+],A
	ldh A,[$FFAB]
	ld [HL+],A
	xor A
	ld [HL+],A
	ld [HL+],A
	ldh A,[$FFAC]
	ld [HL+],A
	xor A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ld L,C
	ld H,$C8
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	ldh A,[$FFAD]
	ld [HL+],A
	xor A
	ld [HL+],A
	ld [HL+],A
	ld [HL+],A
	and A
Addr_01BA50:
	ret	

;*****************************************
;* 
;*****************************************
F_Addr_01BA51:
	ld HL,$C710
	ld A,B
	and $0F
	cp $03
	jr NC,Addr_01BA5E
	ld HL,$C700
Addr_01BA5E:
	ld A,[HL]
	and $0F
	jr NZ,Addr_01BA68
	ld A,L
	ld [$C0A8],A
	ret
Addr_01BA68:
	ld A,L
	add A,$10
	ld L,A
	jr NC,Addr_01BA5E
	scf
	ret
    
;*****************************************
;* 
;*****************************************
F_Addr_0014A9:
	push AF                               
	pop BC                                
	ld A,C                                
	ldh [$FFBD],A                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
Data_0_14AF:
	DW Func00_00158C  ;00                              ; 0X0014AF 00:14AF 8C 15 91; adc A,H
	DW Func01_001591  ;01                              ; 0X0014B1 00:14B1 91 15 94; sub C
	DW Func02_delay  ;02                             ; 0X0014B3 00:14B3 94 15 C3; sub H
	DW Func03_0015C3  ;03                              ; 0X0014B5 00:14B5 C3 15 DB; jp Addr_00DB15 ;00:DB15
	DW Func04_State  ;04                              ; 0X0014B7 00:14B7 DB 15 9A;
	DW Func05_00159A  ;05                             ; 0X0014B9 00:14B9 9A 15 CC; sbc A,D
	DW Func06_0015CC  ;06                             ; 0X0014BB 00:14BB CC 15 E2; call Z,Addr_00E215 ;00:E215
	DW Func07_0015E2  ;07                             ; 0X0014BD 00:14BD E2 15 EB; ld [$FF00+C],A
	DW Func08_0015EB  ;08                             ; 0X0014BF 00:14BF EB 15 FF;
	DW Func09_0015FF  ;09                             ; 0X0014C1 00:14C1 FF 15 0D; rst $38
	DW Func0A_00160D  ;0A                             ; 0X0014C3 00:14C3 0D 16 18; dec C
	DW Func0B_001618  ;0B                             ; 0X0014C5 00:14C5 18 16 1E; jr FUNC_0014DD
	DW Func0C_00161E  ;0C                             ; 0X0014C7 00:14C7 1E 16 24; ld E,$16
	DW Func0D_001624  ;0D                             ; 0X0014C9 00:14C9 24 16 29; inc H
	DW Func0E_001629  ;0E                             ; 0X0014CB 00:14CB 29 16 38; add HL,HL
	DW Func0F_001638  ;0F                             ; 0X0014CD 00:14CD 38 16 42; jr C,FUNC_0014E5
	DW Func10_001642  ;10                             ; 0X0014CF 00:14CF 42 16 51; ld B,D
	DW Func11_001651  ;11                             ; 0X0014D1 00:14D1 51 16 5F; ld D,C
	DW Func12_00165F  ;12                             ; 0X0014D3 00:14D3 5F 16 74; ld E,A
	DW Func13_001674  ;13                             ; 0X0014D5 00:14D5 74 16 7D; ld [HL],H
	DW Func14_00167D  ;14                             ; 0X0014D7 00:14D7 7D 16 91; ld A,L
	DW Func15_001691  ;15                           ;*; 0X0014D9 00:14D9 91 16 91; sub C
	DW Func16_001691  ;16                             ; 0X0014DB 00:14DB 91 16 9A; sub C
	DW Func17_00169A  ;17                             ; 0X0014DD 00:14DD 9A 16 A5; sbc A,D
	DW Func18_0016A5  ;18                             ; 0X0014DF 00:14DF A5 16 F1; and L
	DW Func19_0016F1  ;19                           ;*; 0X0014E1 00:14E1 F1 16 F1; pop AF
	DW Func1A_0016F1  ;1A                             ; 0X0014E3 00:14E3 F1 16 FA; pop AF
	DW Func1B_0016FA  ;1B                             ; 0X0014E5 00:14E5 FA 16 03; ld A,[$0316] ;00:0316
	DW Func1C_001703  ;1C                           ;*; 0X0014E7 00:14E7 03 17 03; inc BC
	DW Func1D_001703  ;1D                           ;*; 0X0014E9 00:14E9 03 17 03; inc BC
	DW Func1E_001703  ;1E                             ; 0X0014EB 00:14EB 03 17 09; inc BC
	DW Func1F_001709  ;1F                             ; 0X0014ED 00:14ED 09 17 0F; add HL,BC
	DW Func20_00170F  ;20                           ;*; 0X0014EF 00:14EF 0F 17 1A; RRCA
	DW Func21_00171A  ;21                             ; 0X0014F1 00:14F1 1A 17 23; ld A,[DE]
	DW Func22_001723  ;22                             ; 0X0014F3 00:14F3 23 17 2C; inc HL
	DW Func23_00172C  ;23                           ;*; 0X0014F5 00:14F5 2C 17 35; inc L
	DW Func24_001735  ;24                           ;*; 0X0014F7 00:14F7 35 17 3E; dec [HL]
	DW Func25_00173E  ;25                             ; 0X0014F9 00:14F9 3E 17 47; ld A,$17
	DW Func26_001747  ;26                             ; 0X0014FB 00:14FB 47 17 50; ld B,A
	DW Func27_001750  ;27                             ; 0X0014FD 00:14FD 50 17 59; ld D,B
	DW Func28_001759  ;28                             ; 0X0014FF 00:14FF 59 17 62; ld E,C
	DW Func29_001762  ;29                             ; 0X001501 00:1501 62 17 66; ld H,D
	DW Func2A_001766  ;2A                             ; 0X001503 00:1503 66 17 7B; ld H,[HL]
	DW Func2B_00177B  ;2B                             ; 0X001505 00:1505 7B 17 81; ld A,E
	DW Func2C_001781  ;2C                             ; 0X001507 00:1507 81 17 87; add A,C
	DW Func2D_001787  ;2D                           ;*; 0X001509 00:1509 87 17 8F; add A,A
	DW Func2E_00178F  ;2E                             ; 0X00150B 00:150B 8F 17 97; adc A,A
	DW Func2F_001797  ;2F                           ;*; 0X00150D 00:150D 97 17 9F; sub A
	DW Func30_00179F  ;30                             ; 0X00150F 00:150F 9F 17 A7; sbc A,A
	DW Func31_0017A7  ;31                           ;*; 0X001511 00:1511 A7 17 A7; and A
	DW Func32_0017A7  ;32                           ;*; 0X001513 00:1513 A7 17 A7; and A
	DW Func33_0017A7  ;33                           ;*; 0X001515 00:1515 A7 17 A7; and A
	DW Func34_0017A7  ;34                             ; 0X001517 00:1517 A7 17 B0; and A
	DW Func35_0017B0  ;35                           ;*; 0X001519 00:1519 B0 17 B0; or B
	DW Func36_0017B0  ;36                             ; 0X00151B 00:151B B0 17 C4; or B
	DW Func37_0017C4  ;37                             ; 0X00151D 00:151D C4 17 D6; call NZ,FUNC_00D617 ;00:D617
	DW Func38_0017D6  ;38                           ;*; 0X00151F 00:151F D6 17 E3; sub $17
	DW Func39_Draw  ;39                             ; 0X001521 00:1521 E3 17 F3;
	DW Func3A_0017F3  ;3A                           ;*; 0X001523 00:1523 F3 17 07; di
	DW Func3B_001807  ;3B                             ; 0X001525 00:1525 07 18 14; RLCA
	DW Func3C_001814  ;3C                           ;*; 0X001527 00:1527 14 18 1A; inc D
	DW Func3D_00181A  ;3D                           ;*; 0X001529 00:1529 1A 18 23; ld A,[DE]
	DW Func3E_001823  ;3E                             ; 0X00152B 00:152B 23 18 2C; inc HL
	DW Func3F_00182C  ;3F                           ;*; 0X00152D 00:152D 2C 18 2C; inc L
	DW Func40_00182C  ;40                           ;*; 0X00152F 00:152F 2C 18 3B; inc L
	DW Func41_00183B  ;41                           ;*; 0X001531 00:1531 3B 18 4A; dec SP
	DW Func42_00184A  ;42                           ;*; 0X001533 00:1533 4A 18 57; ld C,D
	DW Func43_001857  ;43                           ;*; 0X001535 00:1535 57 18 64; ld D,A
	DW Func44_001864  ;44                           ;*; 0X001537 00:1537 64 18 74; ld H,H
	DW Func45_001874  ;45                           ;*; 0X001539 00:1539 74 18 7D; ld [HL],H
	DW Func46_00187D  ;46                           ;*; 0X00153B 00:153B 7D 18 88; ld A,L
	DW Func47_001888  ;47                           ;*; 0X00153D 00:153D 88 18 98; adc A,B
	DW Func48_001898  ;48                             ; 0X00153F 00:153F 98 18 A0; sbc A,B
	DW Func49_0018A0  ;49                           ;*; 0X001541 00:1541 A0 18 AF; and B
	DW Func4A_0018AF  ;4A                             ; 0X001543 00:1543 AF 18 FA; xor A
	DW Func4B_DrawAttrb;4B                             ; 0X001543 00:1543 AF 18 FA; xor A
	DW Func4C_ClearScreen;4C                             ; 0X001543 00:1543 AF 18 FA; xor A
    
    
    
    
    

;*****************************************
;* 
;*****************************************
Addr_001545:
	ld A,[$C0A1] ;05:C0A1                 
	and A                                 
	ret NZ                                
	dec A                                 
	ld HL,MEM_DELAY                           
	and [HL]                              
	jr Z,Addr_001553                      
	dec [HL]                              
	ret                                   
    
Addr_001553:
	ldh A,[$FFBA]                     
	ld L,A                                
	ldh A,[$FFBB]                     
	ld H,A                                
Addr_001559:
	ld A,[HL+]                            
	sla A                                 
	ld DE,Data_0_14AF                           
	add A,E                               
	ld E,A                                
	jr NC,Addr_001564                     
	inc D                                 
Addr_001564:
	ld A,[DE]                             
	ld C,A                                
	inc DE                                
	ld A,[DE]                             
	ld B,A                                
	push BC                               
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_00156B:
	ld A,L                                
	ldh [$FFBA],A                     
	ld A,H                                
	ldh [$FFBB],A                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_001572:
	ld DE,$FFC3                           
	ldh A,[$FFC2]                     
	add A,E                               
	ld E,A                                
	ret NC                                
	inc D                              
	ret                             
    
;*****************************************
;* 
;*****************************************
F_Addr_00157C:
	ld [DE],A                             
	inc DE                                
	ldh A,[$FFC2]                     
	inc A                                 
	ldh [$FFC2],A                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_001584:
	ldh A,[$FFC2]                     
	dec A                                 
	ldh [$FFC2],A                     
	dec DE                                
	ld A,[DE]                             
	ret                                   
    
;*****************************************
;* 
;*****************************************
Func00_00158C:
	ld A,$80                              
	ldh [$FFCA],A                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
Func01_001591:
	jp F_Addr_00156B ;05:156B               
    
;*****************************************
;* delay
;*****************************************
Func02_delay:
	ld A,[HL+]                            
	ldh [MEM_DELAY],A                     
	jp F_Addr_00156B ;05:156B               
    
;*****************************************
;* 
;*****************************************
Func05_00159A:
	ld A,[HL+]                            
	ld B,A                                
	ld A,[HL+]                            
	ld E,A                                
	ld A,[HL+]                            
	ld D,A                                
	push HL                               
	ld HL,$FFCB                           
	ld A,[HL+]                            
	ldh [$FFA8],A                     
	ld A,[HL+]                            
	ldh [$FFA9],A                     
	ld A,[HL+]                            
	ldh [$FFAA],A                     
	ld A,[HL+]                            
	ldh [$FFAB],A                     
	ldh A,[$FFD1]                     
	and $20                               
	ldh [$FFAC],A                     
	xor A                                 
	ldh [$FFAD],A                     
	call F_Addr_00149B ;05:149B             
	call F_Addr_0014A9 ;05:14A9             
	pop HL                                
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func03_0015C3:
	ld A,[HL+]                            
	ld E,A                                
	ld A,[HL+]                            
	ld D,A                                
	call F_Addr_00156B ;05:156B             
	push DE                               
	ret                                   
    
;*****************************************
;* 
;*****************************************
Func06_0015CC:
	ld A,[HL+]                            
	ld E,A                                
	ld A,[HL+]                            
	push HL                               
	ld H,A                                
	ld L,E                                
	ld BC, Addr_0015D7                          
	push BC                               
	jp [HL]                               
Addr_0015D7:
	pop HL                                
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func04_State:
	ld A,[HL+]                            
	ld [STATEGAME],A ;01:C0A0                 
	jp Addr_0008EE ;01:08EE               
    
;*****************************************
;* 
;*****************************************
Func07_0015E2:
	ld A,[HL+]                            
	ldh [$FFBA],A                     
	ld A,[HL+]                            
	ldh [$FFBB],A                     
	jp Addr_001553 ;05:1553               
    
;*****************************************
;* 
;*****************************************
Func08_0015EB:
	ld A,[HL+]                            
	ldh [$FFBA],A                     
	ld A,[HL+]                            
	ldh [$FFBB],A                     
	call F_Addr_001572 ;05:1572             
	ld A,H                                
	call F_Addr_00157C ;05:157C             
	ld A,L                                
	call F_Addr_00157C ;05:157C             
	jp Addr_001553 ;05:1553               
    
;*****************************************
;* 
;*****************************************
Func09_0015FF:
	call F_Addr_001572 ;05:1572             
	call F_Addr_001584 ;05:1584             
	ld L,A                                
	call F_Addr_001584 ;05:1584             
	ld H,A                                
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func0A_00160D:
	call F_Addr_001572 ;01:1572             
	ldh A,[$FFC2]                     
	dec A                                 
	dec A                                 
	ldh [$FFC2],A                     
	jr Func07_0015E2                        
    
;*****************************************
;* 
;*****************************************
Func0B_001618:
	xor A                                 
	ldh [$FFC0],A                     
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func0C_00161E:
	xor A                                 
	ldh [$FFC1],A                     
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func0D_001624:
	ld BC, $FFC0                          
	jr Addr_00162C                        
    
;*****************************************
;* 
;*****************************************
Func0E_001629:
	ld BC, $FFC1                          
Addr_00162C:
	ld A,[BC]                             
	inc A                                 
	ld [BC],A                             
	cp [HL]                               
	inc HL                                
	jp C,Func07_0015E2 ;05:15E2             
	xor A                                 
	ld [BC],A                             
	jr Addr_00164C                        
    
;*****************************************
;* 
;*****************************************
Func0F_001638:
	ldh A,[$FFBD]                     
	ld C,A                                
	push BC                               
	pop AF                                
	jr Z,Addr_00164C                      
	jp Func07_0015E2 ;05:15E2               
    
;*****************************************
;* 
;*****************************************
Func10_001642:
	ldh A,[$FFBD]                     
	ld C,A                                
	push BC                               
	pop AF                                
	jr C,Addr_00164C                      
	jp Func07_0015E2 ;01:15E2               
	
Addr_00164C:
	inc HL                                
	inc HL                                
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func11_001651:
	ld C,$92                              
	ld A,[HL+]                            
	add A,C                               
	ld C,A                                
	ld A,[HL+]                            
	ld B,A                                
	ld A,[$FF00+C]                        
	and B                                 
	jr NZ,Addr_00164C                     
	jp Func07_0015E2 ;05:15E2               
    
;*****************************************
;* 
;*****************************************
Func12_00165F:
	ld A,[HL+]                            
	ld E,A                                
	ld A,[HL+]                            
	ld D,A                                
	ld A,[DE]                             
	sla A                                 
	add A,L                               
	ld E,A                                
	ld A,H                                
	adc A,$00                             
	ld D,A                                
	ld A,[DE]                             
	ld L,A                                
	inc DE                                
	ld A,[DE]                             
	ld H,A                                
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func13_001674:
	ld A,[HL+]                            
	ldh [$FFBE],A                     
	ld A,[HL+]                            
	ldh [$FFBF],A                     
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func14_00167D:
	ld A,[HL+]                            
	ld C,A                                
	ld A,[HL+]                            
	ld B,A                                
	ld A,[HL+]                            
	ld E,A                                
	ld A,[HL+]                            
	ld D,A                                
	ld A,C                                
Addr_001686:
	ld [DE],A                             
	inc DE                                
	dec B                                 
	jr NZ,Addr_001686                     
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
	jp Addr_001559 ;00:1559             
    
;*****************************************
;* 
;*****************************************
Func15_001691:
Func16_001691:
	ld A,[HL+]                            
	push HL                               
	call F_Addr_0002E7 ;05:02E7             
	pop HL                                
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func17_00169A:
	push HL                               
	call F_Addr_0016BA ;01:16BA             
	call F_Addr_0016B0 ;01:16B0             
	pop HL                                
	jp F_Addr_00156B ;01:156B               
    
;*****************************************
;* 
;*****************************************
Func18_0016A5:
	push HL                               
	call F_Addr_0016BA ;01:16BA             
	call F_Addr_0016B0 ;01:16B0             
	pop HL                                
	jp Addr_001559 ;01:1559               
    
F_Addr_0016B0:
	ld DE,$FFD4                           
	ld HL,$FFCB                           
	ldh A,[$FFD2]                     
	jr Addr_0016C2                        
    
F_Addr_0016BA:
	ld DE,$FFD5                           
	ld HL,$FFCD                           
	ldh A,[$FFD3]                     
Addr_0016C2:
	and A                                 
	ret Z                                 
	bit 7, A                              
	jr NZ,Addr_0016D2                     
	call F_Addr_0016DF ;03:16DF             
	add A,[HL]                            
	ld [HL+],A                            
	ld A,[HL]                             
	adc A,$00                             
	ld [HL],A                             
	ret                                   
    
Addr_0016D2:
	cpl                                   
	inc A                                 
	call F_Addr_0016DF ;03:16DF             
	ld A,[HL]                             
	sub B                                 
	ld [HL+],A                            
	ld A,[HL]                             
	sbc A,$00                             
	ld [HL],A                             
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_0016DF:
	swap A                                
	ld C,A                                
	and $07                               
	ld B,A                                
	ld A,C                                
	and $F0                               
	ld C,A                                
	ld A,[DE]                             
	add A,C                               
	ld [DE],A                             
	ld A,B                                
	adc A,$00                             
	ld B,A                                
	ret                                   
    
;*****************************************
;* 
;*****************************************
Func19_0016F1:
Func1A_0016F1:
	ld C,$CA                              
	ld A,[$FF00+C]                        
	res 7, A                              
	ld [$FF00+C],A                        
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func1B_0016FA:
	ld C,$CA                              
	ld A,[$FF00+C]                        
	set 7, A                              
	ld [$FF00+C],A                        
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func1E_001703:
Func1D_001703:
Func1C_001703:
	ld A,[HL+]                            
	ldh [$FFCF],A                     
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func1F_001709:
	ld A,[HL+]                            
	ldh [$FFD0],A                     
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func20_00170F:
	ld C,$D1                             
	ld A,[$FF00+C]                             
	res 4, A                             
	or [HL]                             
	ld [$FF00+C],A                             
	inc HL                             
	jp Addr_001559 ;00:1559                             
    
;*****************************************
;* 
;*****************************************
Func21_00171A:
	ld C,$D1                              
	ld A,[$FF00+C]                        
	res 5, A                              
	ld [$FF00+C],A                        
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func22_001723:
	ld C,$D1                              
	ld A,[$FF00+C]                        
	set 5, A                              
	ld [$FF00+C],A                        
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func23_00172C:
	ld C,$D1                             
	ld A,[$FF00+C]                             
	res 6, A                             
	ld [$FF00+C],A                             
	jp Addr_001559 ;00:1559                             
    
;*****************************************
;* 
;*****************************************
Func24_001735:
	ld C,$D1                             
	ld A,[$FF00+C]                             
	set 6, A                             
	ld [$FF00+C],A                             
	jp Addr_001559 ;00:1559                             
    
;*****************************************
;* 
;*****************************************
Func25_00173E:
	ld C,$D1                              
	ld A,[$FF00+C]                        
	res 7, A                              
	ld [$FF00+C],A                        
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func26_001747:
	ld C,$D1                              
	ld A,[$FF00+C]                        
	set 7, A                              
	ld [$FF00+C],A                        
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func27_001750:
	ld A,[HL+]                            
	ldh [$FFCD],A                     
	ld A,[HL+]                            
	ldh [$FFCE],A                     
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func28_001759:
	ld A,[HL+]                            
	ldh [$FFCB],A                     
	ld A,[HL+]                            
	ldh [$FFCC],A                     
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func29_001762:
	ld C,$CD                              
	jr Addr_001768                        
    
;*****************************************
;* 
;*****************************************
Func2A_001766:
	ld C,$CB                              
Addr_001768:
	ld B, $00                             
	ld A,[HL]                             
	bit 7, A                              
	jr Z,Addr_001770                      
	dec B                                 
Addr_001770:
	ld A,[$FF00+C]                        
	add A,[HL]                            
	ld [$FF00+C],A                        
	inc C                                 
	ld A,[$FF00+C]                        
	adc A,B                               
	ld [$FF00+C],A                        
	inc HL                                
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func2B_00177B:
	ld A,[HL+]                            
	ldh [$FFD3],A                     
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func2C_001781:
	ld A,[HL+]                            
	ldh [$FFD2],A                     
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func2D_001787:
	ldh A,[$FFD3]                             
	inc A                             
	ldh [$FFD3],A                             
	jp Addr_001559 ;00:1559                             
    
;*****************************************
;* 
;*****************************************
Func2E_00178F:
	ldh A,[$FFD2]                     
	inc A                                 
	ldh [$FFD2],A                     
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func2F_001797:
	ldh A,[$FFD3]                             
	dec A                             
	ldh [$FFD3],A                             
	jp Addr_001559 ;00:1559                             
    
;*****************************************
;* 
;*****************************************
Func30_00179F:
	ldh A,[$FFD2]                     
	dec A                                 
	ldh [$FFD2],A                     
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func34_0017A7:
Func33_0017A7:
Func32_0017A7:
Func31_0017A7:
	ld A,[HL+]                            
	ldh [$FFDB],A                     
	ld A,[HL+]                            
	ldh [$FFDA],A                     
	jp Addr_001559 ;01:1559               
    
;*****************************************
;* 
;*****************************************
Func36_0017B0:
Func35_0017B0:
	ld A,[HL+]                            
	ldh [$FFDE],A                     
	jp Addr_001559 ;01:1559 
    
;*****************************************
;* 
;*****************************************
F_Addr_0017B6:
	ld A,[HL+]                            
	ldh [$FF97],A                     
	ld A,[HL+]                            
	or $98                                
	ldh [$FF96],A                     
	ret 
    
;*****************************************
;* 
;*****************************************
F_Addr_0017BF:
	ld A,[HL+]                            
	ld E,A                                
	ld A,[HL+]                            
	ld D,A                                
	ret                                   
    
;*****************************************
;* 
;*****************************************
Func37_0017C4:
	ld A,[HL+]                            
	ld B,A                                
	call F_Addr_0017B6 ;05:17B6             
	call F_Addr_0017BF ;05:17BF             
	push HL                               
	ld L,E                                
	ld H,D                                
	call F_Addr_000466 ;05:0466             
	pop HL                                
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func38_0017D6:
	call F_Addr_0017BF ;00:17BF                             
	push HL                             
	ld L,E                             
	ld H,D                             
	call F_Addr_000457 ;00:0457                             
	pop HL                             
	jp Addr_001559 ;00:1559                             
    
;*****************************************
;* 
;*****************************************
Func39_Draw:
	call F_Addr_0017B6 ;05:17B6             
	call F_Addr_0017BF ;05:17BF             
	push HL                               
	ld H,D                                
	ld L,E                                
	call F_Addr_0004D6 ;05:04D6             
	pop HL                                
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func3A_0017F3:
	ld A,[HL+]                             
	ld B,A                             
	ld A,[HL+]                             
	ld C,A                             
	call F_Addr_0017B6 ;00:17B6                             
	call F_Addr_0017BF ;00:17BF                             
	push HL                             
	ld L,E                             
	ld H,D                             
	call F_Addr_000535 ;00:0535                             
	pop HL                             
	jp Addr_001559 ;00:1559                             
    
;*****************************************
;* 
;*****************************************
Func3B_001807:
	call F_Addr_0017BF ;05:17BF             
	push HL                               
	ld H,D                                
	ld L,E                                
	call F_Addr_0007C5 ;05:07C5             
	pop HL                                
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func3C_001814:
	call F_Addr_0014A9 ;05:14A9             
	jp Addr_001559 ;05:1559               
    
;*****************************************
;* 
;*****************************************
Func3D_00181A:
	ld A,[HL+]                             
	ld B,A                             
	push HL                             
	call F_Addr_000781 ;00:0781                             
	pop HL                             
	jr Func3C_001814                             
    
;*****************************************
;* 
;*****************************************
Func3E_001823:
	ld A,[HL+]                            
	ld B,A                                
	push HL                               
	call F_Addr_0007A3 ;05:07A3             
	pop HL                                
	jr Func3C_001814                        
    
;*****************************************
;* 
;*****************************************
Func40_00182C:
Func3F_00182C:
	call F_Addr_0017BF ;00:17BF                             
	ld A,[HL+]                             
	ld C,A                             
	ld A,[HL+]                             
	push HL                             
	ld H,A                             
	ld L,C                             
	call F_Addr_000697 ;00:0697                             
	pop HL                             
	jr Func3C_001814                             
    
;*****************************************
;* 
;*****************************************
Func41_00183B:
	call F_Addr_0017BF ;00:17BF                             
	ld A,[HL+]                             
	ld C,A                             
	ld A,[HL+]                             
	push HL                             
	ld H,A                             
	ld L,C                             
	call F_Addr_0006B1 ;00:06B1                             
	pop HL                             
	jr Func3C_001814                             
    
;*****************************************
;* 
;*****************************************
Func42_00184A:
	ld A,[HL+]                             
	ld B,A                             
	call F_Addr_0017B6 ;00:17B6                             
	push HL                             
	call F_Addr_00072F ;00:072F                             
	pop HL                             
	jp Addr_001559 ;00:1559                             
    
;*****************************************
;* 
;*****************************************
Func43_001857:
	ld A,[HL+]                             
	ld B,A                             
	call F_Addr_0017B6 ;00:17B6                             
	push HL                             
	call F_Addr_000747 ;00:0747                             
	pop HL                             
	jp Addr_001559 ;00:1559                             
    
;*****************************************
;* 
;*****************************************
Func44_001864:
	ld A,[HL+]                             
	ld B,A                             
	call F_Addr_0017B6 ;00:17B6                             
	call F_Addr_0017BF ;00:17BF                             
	push HL                             
	call F_Addr_0006CA ;00:06CA                             
	pop HL                             
	jp Addr_001559 ;00:1559                             
    
;*****************************************
;* 
;*****************************************
Func45_001874:
	ld A,[HL+]                             
	add A,$47                             
	ld C,A                             
	ld A,[HL+]                             
	ld [$FF00+C],A                             
	jp Addr_001559 ;00:1559                             
    
;*****************************************
;* 
;*****************************************
Func46_00187D:
	ld A,[HL+]                             
	ld [$C5A1],A ;00:C5A1                             
	ld A,[HL+]                             
	ld [$C5A2],A ;00:C5A2                             
	jp Addr_001559 ;00:1559                             
    
;*****************************************
;* 
;*****************************************
Func47_001888:
	ld A,[HL+]                             
	ld C,A                             
	call F_Addr_0017B6 ;00:17B6                             
	call F_Addr_0017BF ;00:17BF                             
	push HL                             
	call F_Addr_00081B ;00:081B                             
	pop HL                             
	jp F_Addr_00156B ;00:156B                             
    
;*****************************************
;* 
;*****************************************
Func48_001898:
	ld A,[$C5A9] ;05:C5A9                 
	cp $FF                                
	jr Z,Addr_0018AC                      
	ret                                   
    
;*****************************************
;* 
;*****************************************
Func49_0018A0:
	ld A,[$C5A9] ;00:C5A9                             
	cp $FF                             
	jr Z,Addr_0018AA                             
	jp Func07_0015E2 ;00:15E2                             
Addr_0018AA:
	inc HL                             
	inc HL                             
Addr_0018AC:
	jp F_Addr_00156B ;05:156B               
    
;*****************************************
;* 
;*****************************************
Func4A_0018AF:
	ld A,[HL+]                            
	ld [$C934],A ;05:C934                 
	ld A,[HL+]                            
	ld [$C935],A ;05:C935                 
	push HL                               
	ld A,BANK_05                              
	call SWITHBANK1 ;05:108F             
	;ld HL,Data_5_4018 ?????                          
	call PrintDialog;GOTOHL ;05:10A3             
	call F_Addr_00109B ;05:109B             
	pop HL                                
	jp F_Addr_00156B ;05:156B               
    
;*****************************************
;* 
;*****************************************
F_Addr_001913:
	push BC                               
	ld DE,$0000                           
	ld HL,$0000                           
	ld A,[$CA0F] ;03:CA0F                 
	SRL A                                 
	jr NC,Addr_001924                     
	ld DE,$009F                           
Addr_001924:
	SRL A                                 
	jr NC,Addr_00192B                     
	ld HL,$007F                           
Addr_00192B:
	ld A,[$CA4D] ;03:CA4D                 
	add A,E                               
	ld E,A                                
	ld A,[$CA4E] ;03:CA4E                 
	adc A,D                               
	ld D,A                                
	ld A,[LVLPOS_YL] ;03:C0A9                 
	add A,L                               
	ld L,A                                
	ld A,[LVLPOS_YH] ;03:C0AA                 
	adc A,H                               
	ld H,A                                
	call F_Addr_001B2D ;03:1B2D             
	ld HL,MEM_C280                           
	add HL,BC                             
	ld A,[HL]                             
	ld [$CA3A],A ;03:CA3A                 
	pop BC                                
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_00194C:
	call F_Addr_0019C1 ;01:19C1             
	call F_Addr_001966 ;01:1966             
	ld A,[$C9DC] ;01:C9DC                 
	and A                                 
	ret NZ                                
F_Addr_001957:
	ld A,[LVLPOS_XL] ;01:C0AB                 
	ld [MEM_CA52],A ;01:D549                 
	ld A,[LVLPOS_YL] ;01:C0A9                 
	sub $10                               
	ld [MEM_WINDOW_Y],A ;01:D592                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_001966:
	ldh A,[$FFB9]                     
	and A                                 
	ret Z                                 
	ld C,A                                
	xor A                                 
	ldh [$FFB9],A                     
	ld DE,$00C0                           
	ld A,[$CA0F] ;01:CA0F                 
	bit 0, A                              
	jr Z,Addr_00197B                      
	ld DE,$FFD8                           
Addr_00197B:
	ld B,D                                
	ld HL,LVLPOS_XL                           
	ld A,[HL]                             
	ldh [$FFA6],A                     
	add A,C                               
	ld [HL+],A                            
	ld C,A                                
	ld A,[HL]                             
	adc A,B                               
	bit 7, A                              
	jr Z,Addr_00198E                      
	xor A                             
	ld [HL-],A                             
	ld C,A                             
Addr_00198E:
	ld [HL],A                             
	ld H,A                                
	ld L,C                                
	ldh A,[$FFA6]                     
	xor L                                 
	bit 3, A                              
	ret Z                                 
	ld B,L                                
	ld A,[LVLPOS_XL] ;01:C0AB                 
	add A,E                               
	ld E,A                                
	ld [$CA47],A ;01:CA47                 
	ld A,[LVLPOS_XH] ;01:C0AC                 
	adc A,D                               
	ld D,A                                
	ld [$CA48],A ;01:CA48                 
	ld A,[LVLPOS_YL] ;01:C0A9                 
	ld L,A                                
	ld [$CA49],A ;01:CA49                 
	ld A,[LVLPOS_YH] ;01:C0AA                 
	ld H,A                                
	ld [$CA4A],A ;01:CA4A                 
	ldh A,[$FFA6]                     
	xor B                                 
	bit 4, A                              
	jp Z,F_Addr_001C07 ;01:1C07             
	jp F_Addr_001A65 ;01:1A65               
    
;*****************************************
;* 
;*****************************************
F_Addr_0019C1:
	ldh A,[$FFB8]                     
	and A                                 
	ret Z                                 
	xor A                                 
	ldh [$FFB9],A                     
	call F_Addr_001957 ;03:1957             
	ld B, $00                             
	ld C,$80                              
	ld A,[$CA0F] ;03:CA0F                 
	bit 1, A                              
	jr Z,Addr_0019D8                      
	ld B, $FF                             
Addr_0019D8:
	ld A,[LVLPOS_YL] ;03:C0A9                 
	ld L,A                                
	ld A,[LVLPOS_YH] ;03:C0AA                 
	ld H,A                                
	add HL,BC                             
	ld A,L                                
	ld [$CA49],A ;03:CA49                 
	ld A,H                                
	ld [$CA4A],A ;03:CA4A                 
	call F_Addr_001BBC ;03:1BBC             
	ld A,[LVLPOS_YL] ;01:C0A9                 
	ld C,A                                
	ld A,[LVLPOS_YH] ;01:C0AA                 
	ld B,A                                
	push BC                               
	ld A,[$CA49] ;01:CA49                 
	ld E,A                                
	ld A,[$CA4A] ;01:CA4A                 
	ld D,A                                
	push DE                               
	ld A,[$CA49] ;01:CA49                 
	ld [LVLPOS_YL],A ;01:C0A9                 
	ld A,[$CA4A] ;01:CA4A                 
	ld [LVLPOS_YH],A ;01:C0AA                 
	call F_Addr_000F8F ;01:0F8F             
	pop DE                                
	ld A,E                                
	ld [$CA49],A ;07:CA49                 
	ld A,D                                
	ld [$CA4A],A ;07:CA4A                 
	pop BC                                
	ld A,C                                
	ld [LVLPOS_YL],A ;07:C0A9                 
	ld A,B                                
	ld [LVLPOS_YH],A ;07:C0AA                 
	ld B, $40                             
Addr_001A21:
	push BC                               
	ld C,$01                              
	call F_Delay_00036C ;03:036C             
	call F_Addr_0012C1 ;03:12C1             
	call F_Addr_000EA7 ;03:0EA7             
	ldh A,[$FFB8]                     
	ld C,A                                
	ld B, $00                             
	bit 7, A                              
	jr Z,Addr_001A38                      
	ld B, $FF                             
Addr_001A38:
	ld A,[LVLPOS_YL] ;03:C0A9                 
	ld L,A                                
	ld A,[LVLPOS_YH] ;03:C0AA                 
	ld H,A                                
	add HL,BC                             
	ld A,L                                
	ld [LVLPOS_YL],A ;03:C0A9                 
	ld A,H                                
	ld [LVLPOS_YH],A ;03:C0AA                 
	call F_Addr_001957 ;03:1957             
	pop BC                                
	dec B                                 
	jr NZ,Addr_001A21                     
	ld A,[LVLPOS_YL] ;03:C0A9                 
	and $F0                               
	ld [LVLPOS_YL],A ;03:C0A9                 
	xor A                                 
	ldh [$FFB8],A                     
	ld [$CA3F],A ;03:CA3F                 
	ld A,[$C9BB] ;03:C9BB                 
	ld [$C708],A ;03:C708                 
	ret                                   
    
    
    
;*****************************************
;* 
;*****************************************
F_Addr_001B2D:
	push DE                               
	xor A                                 
	ldh [$FFA6],A                     
	ld A,[$CA0B] ;01:CA0B                 
	ld E,A                                
	ld BC, $FF80                          
Addr_001B38:
	add HL,BC                             
	bit 7, H                              
	jr NZ,Addr_001B44                     
	ldh A,[$FFA6]                     
	add A,E                               
	ldh [$FFA6],A                     
	jr Addr_001B38                        
Addr_001B44:
	ld BC, $0080                          
	add HL,BC                             
	ld A,L                                
	swap A                                
	and $0F                               
	ld [$CA0E],A ;01:CA0E                 
	pop HL                                
	ld E,$00                              
	ld BC, $FF60                          
Addr_001B56:
	add HL,BC                             
	bit 7, H                              
	jr NZ,Addr_001B5E                     
	inc E                                 
	jr Addr_001B56                        
Addr_001B5E:
	ld BC, $00A0                          
	add HL,BC                             
	ld A,L                                
	swap A                                
	and $0F                               
	ld [$CA0D],A ;01:CA0D                 
	ldh A,[$FFA6]                     
	add A,E                               
	ld C,A                                
	ld B, $00                             
	ld HL,MEM_C200                           
	add HL,BC                             
	ld A,[HL]                             
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_001B76:
	swap A                                
	ld C,A                                
	and $0F                               
	ld B,A                                
	ld A,C                                
	and $F0                               
	ld C,A                                
	push BC                               
	sla C                                 
	RL B                                  
	sla C                                 
	RL B 
	
    ld A,[$CA0C] ;  
    ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;01:2000                 

    ld HL, $4000 ;Data_2_4002 SCREEN
	add HL,BC                             
	pop BC                                
	add HL,BC                             
	ret                                   
    
    
;*****************************************
;* 
;*****************************************
F_Addr_001BBC:
	ld A,[LVLPOS_XL] ;03:C0AB                 
	sub $30                               
	ld E,A                                
	ld [$CA47],A ;03:CA47                 
	ld A,[LVLPOS_XH] ;03:C0AC                 
	sbc A,$00                             
	ld D,A                                
	ld [$CA48],A ;03:CA48                 
	push DE                               
	push HL                               
	call F_Addr_001A65 ;03:1A65             
	pop HL                                
	pop DE                                
	ld B, $0F                             
Addr_001BD7:
	push BC                               
	ld A,E                                
	add A,$08                             
	ld E,A                                
	ld [$CA47],A ;01:CA47                 
	ld A,D                                
	adc A,$00                             
	ld D,A                                
	ld [$CA48],A ;01:CA48                 
	push DE                               
	push HL                               
	call F_Addr_001C07 ;01:1C07             
	pop HL                                
	pop DE                                
	ld A,E                                
	add A,$08                             
	ld E,A                                
	ld [$CA47],A ;01:CA47                 
	ld A,D                                
	adc A,$00                             
	ld D,A                                
	ld [$CA48],A ;01:CA48                 
	push DE                               
	push HL                               
	call F_Addr_001A65 ;01:1A65             
	pop HL                                
	pop DE                                
	pop BC                                
	dec B                                 
	jr NZ,Addr_001BD7                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_001C07:
	ld A,BANK_01                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;02:2000                 
	ld A,[$CA44] ;01:CA44                 
	ld L,A                                
	ld A,[$CA45] ;01:CA45                 
	ld H,A                                
	ld B, $01                             
	ld A,[$CA49] ;01:CA49                 
	and A                                 
	jr NZ,Addr_001C1F                     
	ld B,A                                
Addr_001C1F:
	ld A,[$CA4A] ;01:CA4A                 
	sla A                                 
	add A,B                               
	push AF                               
	rst $18                               
	ld [$CA46],A ;01:CA46                 
	ld A,[$CA42] ;01:CA42                 
	ld L,A                                
	ld A,[$CA43] ;01:CA43                 
	ld H,A                                
	pop AF                                
	rst $20                               
	ld L,E                                
	ld H,D                                
	ld A,[$CA47] ;01:CA47                 
	and $F8                               
	ld E,A                                
	ld A,[$CA48] ;01:CA48                 
	ld D,A                                
Addr_001C40:
	ld A,[HL+]                            
	ldh [$FFAA],A                     
	cp $FF                                
	ret Z                                 
	cp E                                  
	jr NZ,Addr_001C4D                     
	ld A,[HL]                             
	cp D                                  
	jr Z,Addr_001C59                      
Addr_001C4D:
	inc HL                                
	inc HL                                
	inc HL                                
Addr_001C50:
	ld A,[$CA46] ;01:CA46                 
	inc A                                 
	ld [$CA46],A ;01:CA46                 
	jr Addr_001C40                        
Addr_001C59:
	ldh [$FFAB],A                     
	call F_Addr_001D55 ;01:1D55             
	jr C,Addr_001C4D                      
	inc HL                                
	ld A,[HL+]                            
	ld C,A                                
	xor A                                 
	sla C                                 
	rla                                   
	sla C                                 
	rla                                   
	sla C                                 
	rla                                   
	ld [$CA4C],A ;01:CA4C                 
	ld A,C                                
	ld [$CA4B],A ;01:CA4B                 
	ld A,[LVLPOS_YL] ;01:C0A9                 
	ld C,A                                
	ld A,[$CA4B] ;01:CA4B                 
	sub C                                 
	ldh [$FFA8],A                     
	ld A,[LVLPOS_YH] ;01:C0AA                 
	ld C,A                                
	ld A,[$CA4C] ;01:CA4C                 
	sbc A,C                               
	ldh [$FFA9],A                     
	ld A,[LVLPOS_XL] ;01:C0AB                 
	ld C,A                                
	ldh A,[$FFAA]                     
	sub C                                 
	ldh [$FFAA],A                     
	ld A,[LVLPOS_XH] ;01:C0AC                 
	ld C,A                                
	ldh A,[$FFAB]                     
	sbc A,C                               
	ldh [$FFAB],A                     
	call F_Addr_001C9F ;01:1C9F             
	jr Addr_001C50                        
    
    
;*****************************************
;* ????????  ???
;*****************************************
Data_0_1D35:
	DB $72;,0                                ; 0X001D35 00:1D35 72 66 70; ld [HL],D
	DB $66;,0                                ; 0X001D36 00:1D36 66 70 71; ld H,[HL]
	DB $70;,0                                ; 0X001D37 00:1D37 70 71 00; ld [HL],B
	DB $71;,0                                ; 0X001D38 00:1D38 71 00 00; ld [HL],C
	DB $00;,0                              ;*; 0X001D39 00:1D39 00 00 00; nop
	DB $00;,0                              ;*; 0X001D3A 00:1D3A 00 00 00; nop
	DB $00;,0                              ;*; 0X001D3B 00:1D3B 00 00 00; nop
	DB $00;,0                              ;*; 0X001D3C 00:1D3C 00 00 00; nop
	DB $00;,0                              ;*; 0X001D3D 00:1D3D 00 00 00; nop
	DB $00;,0                              ;*; 0X001D3E 00:1D3E 00 00 00; nop
	DB $00;,0                              ;*; 0X001D3F 00:1D3F 00 00 00; nop
	DB $00;,0                              ;*; 0X001D40 00:1D40 00 00 00; nop
	DB $00;,0                              ;*; 0X001D41 00:1D41 00 00 00; nop
	DB $00;,0                              ;*; 0X001D42 00:1D42 00 00 00; nop
	DB $00;,0                              ;*; 0X001D43 00:1D43 00 00 EC; nop
	DB $00;,0                              ;*; 0X001D44 00:1D44 00 EC ED; nop
    
    DB $EC;,0                                ; 0X001D45 00:1D45 EC ED EE;
	DB $ED;,0                                ; 0X001D46 00:1D46 ED EE EF;
	DB $EE;,0                                ; 0X001D47 00:1D47 EE EF C6; xor $EF
	DB $EF;,0                                ; 0X001D48 00:1D48 EF C6 C7; rst $28
	DB $C6;,0                                ; 0X001D49 00:1D49 C6 C7 6D; add A,$C7
	DB $C7;,0                                ; 0X001D4A 00:1D4A C7 6D 00; rst $00
	DB $6D;,0                                ; 0X001D4B 00:1D4B 6D 00 7F; ld L,L
	DB $00;,0                              ;*; 0X001D4C 00:1D4C 00 7F 80; nop
	DB $7F;,0                                ; 0X001D4D 00:1D4D 7F 80 81; ld A,A
	DB $80;,0                                ; 0X001D4E 00:1D4E 80 81 8C; add A,B
	DB $81;,0                              ;*; 0X001D4F 00:1D4F 81 8C 8D; add A,C
	DB $8C;,0                                ; 0X001D50 00:1D50 8C 8D FD; adc A,H
	DB $8D;,0                                ; 0X001D51 00:1D51 8D FD FE; adc A,L
	DB $FD;,0                                ; 0X001D52 00:1D52 FD FE FF;
	DB $FE;,0                                ; 0X001D53 00:1D53 FE FF E5; cp $FF
	DB $FF;,0                                ; 0X001D54 00:1D54 FF E5 21; rst $38
    
;*****************************************
;* 
;*****************************************
F_Addr_001D55:
	push HL                               
	ld HL,$C710                           
Addr_001D59:
	ld A,[HL]                             
	and $0F                               
	cp $03                                
	jr Z,Addr_001D6C                      
	cp $0A                                
	jr NC,Addr_001D6C                     
Addr_001D64:
	ld A,L                                
	add A,$10                             
	ld L,A                                
	jr C,Addr_001D7E                      
	jr Addr_001D59                        
Addr_001D6C:
	inc H                                 
	ld A,L                                
	or $07                                
	ld L,A                                
	ld A,[$CA46] ;01:CA46                 
	cp [HL]                               
	jr Z,Addr_001D81                      
	ld A,L                                
	and $F0                               
	ld L,A                                
	dec H                                 
	jr Addr_001D64                        
Addr_001D7E:
	pop HL                                
	and A                                 
	ret                                   
    
Addr_001D81:
	pop HL                                
	scf                                   
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_001D84:
	ld A,BANK_14                     
	ld [$2000],A ;01:2000                 
    
    ld A,[$C916] ;04:C916                 
	and A                                 
	jr Z,Addr_001D93                      
	ld A,$20                              
	ld [$C707],A ;04:C707                 
	ld A,$60                              
	jr Addr_001DB4                        
Addr_001D93:
	ld A,[$C91C] ;04:C91C                 
	ld HL,Data_0_0FF5                           
	rst $20                               
	ld L,E                                
	ld H,D                                
	ld A,[MEM_CURRENT_LEVEL] ;04:C900                 
	rst $18                               
	ld [$C707],A ;04:C707                 
	ld A,[$C91C] ;04:C91C                 
	cp $02                                
	jr NZ,Addr_001DB3                     
	ld HL,Data_0_1010                             
	ld A,[MEM_CURRENT_LEVEL] ;00:C900                             
	rst $18                             
	jr Addr_001DB4                             
Addr_001DB3:
	xor A                                 
Addr_001DB4:
	ld [$C701],A ;04:C701                 
	ld A,$02                              
	ld [$C700],A ;04:C700                 
	ld A,$50                              
	ld [$C703],A ;04:C703                 
	ld A,$0B                              
	ld [$C801],A ;04:C801                 
	ld A,$16                              
	ld [$C800],A ;04:C800                 
	ld A,[$C910] ;04:C910                 
	ld [MEM_LIFE],A ;04:C911                 
	xor A                                 
	ld [$C702],A ;04:C702                 
	ld [$C704],A ;04:C704                 
	ld [$C705],A ;04:C705                 
	ld [MEM_HERO_ANIM],A ;04:C706                 
	ld [$C806],A ;04:C806                 
	ld [$C803],A ;04:C803                 
	ld [$C805],A ;04:C805                 
	ld [$C808],A ;04:C808

	ldh A,[MEM_CURRENT_BANK]                     
	ld [$2000],A ;01:2000                 

	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_001DEB:
	ld HL,$FFDF                           
	ld A,[HL]                             
	and A                                 
	ret Z                                 
	dec [HL]                              
	jr Z,Addr_001E00                      
	jr C,Addr_001E00                      
	bit 2, [HL]                           
	jr Z,Addr_001E00                      
	ld HL,$FFCA                           
	set 7, [HL]                           
	ret                                   
Addr_001E00:
	ld HL,$FFCA                           
	res 7, [HL]                           
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_001E06:
	ld A,$08                              
	ld [$C9BA],A ;01:C9BA                 
	ld A,[$C913] ;01:C913                 
	cp $02                                
	jp NC,Addr_001E14 ;01:1E14            
	inc A                                 
Addr_001E14:
	ld B,A                                
	ld A,[MEM_LIFE] ;01:C911                 
	sub B                                 
	ld [MEM_LIFE],A ;01:C911                 
	jr C,Addr_001E28                      
	jr Z,Addr_001E28                      
	call F_Addr_0011E3 ;01:11E3             
	ld A,$28                              
	jp F_Addr_0002E7 ;01:02E7               
Addr_001E28:
	xor A                             
	ld [MEM_LIFE],A ;00:C911                             
	ld A,$18                             
	ld [$C9BA],A ;00:C9BA                             
	call F_Addr_0011E3 ;00:11E3                             
	ld A,$28                             
	jp F_Addr_0002E7 ;00:02E7                             
    
;*****************************************
;* 
;*****************************************
F_Addr_001E39:
	ld B, $0F                             
	ld HL,$C710                           
Addr_001E3E:
	ld A,$80                              
	ld [HL],A                             
	ld A,$10                              
	add A,L                               
	ld L,A                                
	dec B                                 
	jr NZ,Addr_001E3E                     
	ret                                   
    
    
;*****************************************
;* 
;*****************************************
F_Addr_001E83:
	ld HL,$FFD1                           
	res 7, [HL]                           
	ldh A,[$FFCB]                     
	cp $24                                
	ret C                                 
	ldh A,[$FFCD]                     
	add A,$0A                             
	ld B,A                                
	ldh A,[$FFCB]                     
	sub $10                               
	ld C,A                                
	call F_Addr_001E49 ;03:1E49             
	call F_Addr_001EC9 ;03:1EC9             
	ret C                                 
	ldh A,[$FFCD]                     
	add A,$0A                             
	ld B,A                                
	ldh A,[$FFCB]                     
	ld C,A                                
	call F_Addr_001E49 ;03:1E49             
	call F_Addr_001EC9 ;03:1EC9             
	ret C                                 
	ldh A,[$FFCD]                     
	sub $0A                               
	ld B,A                                
	ldh A,[$FFCB]                     
	sub $10                               
	ld C,A                                
	call F_Addr_001E49 ;03:1E49             
	call F_Addr_001EC9 ;03:1EC9             
	ret C                                 
	ldh A,[$FFCD]                     
	sub $0A                               
	ld B,A                                
	ldh A,[$FFCB]                     
	ld C,A                                
	call F_Addr_001E49 ;03:1E49             
F_Addr_001EC9:
	cp $8E                                
	jr NC,Addr_001ED1                     
	cp $82                                
	jr NC,Addr_001ED3                     
Addr_001ED1:
	xor A                                 
	ret                                   
    
Addr_001ED3:
	ld HL,$FFD1                           
	;;;;;;;;;;;;;set 7, [HL]  ;   .                         
	scf                                   
	ret                                   
    
    
;*****************************************
;* 
;*****************************************
SCR_0_1F87:
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
SCR_0_1F8F:    
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_Ret  
    
;*****************************************
;* 
;*****************************************
SCR_0_1F98:    
	scrFunc_01                                
	scrFunc_GotoSrc SCR_0_1F98  
    
;*****************************************
;* 
;*****************************************
SCR_0_1F9C:     
	scrFunc_17                                
	scrFunc_GotoSrc SCR_0_1F9C                                
        
;*****************************************
;* 
;*****************************************
Addr_001FA0:
	xor A                                 
	jp F_Addr_0014A9 ;05:14A9               
    
;*****************************************
;* 
;*****************************************
Addr_001FA4:
	xor A                                 
	inc A                                 
	jp F_Addr_0014A9 ;05:14A9               
    
;*****************************************
;* 
;*****************************************
Addr_001FA9:
	scf                                   
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 
;*****************************************
Addr_001FAD:
	xor A                                 
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 
;*****************************************
F_Addr_001FB1:
	ld A,B                                
	cp $D0                                
	jr NC,Addr_001FBD                     
	cp $B8                                
	ret C                                 
	ld B, $B7                             
	jr Addr_001FC2                        
Addr_001FBD:
	cp $F0                                
	ret NC                                
	ld B, $F0                             
Addr_001FC2:
	ldh A,[$FFCA]                     
	and $0F                               
	cp $0B                                
	ret NZ                                
	pop DE                                
	jp Addr_001FA9 ;01:1FA9               
    
;*****************************************
;* 
;*****************************************
F_Addr_001FCD:
	ldh A,[$FFCA]                     
	and $0F                               
	cp $03                                
	ret NZ                                
	ld A,B                                
	cp $D0                                
	jr NC,Addr_001FDE                     
	cp $B8                                
	ret C                                 
	jr Addr_001FE1                        
Addr_001FDE:
	cp $F0                                
	ret NC                                
Addr_001FE1:
	pop DE                                
	jp Addr_001FAD ;01:1FAD               
    
;*****************************************
;* 
;*****************************************
F_Addr_001FE5:
	ldh A,[$FFCD]                     
	ld B,A                                
	call F_Addr_001FB1 ;01:1FB1             
	ldh A,[$FFCB]                     
	cp $88                                
	jp NC,Addr_001FAD ;01:1FAD            
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $A0                                
	jp NC,Addr_001FA9 ;01:1FA9            
	cp $8E                                
	jr NC,Addr_002004                     
	cp $8C                                
	jp NC,Addr_001FA9 ;01:1FA9            
Addr_002004:
	ldh A,[$FFDB]                     
	dec A                                 
	ld B,A                                
	ldh A,[$FFCD]                     
	add A,B                               
	ld B,A                                
	call F_Addr_001FB1 ;01:1FB1             
	ldh A,[$FFCB]                     
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $A0                                
	jp NC,Addr_001FA9 ;01:1FA9            
	cp $8E                                
	jr NC,Addr_002023                     
	cp $8C                                
	jp NC,Addr_001FA9 ;01:1FA9            
Addr_002023:
	ldh A,[$FFDB]                     
	dec A                                 
	ld B,A                                
	ldh A,[$FFCD]                     
	sub B                                 
	ld B,A                                
	call F_Addr_001FB1 ;01:1FB1             
	ldh A,[$FFCB]                     
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $A0                                
	jp NC,Addr_001FA9 ;01:1FA9            
	cp $8E                                
	jp NC,Addr_001FAD ;01:1FAD            
	cp $8C                                
	jp NC,Addr_001FA9 ;01:1FA9            
	jp Addr_001FAD ;01:1FAD               
    
;*****************************************
;* 
;*****************************************
F_Addr_002046:
	ldh A,[$FFD3]                     
	bit 7, A                              
	jr NZ,Addr_002093                     
	ldh A,[$FFDB]                     
	ld B,A                                
	ldh A,[$FFCD]                     
	add A,B                               
	ld B,A                                
	call F_Addr_001FCD ;01:1FCD             
	ldh A,[$FFCB]                     
	sub $02                               
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $A0                                
	jp NC,Addr_001FA9 ;01:1FA9            
	cp $8E                                
	jp NC,Addr_001FAD ;01:1FAD            
	cp $8C                                
	jp NC,Addr_001FA9 ;01:1FA9            
	ldh A,[$FFDB]                     
	ld B,A                                
	ldh A,[$FFCD]                     
	add A,B                               
	ld B,A                                
	call F_Addr_001FCD ;01:1FCD             
	ldh A,[$FFDA]                     
	ld C,A                                
	ldh A,[$FFCB]                     
	sub C                                 
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $A0                                
	jp NC,Addr_001FA9 ;01:1FA9            
	cp $8E                                
	jp NC,Addr_001FAD ;01:1FAD            
	cp $8C                                
	jp NC,Addr_001FA9 ;01:1FA9            
	jp Addr_001FAD ;01:1FAD               
    
;*****************************************
;* 
;*****************************************
Addr_002093:
	ldh A,[$FFDB]                     
	ld B,A                                
	ldh A,[$FFCD]                     
	sub B                                 
	ld B,A                                
	call F_Addr_001FCD ;01:1FCD             
	ldh A,[$FFCB]                     
	sub $02                               
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $A0                                
	jp NC,Addr_001FA9 ;01:1FA9            
	cp $8E                                
	jp NC,Addr_001FAD ;01:1FAD            
	cp $8C                                
	jp NC,Addr_001FA9 ;01:1FA9            
	ldh A,[$FFDB]                     
	ld B,A                                
	ldh A,[$FFCD]                     
	sub B                                 
	ld B,A                                
	call F_Addr_001FCD ;01:1FCD             
	ldh A,[$FFDA]                     
	ld C,A                                
	ldh A,[$FFCB]                     
	sub C                                 
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $A0                                
	jp NC,Addr_001FA9 ;01:1FA9            
	cp $8E                                
	jp NC,Addr_001FAD ;01:1FAD            
	cp $8C                                
	jp NC,Addr_001FA9 ;01:1FA9            
	jp Addr_001FAD ;01:1FAD               
    
;*****************************************
;* 
;*****************************************
Addr_0020DA:
	ldh A,[$FFCD]                     
	ld B,A                                
	ldh A,[$FFDA]                     
	ld C,A                                
	ldh A,[$FFCB]                     
	sub C                                 
	cp $90                                
	jp NC,Addr_001FAD ;01:1FAD            
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $A0                                
	jp NC,Addr_001FA9 ;01:1FA9            
	ldh A,[$FFDB]                     
	dec A                                 
	ld B,A                                
	ldh A,[$FFCD]                     
	add A,B                               
	ld B,A                                
	ldh A,[$FFDA]                     
	ld C,A                                
	ldh A,[$FFCB]                     
	sub C                                 
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $A0                                
	jp NC,Addr_001FA9 ;01:1FA9            
	ldh A,[$FFDB]                     
	dec A                                 
	ld B,A                                
	ldh A,[$FFCD]                     
	sub B                                 
	ld B,A                                
	ldh A,[$FFDA]                     
	ld C,A                                
	ldh A,[$FFCB]                     
	sub C                                 
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $A0                                
	jp NC,Addr_001FA9 ;01:1FA9            
	jp Addr_001FAD ;01:1FAD               
    
;*****************************************
;* 
;*****************************************
Addr_002122:
	ldh A,[$FFCB]                     
	and $F0                               
	ldh [$FFCB],A                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_002129:
	ldh A,[$FFD3]                     
	cpl                                   
	inc A                                 
	ldh [$FFD3],A                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002130:
	call F_Addr_002129 ;01:2129             
	ld HL,$FFD1                           
	ldh A,[$FFD3]                     
	bit 7, A                              
	jr NZ,Addr_00213F                     
	set 5, [HL]                           
	ret                                   
Addr_00213F:
	res 5, [HL]                           
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002142:
	ldh A,[$FFD2]                     
	cpl                                   
	inc A                                 
	ldh [$FFD2],A                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002149:
	ld HL,$FFD2                           
	bit 7, [HL]                           
	jr NZ,Addr_002157                     
	ld A,[HL]                             
	cp $40                                
	ret NC                                
Addr_002154:
	inc [HL]                              
	inc [HL]                              
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002157:
	ld A,[HL]                             
	cp $F8                                
	jr C,Addr_002154                      
	cpl                                   
	inc A                                 
	ld [HL],A                             
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002160:
	ld HL,$FFDD                           
	set 3, [HL]                           
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002166:
	ld HL,$FFDD                           
	res 3, [HL]                           
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_00216C:
	ld HL,$FFDD                           
	set 2, [HL]                           
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_002172:
	ld HL,$FFDD                           
	res 2, [HL]                           
	ret                                   
    
;*****************************************
;*    
;*****************************************
SCR_0_2178:
    scrFunc_MemSet $84,$01,$FFCA                                
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_1E $00                                
	scrFunc_01                                
	scrFunc_PlaySnd $25                                
SCR_0_2187:	
	scrFunc_MemSet $84,$01,$FFCA                                
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_1E $00                                
	scrFunc_1A                                
	scrFunc_1F $1F                                
	scrFunc_Delay $08                                
	scrFunc_1F $20                                
	scrFunc_Delay $08                                
	scrFunc_00                                
    
;*****************************************
;* 
;*****************************************
SCR_0_219D:
	scrFunc_13 SCR_0_2178                                
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_PlaySnd $21                                
	scrFunc_34 $08,$10                                
	scrFunc_36 $01                                
	scrFunc_2B $20                                
	scrFunc_2C $E0                                
	scrFunc_Call Addr_0021CA                                
	scrFunc_1F $21                                
	scrFunc_21                                
	scrFunc_1A                                
SCR_0_21B7:	
	scrFunc_17                                
	scrFunc_Call F_Addr_001FE5                                
	scrFunc_10 SCR_0_21C1                                
	scrFunc_GotoSrc SCR_0_2178                                
SCR_0_21C1:	
	scrFunc_Call Addr_0020DA                                
	scrFunc_10 SCR_0_21B7                                
	scrFunc_GotoSrc SCR_0_2178                                

        
;*****************************************
;* 
;*****************************************
Addr_0021CA:
	ldh A,[$FFD1]                     
	and $20                               
	jr NZ,Addr_0021DA                     
	ldh A,[$FFD3]                     
	bit 7, A                              
	ret Z                                 
Addr_0021D5:
	cpl                                   
	inc A                                 
	ldh [$FFD3],A                     
	ret                                   
    
Addr_0021DA:
	ldh A,[$FFD3]                     
	bit 7, A                              
	jr Z,Addr_0021D5                      
	ret                                 
    
        
;*****************************************
;* 
;*****************************************
Addr_002234:
	ld HL,$C9DB                           
	ld A,[HL]                             
	and A                                 
	ret Z                                 
	dec [HL]                              
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_00223C:
	ld A,[$C91C] ;01:C91C                 
	cp $02                                
	jp F_Addr_0014A9 ;01:14A9               
   



;*****************************************
;* 
;*****************************************
Addr_002244:
	ldh A,[$FFE1]                     
	ld C,A                                
	ld B, $00                             
	ld HL,MEM_C100                           
	add HL,BC                             
	ld A,$FF                              
	ld [HL],A                             
	call F_Addr_002263 ;01:2263             
	ret                                   
;*****************************************
;* 
;*****************************************
Addr_002244_2:
	ldh A,[$FFE1]                     
	ld C,A                                
	ld B, $00                             
	ld HL,MEM_C100                           
	add HL,BC                             
	ld A,$FF                              
	ld [HL],A                             
	;;;call F_Addr_002263 ;01:2263             
	ret                                   

;*****************************************
;* 
;*****************************************
Addr_002254:
	ldh A,[$FFE1]                     
	ld C,A                                
	ld B, $00                             
	ld HL,MEM_C100                           
	add HL,BC                             
	ld A,[HL]                             
	and A                                 
	jp NZ,Func00_00158C ;01:158C            
	ret                                   
    
;*****************************************
;*    
;*****************************************
F_Addr_002263:
	ld HL,$C91B
	ld A,[HL]
	and A
	ret Z
	dec [HL]
    ;jr NZ,.L_002263_T
    ;ld A,91;45;47                            
	;call F_Addr_0002E7 ;05:02E7             
;.L_002263_T: 
    call F_Addr_002264
	ret
    
    
;*****************************************
;*     
;*****************************************
F_Addr_002264:
    ld A,[$C91B]
    ld B,A
    ld A,[MEM_CURRENT_LEVEL]
	ld HL,Data_0_12A7
	rst $18
    sub B
    
	ld HL,$C5AB 
    push HL
    
	ld D,A
	ld B, $FF
.L_017207_T: 
	inc B
	ld A,D
	ld E,A
	sub $64
	ld D,A
	jr NC,.L_017207_T
	ld A,B
	ld C,A
	and A
	jr Z,.L_017217_T
	or $F0
	ld [HL+],A 
    
.L_017217_T:
	ld B, $FF
.L_017219_T:
	inc B
	ld A,E
	ld D,A
	sub $0A
	ld E,A
	jr NC,.L_017219_T
	ld A,C
	and A
	jr NZ,.L_017229_T
    
.L_017229_T:    
	ld A,B
	or $F0
	ld [HL+],A
.L_01722D_T:        
	ld A,D
	or $F0
	ld [HL+],A
    
    pop HL
	ld A,$9F                              
	ldh [$FF96],A                     
	ld A,$D0                              
	ldh [$FF97],A                     
    ld B, $02
    
    call F_Addr_000466
	ret                                   
    
    
    
        
        
;*****************************************
;* 
;*****************************************
Addr_0022C4:
	ld A,[$C91C] ;01:C91C                 
	cp $02                                
	ret NZ                                
	ldh A,[$FFCE]                     
	and A                                 
	jp NZ,Addr_004CEB ;01:4CEB            
	ldh A,[$FFCD]                     
	cp $90                                
	jp NC,Addr_004CEB ;01:4CEB            
	cp $10                                
	jp C,Addr_004CEB ;01:4CEB             
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_0022DD:
	ldh A,[$FFE0]                     
	and A                                 
	jp Z,Addr_001FA0 ;01:1FA0             
	call F_Addr_002E44 ;01:2E44             
	jp C,Addr_001FA0 ;01:1FA0             
	ld A,[$C9D0] ;01:C9D0                 
	and A                                 
	jp Z,Addr_001FA0 ;01:1FA0             
	ldh A,[$FFCD]                     
	ld B,A                                
	ld A,[$C703] ;01:C703                 
	cp B                                  
	jr NC,Addr_002307                     
	ld A,[$C707] ;01:C707                 
	and $20                               
	jp NZ,Addr_001FA0 ;01:1FA0            
	ld A,$28                              
	ldh [$FFD3],A                     
	jr Addr_002313                        
Addr_002307:
	ld A,[$C707] ;01:C707                 
	and $20                               
	jp Z,Addr_001FA0 ;01:1FA0             
	ld A,$D8                              
	ldh [$FFD3],A                     
Addr_002313:
	ld A,[$C9D4] ;01:C9D4                 
	and A                                 
	jp NZ,Addr_001FA0 ;01:1FA0            
	ld A,$FF                              
	ld [$C9D4],A ;01:C9D4                 
	jp Addr_001FA4 ;01:1FA4               
    
;*****************************************
;* 
;*****************************************
Addr_002322:
	ldh A,[$FFDB]                     
	dec A                                 
	ld B,A                                
	ldh A,[$FFCD]                     
	add A,B                               
	ld B,A                                
	ldh A,[$FFCB]                     
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $A3                                
	jr NC,Addr_002339                     
	cp $A0                                
	jp NC,Addr_001FA9 ;01:1FA9            
Addr_002339:
	ldh A,[$FFDB]                     
	dec A                                 
	ld B,A                                
	ldh A,[$FFCD]                     
	sub B                                 
	ld B,A                                
	ldh A,[$FFCB]                     
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $A3                                
	jp NC,Addr_001FAD ;01:1FAD            
	cp $A0                                
	jp NC,Addr_001FA9 ;01:1FA9            
	jp Addr_001FAD ;01:1FAD               
    
;*****************************************
;* 
;*****************************************
Addr_002354:
	ld A,[$C9E0] ;01:C9E0                 
	and A                                 
	ret Z                                 
	ldh A,[$FFD3]                     
	push AF                               
	ld A,[$C9E0] ;01:C9E0                 
	ldh [$FFD3],A                     
	call F_Addr_002046 ;01:2046             
	jr C,Addr_002369                      
	call F_Addr_0016BA ;01:16BA             
Addr_002369:
	pop AF                                
	ldh [$FFD3],A                     
	ret                                   
    
        
;*****************************************
;* 
;*****************************************
Addr_002409:
	ldh A,[$FFCE]                     
	cp $FF                                
	jr Z,Addr_00241A                      
	and A                                 
	jr Z,Addr_002421                      
Addr_002412:
	ld HL,$C9ED                             
	set 7, [HL]                             
	jp Func00_00158C                             
Addr_00241A:
	ldh A,[$FFCD]                             
	cp $D0                             
	jr C,Addr_002412                             
	ret                             
Addr_002421:
	ldh A,[$FFCD]                     
	cp $C8                                
	jr NC,Addr_002412                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002428:
	ld A,[$C9ED] ;01:C9ED                 
	bit 7, A                              
	jp NZ,Func00_00158C ;01:158C            
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002431:
	ld A,[$C9ED] ;01:C9ED                 
	bit 0, A                              
	jp Z,Addr_001FA4 ;01:1FA4             
	jp Addr_001FA0 ;01:1FA0               
    
;*****************************************
;* 
;*****************************************
Addr_00243C:
	ld HL,$FFDD                           
	res 0, [HL]                           
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002442:
	ld HL,$FFDD                           
	set 0, [HL]                           
	ret                                   
    
        
;*****************************************
;* 
;*****************************************
Addr_002514:
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	ld HL,Data_0_3B68                           
	rst $18                               
	ld B,A                                
	ld A,[$C923] ;01:C923                 
	and B                                 
	jp F_Addr_0014A9 ;01:14A9               
    

;*****************************************
;* 
;*****************************************
Addr_002549:
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	ld HL,Data_0_3B68                           
	rst $18                               
	ld B,A                                
	ld A,[$C924] ;01:C924                 
	and B                                 
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 46   
;*****************************************
SCR_46:   
	scrFunc_Call Addr_00256B                                
	scrFunc_IF_NZ SCR_22                              
	scrFunc_13 SCR_0_2564                                
	scrFunc_GotoSrc SCR_0_226E                                
SCR_0_2564:	
	scrFunc_05 $04,SCR_0_2178                                
	scrFunc_GotoSrc SCR_0_3BB1                                
        
;*****************************************
;* 
;*****************************************
Addr_00256B:
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	ld HL,Data_0_3B68                           
	rst $18                               
	ld B,A                                
	ld A,[$C921] ;01:C921                 
	and B                                 
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 2A    - 
;*****************************************
SCR_2a: 
	scrFunc_Call Addr_00256B                                
	scrFunc_IF_NZ SCR_22                                
	scrFunc_13 SCR_0_2586                                
	scrFunc_GotoSrc SCR_0_226E                                
SCR_0_2586:	
	scrFunc_05 $04,SCR_0_2178                                
	scrFunc_GotoSrc SCR_0_3A92                                
        
;*****************************************
;* 47  
;*****************************************
SCR_47:  
	scrFunc_Call Addr_0025A6                                
	scrFunc_IF_NZ SCR_0_25A0                              
	scrFunc_13 SCR_0_2599                                
	scrFunc_GotoSrc SCR_0_2271                                
SCR_0_2599:	
	scrFunc_05 $09,SCR_0_3D13                                
	scrFunc_GotoSrc SCR_0_2178                                
SCR_0_25A0:	
	scrFunc_13 SCR_0_25C7                              
	scrFunc_GotoSrc SCR_0_2271                              
        
;*****************************************
;* 
;*****************************************
Addr_0025A6:
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	ld HL,Data_0_3B68                           
	rst $18                               
	ld B,A                                
	ld A,[$C920] ;01:C920                 
	and B                                 
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 
;*****************************************
SCR_0_25B5:
	scrFunc_28 $80,$00                              
	scrFunc_GotoSrc SCR_0_25BE                              
SCR_0_25BB: 
	scrFunc_28 $60,$00                              
SCR_0_25BE:	
	scrFunc_27 $50,$00                              
	scrFunc_13 SCR_0_25C7                              
	scrFunc_GotoSrc SCR_0_25D7                              
SCR_0_25C7:	
	scrFunc_05 $09,SCR_0_3C41                              
	scrFunc_GotoSrc SCR_0_2178                              
        
;*****************************************
;* 
;*****************************************
SCR_0_25CE:
	scrFunc_28 $80,$00                                
	scrFunc_Call Addr_0025EC                                
	scrFunc_13 SCR_0_25E5                                
SCR_0_25D7:	
	scrFunc_05 $04,SCR_0_2178                                
	scrFunc_Delay $0C                                
	scrFunc_MemSet $07,$01,$FFCA                                
	scrFunc_GotoSrc SCR_0_2271                                
SCR_0_25E5:	
	scrFunc_05 $09,SCR_0_3C52                                
	scrFunc_GotoSrc SCR_0_2178                                
        
;*****************************************
;* 
;*****************************************
Addr_0025EC:
	ld A,[$C703] ;01:C703                 
	cp $50                                
	jr NC,Addr_0025F8                     
	ld A,$88                              
	ldh [$FFCD],A                     
	ret                                   
Addr_0025F8:
	ld A,$18                              
	ldh [$FFCD],A                     
	ret                                   
    
        
;*****************************************
;* 
;*****************************************
Addr_00267B:
	ldh A,[$FFE0]                     
	and A                                 
	ret Z                                 
	call F_Addr_0026AD ;01:26AD             
	ret NZ                                
	ldh A,[$FFCD]                     
	ld B,A                                
	ld A,[$C703] ;01:C703                 
	cp B                                  
	jr NC,Addr_002694                     
	ld A,[$C707] ;01:C707                 
	and $20                               
	jr Z,Addr_00269A                      
	ret                              
Addr_002694:
	ld A,[$C707] ;01:C707                 
	and $20                               
	ret Z                                 
Addr_00269A:
	ld A,$FF                              
	ld [$C9D6],A ;01:C9D6                 
	ld HL,$C9B9                           
	bit 2, [HL]                           
	ret Z                                 
	ld A,[$C709] ;01:C709                 
	ldh [$FFD3],A                     
	jp F_Addr_0016BA ;01:16BA               
F_Addr_0026AD:
	ldh A,[$FFCB]                     
	ld B,A                                
	ld A,[$C701] ;01:C701                 
	cp B                                  
	ret                                   
    
;*****************************************
;* 2C  
;*****************************************
SCR_2c:
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $08,$20                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $30                                
	scrFunc_1A                                
SCR_0_26C4:	
	scrFunc_Call Addr_0026D0                                
	scrFunc_IF_NZ SCR_0_2675                                
	scrFunc_03 Addr_0026D7                                
	scrFunc_GotoSrc SCR_0_26C4                                

;*****************************************
;* 
;*****************************************
Addr_0026D0:
	ld A,[MEM_FERRULE_3] ;01:C91F                 
	and A                                 
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 
;*****************************************
Addr_0026D7:
	ldh A,[$FFE0]                     
	and A                                 
	ret Z                                 
	call F_Addr_0026AD ;00:26AD                             
	ret NZ                             
	ld A,$FF                             
	ld [$C9D6],A ;00:C9D6                             
	ld [$C9D7],A ;00:C9D7                             
	ret                             
    
;*****************************************
;* 2D ?????? 
;*****************************************
SCR_2d: 
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_Call Addr_00327B                                
	scrFunc_34 $08,$10                                
	scrFunc_36 $00                                
	scrFunc_1F $1E                                
	scrFunc_1A                                
SCR_0_26F8:	
	scrFunc_03 Addr_00274D                                
	scrFunc_Call Addr_00267B                                
	scrFunc_Call Addr_00338D                                
	scrFunc_IF_NZ SCR_0_26F8                                
	scrFunc_Call F_Addr_001FE5                                
	scrFunc_10 SCR_0_270D                                
	scrFunc_GotoSrc SCR_0_26F8                                
SCR_0_270D:	
	scrFunc_2C $08                                
	scrFunc_2B $00                                
	scrFunc_Call Addr_0027C8                                
SCR_0_2714:	
	scrFunc_03 Addr_00274D                                
	scrFunc_18                                
	scrFunc_2E                                
	scrFunc_2E                                
	scrFunc_Call F_Addr_001FE5                                
	scrFunc_10 SCR_0_2714                                
	scrFunc_Call Addr_002122                                
	scrFunc_Call Addr_002781                                
	scrFunc_IF_NZ SCR_0_272F                                
SCR_0_2729:	
	scrFunc_03 Addr_00274D                                
	scrFunc_GotoSrc SCR_0_2729                                
SCR_0_272F:	
	scrFunc_MemSet $01,$01,$C9CF                                
	scrFunc_Delay $1E                                
	scrFunc_PlaySnd $4F                                
SCR_0_2738:	
	scrFunc_Call Addr_003B31                                
	scrFunc_Delay $04                                
	scrFunc_Call Addr_003B3F                                
	scrFunc_Delay $04                                
	scrFunc_0D $10,SCR_0_2738 
    
	scrFunc_Call F_FadeOut_0010B3                                
	scrFunc_PlaySnd $00                                
	scrFunc_State $08                                

;*****************************************
;* 
;*****************************************
Addr_00274D:
	ld DE,$05A0                           
	ld HL,$06F0                           
	call F_Addr_00275C ;01:275C             
	ret NC                                
	xor A                              
	ld [$C916],A ;00:C916                              
	ret                             
F_Addr_00275C:
	ld A,[LVLPOS_XH] ;01:C0AC                 
	cp H                                  
	jr Z,Addr_002766                      
	jr NC,Addr_00277C                     
	jr Addr_00276C                        
Addr_002766:
	ld A,[LVLPOS_XL] ;01:C0AB                 
	cp L                                  
	jr NC,Addr_00277C                     
Addr_00276C:
	ld A,[LVLPOS_XH] ;01:C0AC                 
	cp D                                  
	jr Z,Addr_002775                      
	jr C,Addr_00277C                      
	ret                                   
Addr_002775:
	ld A,[LVLPOS_XL] ;01:C0AB                 
	cp E                                  
	jr C,Addr_00277C                      
	ret                                   
Addr_00277C:
	call Func00_00158C ;01:158C             
	scf                                   
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002781:
	ld A,[LVLPOS_XL] ;01:C0AB                 
	ld C,A                                
	ld A,[LVLPOS_XH] ;01:C0AC                 
	ld B,A                                
	ldh A,[$FFCD]                     
	ld L,A                                
	ldh A,[$FFCE]                     
	ld H,A                                
	add HL,BC                             
	ld A,H                                
	cp $06                                
	jp NZ,Addr_001FA0 ;01:1FA0            
	ld A,L                                
	cp $80                                
	jp C,Addr_0027A4 ;01:27A4             
	cp $90                                
	jp NC,Addr_0027B6 ;01:27B6            
	jp Addr_001FA0                             
    
;*****************************************
;* 
;*****************************************
Addr_0027A4:
	ld HL,$C916                           
	bit 0, [HL]                           
	jp NZ,Addr_001FA0 ;01:1FA0            
	set 0, [HL]                           
	bit 1, [HL]                           
	jp NZ,Addr_001FA4 ;01:1FA4            
	jp Addr_001FA0 ;01:1FA0               
    
;*****************************************
;* 
;*****************************************
Addr_0027B6:
	ld HL,$C916                           
	bit 1, [HL]                           
	jp NZ,Addr_001FA0 ;01:1FA0            
	set 1, [HL]                           
	bit 0, [HL]                           
	jp NZ,Addr_001FA4 ;01:1FA4            
	jp Addr_001FA0 ;00:1FA0                             
    
;*****************************************
;* 
;*****************************************
Addr_0027C8:
	ld HL,$C9B9                           
	res 2, [HL]                           
	ret                                   
    
;*****************************************
;* 2F ?????? 
;*****************************************
SCR_2f: 
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_Call Addr_0027E1                                
	scrFunc_34 $08,$10                                
    scrFunc_36 $00                                
	scrFunc_1F $1E                                
	scrFunc_1A                                
	scrFunc_GotoSrc SCR_0_1F98                                

;*****************************************
;* 
;*****************************************
Addr_0027E1:
	ld A,[$C915] ;01:C915                 
	and A                                 
	jp Z,Func00_00158C ;01:158C             
	ret                                   
    
;*****************************************
;* 2E  
;*****************************************
SCR_2e: 
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $08,$10                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $36                                
	scrFunc_1A                                
SCR_0_27F8:	
	scrFunc_03 Addr_0022DD                                
	scrFunc_IF_NZ SCR_0_2801                                
	scrFunc_GotoSrc SCR_0_27F8                                
SCR_0_2801:	
	scrFunc_PlaySnd $21                                
	scrFunc_MemSet $03,$01,$FFCA                                
SCR_0_2808:	
	scrFunc_03 F_Addr_002046                                
	scrFunc_10 SCR_0_2817                                
	scrFunc_Call Addr_002839                                
	scrFunc_10 SCR_0_2831                              
	scrFunc_Call Addr_002899                                
SCR_0_2817:	
	scrFunc_Call F_Addr_001FE5                                
	scrFunc_10 SCR_0_2821                                
	scrFunc_18                                
	scrFunc_GotoSrc SCR_0_2808                                
SCR_0_2821:	
	scrFunc_2C $28                                
	scrFunc_2B $00                                
	scrFunc_17                                
	scrFunc_Call F_Addr_001FE5                                
	scrFunc_10 SCR_0_2821                                
	scrFunc_2C $00                                
	scrFunc_Call Addr_002122                                
SCR_0_2831:	
	scrFunc_MemSet $0B,$01,$FFCA                                
	scrFunc_GotoSrc SCR_0_27F8                                

;*****************************************
;* 
;*****************************************
Addr_002839:
	ldh A,[$FFD3]                     
	bit 7, A                              
	jr NZ,Addr_00286C                     
	ldh A,[$FFDB]                     
	ld B,A                                
	ldh A,[$FFCD]                     
	add A,B                               
	ld B,A                                
	ldh A,[$FFCB]                     
	sub $02                               
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $FD                                
	jp NC,Addr_001FA9 ;01:1FA9            
	ldh A,[$FFDB]                             
	ld B,A                             
	ldh A,[$FFCD]                             
	add A,B                             
	ld B,A                             
	ldh A,[$FFDA]                             
	ld C,A                             
	ldh A,[$FFCB]                             
	sub C                             
	ld C,A                             
	call F_Addr_001E49 ;00:1E49                             
	cp $FD                             
	jp NC,Addr_001FA9 ;00:1FA9                             
	jp Addr_001FAD ;00:1FAD                             
Addr_00286C:
	ldh A,[$FFDB]                             
	ld B,A                             
	ldh A,[$FFCD]                             
	sub B                             
	ld B,A                             
	ldh A,[$FFCB]                             
	sub $02                             
	ld C,A                             
	call F_Addr_001E49 ;00:1E49                             
	cp $FD                             
	jp NC,Addr_001FA9 ;00:1FA9                             
	ldh A,[$FFDB]                             
	ld B,A                             
	ldh A,[$FFCD]                             
	sub B                             
	ld B,A                             
	ldh A,[$FFDA]                             
	ld C,A                             
	ldh A,[$FFCB]                             
	sub C                             
	ld C,A                             
	call F_Addr_001E49 ;00:1E49                             
	cp $FD                             
	jp NC,Addr_001FA9 ;00:1FA9                             
	jp Addr_001FAD ;00:1FAD                             

;*****************************************
;* 
;*****************************************
Addr_002899:
	ldh A,[$FFD3]                     
	bit 7, A                              
	jr NZ,Addr_0028A5                     
	ldh A,[$FFCD]                     
	add A,$10                             
	jr Addr_0028A9                        
Addr_0028A5:
	ldh A,[$FFCD]                             
	sub $10                             
Addr_0028A9:
	ld [$C9F3],A ;01:C9F3                 
	ldh A,[$FFCB]                     
	sub $04                               
	ld [$C9F4],A ;01:C9F4                 
	call F_Addr_001EDA ;01:1EDA             
	ld B, $04                             
	ld DE,SCR_0_2178                           
	jp F_Addr_00149B ;01:149B               
    
;*****************************************
;* 30   
;*****************************************
SCR_30: 
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $10,$08                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $00                                
	scrFunc_2C $06                                
	scrFunc_2B $00                                
	scrFunc_1A                                
SCR_0_28D1:	
	scrFunc_17                                
	scrFunc_Call Addr_0028E5                                
	scrFunc_Call Addr_0028DB                                
	scrFunc_GotoSrc SCR_0_28D1                                

;*****************************************
;* 
;*****************************************
Addr_0028DB:
	ldh A,[$FFCB]                     
	cp $98                                
	ret C                                 
	ld A,$50                              
	ldh [$FFCB],A                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_0028E5:
	ldh A,[$FFE0]                     
	and A                                 
	ret Z                                 
	call F_Addr_002E44 ;01:2E44             
	ret NC                                
	ldh A,[$FFD2]                     
	ld [$C9D2],A ;01:C9D2                 
	ldh A,[$FFD4]                     
	ld [$C9D3],A ;01:C9D3                 
	ret                                   
    
;*****************************************
;* 31  
;*****************************************
SCR_31: 
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $10,$08                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $00                                
	scrFunc_1A                                
SCR_0_2907:	
	scrFunc_2B $00                                
	scrFunc_2C $00                                
SCR_0_290B:	
	scrFunc_Call F_Addr_001E83                                
	scrFunc_03 Addr_00294B                                
	scrFunc_IF_NZ SCR_0_2921                                
	scrFunc_Call F_Addr_002046                                
	scrFunc_10 SCR_0_291D                                
	scrFunc_GotoSrc SCR_0_290B                                
SCR_0_291D:	
	scrFunc_18                                
	scrFunc_GotoSrc SCR_0_290B                                
SCR_0_2921:	
	scrFunc_PlaySnd $21                                
SCR_0_2923:	
	scrFunc_Call F_Addr_001E83                                
	scrFunc_Call F_Addr_002046                                
	scrFunc_10 SCR_0_292F                                
	scrFunc_GotoSrc SCR_0_290B                                
SCR_0_292F:	
	scrFunc_17                                
	scrFunc_Call Addr_002936                                
	scrFunc_GotoSrc SCR_0_2923                                
        
;*****************************************
;* 
;*****************************************
Addr_002936:
	ldh A,[$FFE0]                     
	and A                                 
	jp Z,Addr_00297B ;01:297B             
	call F_Addr_002E44 ;01:2E44             
	jp NC,Addr_00297B ;01:297B            
	call F_Addr_002987 ;01:2987             
	ldh A,[$FFD3]                     
	ld [$C9D1],A ;01:C9D1                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_00294B:
	ldh A,[$FFE0]                     
	and A                                 
	jp Z,Addr_00297B ;01:297B             
	call F_Addr_002E44 ;01:2E44             
	jp NC,Addr_00297B ;01:297B            
	call F_Addr_002987 ;01:2987             
	ld A,$FF                              
	ld [$C9D9],A ;01:C9D9                 
	ld A,[$C9D0] ;01:C9D0                 
	and A                                 
	jp Z,Addr_001FA0 ;01:1FA0             
	ld A,[$C707] ;01:C707                 
	and $20                               
	jr NZ,Addr_002974                     
	ld A,$F8                              
	ldh [$FFD3],A                     
	jp Addr_001FA4 ;01:1FA4               
    
;*****************************************
;* 
;*****************************************
Addr_002974:
	ld A,$08                              
	ldh [$FFD3],A                     
	jp Addr_001FA4 ;01:1FA4               
    
;*****************************************
;* 
;*****************************************
Addr_00297B:
	ld A,$78                              
	ldh [$FFCB],A                     
	xor A                                 
	ldh [$FFE2],A                     
	ldh [$FFD4],A                     
	jp Addr_001FA0 ;01:1FA0               
    
;*****************************************
;* 
;*****************************************
F_Addr_002987:
	ldh A,[$FFE2]                     
	cp $02                                
	jr NC,Addr_0029A4                     
	ld A,$10                              
	ldh [$FFD2],A                     
	ld [$C9D2],A ;01:C9D2                 
	ldh A,[$FFD4]                     
	ld [$C9D3],A ;01:C9D3                 
	call F_Addr_0016B0 ;01:16B0             
	xor A                                 
	ldh [$FFD2],A                     
	ld HL,$FFE2                           
	inc [HL]                              
	ret                                   
    
Addr_0029A4:
	cp $0A                                
	jr NC,Addr_0029AD                     
	ld HL,$FFE2                           
	inc [HL]                              
	ret                                   
    
Addr_0029AD:
	cp $0B                                
	ret NC                                
	ld A,$F0                              
	ldh [$FFD2],A                     
	ld [$C9D2],A ;01:C9D2                 
	ldh A,[$FFD4]                     
	ld [$C9D3],A ;01:C9D3                 
	call F_Addr_0016B0 ;01:16B0             
	xor A                                 
	ldh [$FFD2],A                     
	ld HL,$FFE2                           
	inc [HL]                              
	ret                                   
    
;*****************************************
;* 32   
;*****************************************
SCR_32: 
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $06,$0E                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $34                                
	scrFunc_1A                                
SCR_0_29D6:	
	scrFunc_03 Addr_0029DC                                
	scrFunc_GotoSrc SCR_0_29D6                                
        
;*****************************************
;* 
;*****************************************
Addr_0029DC:
	ldh A,[$FFE0]                     
	and A                                 
	jr Z,Addr_002A39                      
	ldh A,[$FFCD]                     
	ld B,A                                
	ld A,[$C703] ;01:C703                 
	cp B                                  
	jr NC,Addr_0029F3                     
	ld A,[$C707] ;01:C707                 
	and $20                               
	jr Z,Addr_0029FC                      
	jr Addr_002A1D                        
Addr_0029F3:
	ld A,[$C707] ;01:C707                 
	and $20                               
	jr NZ,Addr_0029FC                     
	jr Addr_002A1D                        
Addr_0029FC: ;   
	call F_Addr_0026AD ;01:26AD    db 0,0,0;         
	jr NZ,Addr_002A1D                     
	ld A,$FF                              
	ld [$C9D6],A ;01:C9D6                 
	ld [$C9D7],A ;01:C9D7                 
	ld HL,$C9B9                           
	bit 2, [HL]                           
	jr Z,Addr_002A1D                      
	bit 0, [HL]                           
	jr Z,Addr_002A1D                      
	ld A,[$C707] ;01:C707                 
	and $20                               
	jr Z,Addr_002A4E                      
	jr Addr_002A3E                        
Addr_002A1D:
	ld A,[$C9DA] ;01:C9DA                 
	and A                                 
	jr Z,Addr_002A39                      
	ld A,[$C9B9] ;01:C9B9                 
	bit 3, A                              
	jr Z,Addr_002A39                      
	ldh A,[$FFCA]                     
	cp $04                                
	jr Z,Addr_002A39                      
	ld A,$04                              
	ldh [$FFCA],A                     
	ld A,$5A                              
	call F_Addr_0002E7 ;01:02E7             
Addr_002A39:
	ld A,$34                              
	ldh [$FFD0],A                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002A3E:
	ldh A,[$FFD1]                     
	or $20                                
	ldh [$FFD1],A                     
	ld A,$35                              
	ldh [$FFD0],A                     
	ld A,$90                              
	ld [$C9DA],A ;01:C9DA                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002A4E:
	ldh A,[$FFD1]                     
	and $DF                               
	ldh [$FFD1],A                     
	ld A,$35                              
	ldh [$FFD0],A                     
	ld A,$70                              
	ld [$C9DA],A ;01:C9DA                 
	ret                                   
    
;*****************************************
;* 34   
;*****************************************
SCR_34:
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $08,$10                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $10                                
	scrFunc_1A                                
SCR_0_2A6D:	
	scrFunc_03 Addr_0022DD                                
	scrFunc_IF_NZ SCR_0_2A76                                
	scrFunc_GotoSrc SCR_0_2A6D                                
SCR_0_2A76:	
	scrFunc_PlaySnd $21                                
	scrFunc_2C $E0                                
	scrFunc_Call Addr_002A95                                
SCR_0_2A7D:	
	scrFunc_17                                
	scrFunc_Call Addr_002149                                
	scrFunc_Call Addr_002AA5                                
	scrFunc_10 SCR_0_2A7D                                
	scrFunc_PlaySnd $58                                
	scrFunc_05 $04,SCR_0_2187                                
	scrFunc_34 $10,$08                                
	scrFunc_1F $11                                
	scrFunc_GotoSrc SCR_0_2907                                
        
;*****************************************
;* 
;*****************************************
Addr_002A95:
	ldh A,[$FFD3]                     
	bit 7, A                              
	jr NZ,Addr_002AA0                     
	ld A,$0A                              
	ldh [$FFD3],A                     
	ret                                   
Addr_002AA0:
	ld A,$F6                             
	ldh [$FFD3],A                             
	ret                             
    
;*****************************************
;* 
;*****************************************
Addr_002AA5:
	ldh A,[$FFCB]                     
	cp $78                                
	jp C,Addr_001FAD ;01:1FAD             
	ld A,$78                              
	ldh [$FFCB],A                     
	jp Addr_001FA9 ;01:1FA9               
    
;*****************************************
;* 35   
;*****************************************
SCR_35:  
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $05,$07                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $0E                                
	scrFunc_1A                                
SCR_0_2AC2:	
	scrFunc_03 Addr_002AC8                                
	scrFunc_GotoSrc SCR_0_2AC2                                

;*****************************************
;* 
;*****************************************
Addr_002AC8:
	ldh A,[$FFE0]                     
	and A                                 
	jr Z,Addr_002B0D                      
	call F_Addr_0026AD ;01:26AD             
	jr NZ,Addr_002B09                     
	ldh A,[$FFCD]                     
	ld B,A                                
	ld A,[$C703] ;01:C703                 
	cp B                                  
	jr NC,Addr_002AE4                     
	ld A,[$C707] ;01:C707                 
	and $20                               
	jr Z,Addr_002AED                      
	jr Addr_002B09                             
    
Addr_002AE4:
	ld A,[$C707] ;01:C707                 
	and $20                               
	jr NZ,Addr_002AED                     
	jr Addr_002B09                        
    
Addr_002AED:
	ld A,$FF                              
	ld [$C9D6],A ;01:C9D6                 
	ld [$C9D7],A ;01:C9D7                 
	ld HL,$C9B9                           
	bit 2, [HL]                           
	jr Z,Addr_002B09                      
	bit 0, [HL]                           
	jr Z,Addr_002B09                      
	ld A,[$C707] ;01:C707                 
	and $20                               
	jr Z,Addr_002B2E                      
	jr Addr_002B12                        
    
Addr_002B09:
	xor A                                 
	ld [$C9E0],A ;01:C9E0                 
Addr_002B0D:
	ld A,$0E                              
	ldh [$FFD0],A                     
	ret                                   

;*****************************************
;* 
;*****************************************
Addr_002B12:
	ldh A,[$FFD1]                     
	and $DF                               
	ldh [$FFD1],A                     
	ld A,$0F                              
	ldh [$FFD0],A                     
	ld A,$08                              
	ld [$C9E0],A ;01:C9E0                 
	ld HL,$C90F                           
	inc [HL]                              
	ld A,[HL]                             
	cp $18                                
	jr C,Addr_002B49                      
	xor A                                 
	ld [HL],A                             
	jr Addr_002B49                        
    
;*****************************************
;* 
;*****************************************
Addr_002B2E:
	ldh A,[$FFD1]                     
	or $20                                
	ldh [$FFD1],A                     
	ld A,$0F                              
	ldh [$FFD0],A                     
	ld A,$F8                              
	ld [$C9E0],A ;01:C9E0                 
	ld HL,$C90F                           
	dec [HL]                              
	ld A,[HL]                             
	cp $FF                                
	jr NZ,Addr_002B49                     
	ld A,$17                              
	ld [HL],A                             
Addr_002B49:
	push AF                               
	ld A,[$C90E] ;01:C90E                 
	and $0F                               
	jr NZ,Addr_002B56                     
	ld A,$54                              
	call F_Addr_0002E7 ;01:02E7             
Addr_002B56:
	ld A,BANK_06                              
	call SWITHBANK1 ;01:108F             
	ld HL,Data_6_7CBE;Data_6_4024                           
	pop AF                                
	rst $20                               
	ld L,E                                
	ld H,D                                
	call SetupTile ;06:05ED             
	jp F_Addr_00109B ;06:109B               
    
;*****************************************
;* 36   
;*****************************************
SCR_36: 
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $08,$10                                
	scrFunc_36 $01                                
	scrFunc_1F $21                                
	scrFunc_1A                                
SCR_0_2B78:	
	scrFunc_03 Addr_002322                                
	scrFunc_10 SCR_0_2B81                                
	scrFunc_Call Addr_002354                                
SCR_0_2B81:	
	scrFunc_Call F_Addr_001FE5                                
	scrFunc_10 SCR_0_2B8D                                
	scrFunc_Call Addr_002122                                
	scrFunc_GotoSrc SCR_0_2B78                                
SCR_0_2B8D:	
	scrFunc_2C $28                                
	scrFunc_2B $00                                
	scrFunc_17                                
	scrFunc_2C $00                                
	scrFunc_Call F_Addr_001FE5                                
	scrFunc_10 SCR_0_2B8D                                
	scrFunc_Call Addr_002322                                
	scrFunc_10 SCR_0_2BA3                                
	scrFunc_GotoSrc SCR_0_2B78                              
SCR_0_2BA3:	
	scrFunc_PlaySnd $43                                
	scrFunc_Call Addr_002122                                
	scrFunc_Call Addr_002BB2                                
	scrFunc_Call Addr_00216C                                
	scrFunc_1B                                
	scrFunc_GotoSrc SCR_0_1F98                                
        
;*****************************************
;* 
;*****************************************
Addr_002BB2:
	ldh A,[$FFCB]                     
	sub $04                               
	ld [$C9F4],A ;01:C9F4                 
	ldh A,[$FFCD]                     
	ld [$C9F3],A ;01:C9F3                 
	ld A,$FD                              
	jp F_Addr_001F40 ;01:1F40               
    
;*****************************************
;* 37  ??????
;*****************************************
SCR_37:  
	scrFunc_13 SCR_0_2BE0                                
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_MemSet $01,$01,$FFDC                                
	scrFunc_34 $06,$20                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $33                                
	scrFunc_1A                                
SCR_0_2BDA:	
	scrFunc_03 Addr_002BEC                                
	scrFunc_GotoSrc SCR_0_2BDA                                
SCR_0_2BE0:	
	scrFunc_05 $04,SCR_0_2BE7                                
	scrFunc_GotoSrc SCR_0_2178                                
SCR_0_2BE7:	
	scrFunc_2A $F0                                
	scrFunc_GotoSrc SCR_0_2178                                
        
;*****************************************
;* 
;*****************************************
Addr_002BEC:
	ldh A,[$FFE0]                     
	and A                                 
	ret Z                                 
	ld A,$FF                             
	ld [$C9D8],A ;00:C9D8                             
	ret                             
    
;*****************************************
;* 38  ??????
;*****************************************
SCR_38:  
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_34 $08,$18                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $0D                                
	scrFunc_1A                                
SCR_0_2C05:	
	scrFunc_Call Addr_002C0E                                
	scrFunc_03 Addr_002C18                                
	scrFunc_GotoSrc SCR_0_2C05                                
        
;*****************************************
;* 
;*****************************************
Addr_002C0E:
	ld DE,$0260                           
	ld HL,$0380                           
	call F_Addr_00275C ;01:275C             
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002C18:
	ldh A,[$FFDE]                     
	ld B,A                                
	ld C,$00                              
	ld HL,$C9E2                           
	add HL,BC                             
	ld A,[HL]                             
	and A                                 
	jr Z,Addr_002C2B                      
	ldh [$FFD2],A                     
	call F_Addr_0016B0 ;01:16B0             
	ret                                   
Addr_002C2B:
	ldh A,[$FFE0]                     
	and A                                 
	jr NZ,Addr_002C3E                     
Addr_002C30:
	ldh A,[$FFDE]                     
	ld B,A                                
	ld C,$00                              
	ld HL,$C9E7                           
	add HL,BC                             
	xor A                                 
	ld [HL],A                             
	ldh [$FFD2],A                     
	ret                                   
    
Addr_002C3E:
	call F_Addr_002E44 ;01:2E44             
	jr C,Addr_002C4A                      
	ld A,$FF                              
	ld [$C9D8],A ;01:C9D8                 
	jr Addr_002C30                        
    
Addr_002C4A:
	call F_Addr_001FE5 ;01:1FE5             
	jr C,Addr_002C30                      
	ld A,$08                              
	ldh [$FFD2],A                     
	ld [$C9D2],A ;01:C9D2                 
	ldh A,[$FFD4]                     
	ld [$C9D3],A ;01:C9D3                 
	ldh A,[$FFDE]                     
	ld B,A                                
	ld C,$00                              
	ld HL,$C9E7                           
	add HL,BC                             
	ld A,$F8                              
	ld [HL],A                             
	call F_Addr_0016B0 ;01:16B0             
	ld A,[$C90E] ;01:C90E                 
	and $0F                               
	ret NZ                                
	ld A,$51                              
	jp F_Addr_0002E7 ;01:02E7               
    
;*****************************************
;* 53  ?????? 
;*****************************************
SCR_53:  
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_34 $08,$18                                
	scrFunc_36 $01                                
	scrFunc_1E $01                                
	scrFunc_1F $0D                                
	scrFunc_1A                                
SCR_0_2C84:	
	scrFunc_Call Addr_002C8D                                
	scrFunc_03 Addr_002C18                                
	scrFunc_GotoSrc SCR_0_2C84                                
        
;*****************************************
;* 
;*****************************************
Addr_002C8D:
	ld DE,$0410                           
	ld HL,$0530                           
	call F_Addr_00275C ;01:275C             
	ret                                   
    
;*****************************************
;* 54  ?????? 
;*****************************************
SCR_54: 
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_34 $08,$18                                
	scrFunc_36 $02                                
	scrFunc_1E $01                                
	scrFunc_1F $0D                                
	scrFunc_1A                                
SCR_0_2CA6:	
	scrFunc_Call Addr_002CAF                                
	scrFunc_03 Addr_002C18                                
	scrFunc_GotoSrc SCR_0_2CA6                                
        
;*****************************************
;* 
;*****************************************
Addr_002CAF:
	ld DE,$04B0                           
	ld HL,$05D0                           
	call F_Addr_00275C ;01:275C             
	ret                                   
    
;*****************************************
;* 39   
;*****************************************
SCR_39:  
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $04,$0E                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1A                                
SCR_0_2CC6:	
	scrFunc_03 Addr_002CF3                                
	scrFunc_GotoSrc SCR_0_2CC6                                
        
;*****************************************
;* 
;*****************************************
SCR_0_2CCC:
	scrFunc_13 SCR_0_2178                                
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $08,$10                                
	scrFunc_36 $00                                
	scrFunc_2B $D8                                
	scrFunc_2C $00                                
	scrFunc_2A $0E                                
	scrFunc_29 $EC                                
	scrFunc_1E $01                                
	scrFunc_1F $09                                
	scrFunc_21                                
	scrFunc_1A                                
	scrFunc_PlaySnd $53                                
SCR_0_2CE9:	
	scrFunc_17                                
	scrFunc_Call F_Addr_002046                                
	scrFunc_10 SCR_0_2CE9                                
	scrFunc_GotoSrc SCR_0_2178                              
        
;*****************************************
;* 
;*****************************************
Addr_002CF3:
	ld HL,$FFE3                           
	ld A,[HL]                             
	and A                                 
	jr Z,Addr_002CFB                      
	dec [HL]                              
Addr_002CFB:
	ldh A,[$FFE0]                     
	and A                                 
	jr Z,Addr_002D3C                      
	call F_Addr_0026AD ;01:26AD             
	jr NZ,Addr_002D3C                     
	ldh A,[$FFCD]                     
	ld B,A                                
	ld A,[$C703] ;01:C703                 
	cp B                                  
	jr NC,Addr_002D17                     
	ld A,[$C707] ;01:C707                 
	and $20                               
	jr Z,Addr_002D20                      
	jr Addr_002D3C                             
Addr_002D17:
	ld A,[$C707] ;01:C707                 
	and $20                               
	jr NZ,Addr_002D20                     
	jr Addr_002D3C                             
Addr_002D20:
	ld A,$FF                              
	ld [$C9D6],A ;01:C9D6                 
	ld [$C9D7],A ;01:C9D7                 
	ld HL,$C9B9                           
	bit 2, [HL]                           
	jr Z,Addr_002D3C                      
	bit 0, [HL]                           
	jr Z,Addr_002D3C                      
	ld A,[$C707] ;01:C707                 
	and $20                               
	jr Z,Addr_002D64                      
	jr Addr_002D44                        
Addr_002D3C:
	xor A                                 
	ldh [$FFE2],A                     
	ld A,$07                              
	ldh [$FFD0],A                     
	ret                                   
    
Addr_002D44:
	ldh A,[$FFE2]                     
	and A                                 
	ret NZ                                
	ldh A,[$FFD1]                     
	and $DF                               
	ldh [$FFD1],A                     
	ld A,$08                              
	ldh [$FFD0],A                     
	ldh [$FFE2],A                     
	ldh A,[$FFE3]                     
	and A                                 
	ret NZ                                
	ld A,$1E                              
	ldh [$FFE3],A                     
	ld B, $03                             
	ld DE,SCR_0_2CCC                           
	jp Addr_001487 ;01:1487               
    
;*****************************************
;* 
;*****************************************
Addr_002D64:
	ldh A,[$FFD1]                              
	or $20                             
	ldh [$FFD1],A                             
	ld A,$08                             
	ldh [$FFD0],A                             
	ret                             
    
;*****************************************
;* 3A  ??????
;*****************************************
SCR_3a: 
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_34 $07,$0F                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $18                                
	scrFunc_1A                                
SCR_0_2D7E:	
	scrFunc_Call Addr_002D87                                
	scrFunc_03 Addr_002D96                                
	scrFunc_GotoSrc SCR_0_2D7E                                
        
;*****************************************
;* 
;*****************************************
Addr_002D87:
	ld DE,$00F0                           
	ld HL,$0380                           
	call F_Addr_00275C ;01:275C             
	ret NC                                
	xor A                                 
	ld [$C9EE],A ;01:C9EE                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002D96:
	ldh A,[$FFE0]                     
	and A                                 
	jr NZ,Addr_002DB3                     
    
;*****************************************
;* 
;*****************************************
Addr_002D9B:
	ld HL,$FFE2                           
	ld A,[HL]                             
	and A                                 
	jr NZ,Addr_002DAB                     
	ldh A,[$FFDE]                     
	ld HL,Data_0_2E3E                           
	rst $18                               
	ldh [$FFCB],A                     
	ret                                   
    
Addr_002DAB:
	dec [HL]                              
	ld A,$F8                              
	ldh [$FFD2],A                     
	jp F_Addr_0016B0 ;01:16B0               
    
;*****************************************
;* 
;*****************************************
Addr_002DB3:
	call F_Addr_002E44 ;01:2E44             
	jr C,Addr_002DBF                      
	ld A,$FF                              
	ld [$C9D8],A ;01:C9D8                 
	jr Addr_002D9B                        
    
Addr_002DBF:
	ld HL,$FFE2                           
	ld A,[HL]                             
	cp $20                                
	jr NC,Addr_002DD8                     
	inc [HL]                              
	ld A,$08                              
	ldh [$FFD2],A                     
	ld [$C9D2],A ;01:C9D2                 
	ldh A,[$FFD4]                     
	ld [$C9D3],A ;01:C9D3                 
	call F_Addr_0016B0 ;01:16B0             
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_002DD8:
	ldh A,[$FFDE]                     
	ld HL,Data_0_2E40                           
	rst $18                               
	ldh [$FFCB],A                     
	ld A,[$C9EE] ;01:C9EE                 
	and A                                 
	ret NZ                                
	ld A,$38                              
	call F_Addr_0002E7 ;01:02E7             
	ld A,$FF                              
	ld [$C9EE],A ;01:C9EE                 
	ld B, $08                             
	call F_Addr_000D03 ;01:0D03             
	ld A,$A0                              
	ldh [$FF95],A                     
	ldh A,[$FFDE]                     
	ld HL,Data_0_2E42                           
	rst $18                               
	ldh [$FF94],A                     
	ld A,$8C                              
	call F_Addr_001F5C ;01:1F5C             
	ldh A,[$FF94]                     
	add A,$10                             
	ldh [$FF94],A                     
	ld A,$8C                              
	call F_Addr_001F5C ;01:1F5C             
	ld B, $05                             
Addr_002E12:
	push BC                               
	ld A,$3F                              
	call F_Addr_0002E7 ;01:02E7             
	ld B, $08                             
	call F_Addr_000D03 ;01:0D03             
	ldh A,[$FF95]                     
	add A,$10                             
	ldh [$FF95],A                     
	ldh A,[$FF94]                     
	sub $10                               
	ldh [$FF94],A                     
	ld A,$8D                              
	call F_Addr_001F5C ;01:1F5C             
	ldh A,[$FF94]                     
	add A,$10                             
	ldh [$FF94],A                     
	ld A,$8D                              
	call F_Addr_001F5C ;01:1F5C             
	pop BC                                
	dec B                                 
	jr NZ,Addr_002E12                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
Data_0_2E3E:
	DB $40                                
	DB $60                                
;*****************************************
Data_0_2E40:
	DB $50                                
	DB $70                                
;*****************************************
Data_0_2E42:
	DB $F0                                
	DB $00                                
    
;*****************************************
;* 
;*****************************************
F_Addr_002E44:
	ld A,[$C9B9] ;01:C9B9                 
	bit 3, A                              
	jr NZ,Addr_002E5F                     
	bit 4, A                              
	jr NZ,Addr_002E5F                     
	ldh A,[$FFDA]                     
	ld B,A                                
	ldh A,[$FFCB]                     
	sub B                                 
	inc A                                 
	ld B,A                                
	ld A,[$C701] ;01:C701                 
	cp B                                  
	jr Z,Addr_002E61                      
	jr C,Addr_002E61                      
Addr_002E5F:
	xor A                                 
	ret                                   
Addr_002E61:
	scf                                   
	ret                                   
    
;*****************************************
;* 4E   
;*****************************************
SCR_4e:  
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_34 $07,$0F                                
	scrFunc_36 $01                                
	scrFunc_1E $01                                
	scrFunc_1F $18                                
	scrFunc_1A                                
	scrFunc_GotoSrc SCR_0_2D7E                                
        
;*****************************************
;* 
;*****************************************
SCR_0_2E75:
	scrFunc_MemSet $06,$01,$FFDD                                
	scrFunc_34 $08,$08                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1A                                
    scrFunc_1F $25                                
	scrFunc_Delay $08                                
	scrFunc_1F $26                                
	scrFunc_Delay $08                                
	scrFunc_PlaySnd $5D                                
	scrFunc_Call F_Addr_002172                                
	scrFunc_1F $27                                
	scrFunc_Delay $08                                
	scrFunc_1F $28                                
	scrFunc_Delay $78                                
	scrFunc_1F $27                                
	scrFunc_Delay $08                                
	scrFunc_Call Addr_00216C                                
	scrFunc_1F $26                                
	scrFunc_Delay $08                                
	scrFunc_1F $25                                
	scrFunc_Delay $08                                
	scrFunc_00                                
    
;*****************************************
;* 3B   
;*****************************************
SCR_3b:  
	scrFunc_36 $00                                
SCR_0_2EA9:	
	scrFunc_34 $07,$10                                
	scrFunc_1E $01                                
	scrFunc_1F $31                                
	scrFunc_1A                                
SCR_0_2EB1:	
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_03 Addr_002EF3                                
	scrFunc_IF_NZ SCR_0_2EB1                                
SCR_0_2EBC:    
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_Call Addr_002F56                                
	scrFunc_IF_NZ SCR_0_2EB1                                
SCR_0_2EC7:   
	scrFunc_03 Addr_002EF3                                
	scrFunc_0D $5A,SCR_0_2EC7                                
	scrFunc_Call Addr_002ED7                                
	scrFunc_IF_NZ SCR_0_2EBC                                
	scrFunc_GotoSrc SCR_0_2EB1                                
        
;*****************************************
;* 
;*****************************************
Addr_002ED7:
	ld HL,$FFE3                           
	inc [HL]                              
	ldh A,[$FFDE]                     
	ld HL,Data_0_3020                           
	rst $20                               
	ld L,E                                
	ld H,D                                
	ldh A,[$FFE3]                     
	rst $18                               
	cp $FF                                
	jp NZ,F_Addr_0014A9 ;01:14A9            
	xor A                                 
	ldh [$FFE3],A                     
	ldh [$FFE4],A                     
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 
;*****************************************
Addr_002EF3:
	ldh A,[$FFE0]                     
	and A                                 
	jr NZ,Addr_002F15                     
Addr_002EF8:
	ld HL,$FFE2                           
	ld A,[HL]                             
	and A                                 
	jr NZ,Addr_002F0A                     
	ldh A,[$FFDE]                     
	ld HL,Data_0_2FAE                           
	rst $18                               
	ldh [$FFCB],A                     
	jp Addr_001FA4 ;01:1FA4               
    
Addr_002F0A:
	dec [HL]                              
	ld A,$F8                              
	ldh [$FFD2],A                     
	call F_Addr_0016B0 ;01:16B0             
	jp Addr_001FA4 ;01:1FA4               

Addr_002F15:
	call F_Addr_002E44 ;01:2E44             
	jr C,Addr_002F21                      
	ld A,$FF                              
	ld [$C9D8],A ;01:C9D8                 
	jr Addr_002EF8                        
    
Addr_002F21:
	ld HL,$FFE2                           
	ld A,[HL]                             
	cp $20                                
	jr NC,Addr_002F3C                     
	inc [HL]                              
	ld A,$08                              
	ldh [$FFD2],A                     
	ld [$C9D2],A ;01:C9D2                 
	ldh A,[$FFD4]                     
	ld [$C9D3],A ;01:C9D3                 
	call F_Addr_0016B0 ;01:16B0             
	jp Addr_001FA4 ;01:1FA4               
    
Addr_002F3C:
	ldh A,[$FFDE]                     
	ld HL,Data_0_2FB5                           
	rst $18                               
	ldh [$FFCB],A                     
	ldh A,[$FFE4]                     
	and A                                 
	jp NZ,Addr_001FA0 ;01:1FA0            
	ld A,$38                              
	call F_Addr_0002E7 ;01:02E7             
	ld A,$FF                              
	ldh [$FFE4],A                     
	jp Addr_001FA0 ;01:1FA0               
    
;*****************************************
;* 
;*****************************************
Addr_002F56:
	ldh A,[$FFDE]                     
	ld HL,Data_0_3020                           
	rst $20                               
	ld L,E                                
	ld H,D                                
	ldh A,[$FFE3]                     
	rst $18                               
	ldh [$FFA8],A                     
	xor A                                 
	ldh [$FFA9],A                     
	ldh A,[$FFDE]                     
	ld HL,Data_0_2FBC                           
	rst $20                               
	ld L,E                                
	ld H,D                                
	ldh A,[$FFE3]                     
	rst $20                               
	ld A,[LVLPOS_XL] ;01:C0AB                 
	ld C,A                                
	ld A,E                                
	sub C                                 
	ldh [$FFAA],A                     
	ld A,[LVLPOS_XH] ;01:C0AC                 
	ld C,A                                
	ld A,D                                
	sbc A,C                               
	ldh [$FFAB],A                     
	and A                                 
	jr Z,Addr_002F8A                      
	cp $FF                                
	jr Z,Addr_002F92                      
	jr Addr_002F98                        
    
Addr_002F8A:
	ldh A,[$FFAA]                     
	cp $E0                                
	jr NC,Addr_002F98                     
	jr Addr_002F9E                        
    
Addr_002F92:
	ldh A,[$FFAA]                     
	cp $C0                                
	jr NC,Addr_002F9E                     
Addr_002F98:
	xor A                                 
	ldh [$FFE3],A                     
	jp Addr_001FA4 ;01:1FA4               
Addr_002F9E:
	ld B, $07                             
	ld DE,SCR_0_2E75                           
	xor A                                 
	ldh [$FFAC],A                     
	ldh [$FFAD],A                     
	call F_Addr_00149B ;01:149B             
	jp Addr_001FA0 ;01:1FA0               
    
;*****************************************
;* 
;*****************************************
Data_0_2FAE:
	DB $60                                ; 0X002FAE 00:2FAE 60 60 60; ld H,B
	DB $60                                ; 0X002FAF 00:2FAF 60 60 70; ld H,B
	DB $60                                ; 0X002FB0 00:2FB0 60 70 60; ld H,B
	DB $70                                ; 0X002FB1 00:2FB1 70 60 60; ld [HL],B
	DB $60                                ; 0X002FB2 00:2FB2 60 60 60; ld H,B
	DB $60                                ; 0X002FB3 00:2FB3 60 60 70; ld H,B
	DB $60                                ; 0X002FB4 00:2FB4 60 70 70; ld H,B
;*****************************************
Data_0_2FB5:
	DB $70                                ; 0X002FB5 00:2FB5 70 70 70; ld [HL],B
	DB $70                                ; 0X002FB6 00:2FB6 70 70 80; ld [HL],B
	DB $70                                ; 0X002FB7 00:2FB7 70 80 70; ld [HL],B
	DB $80                              ;*; 0X002FB8 00:2FB8 80 70 70; add A,B
	DB $70                                ; 0X002FB9 00:2FB9 70 70 70; ld [HL],B
	DB $70                                ; 0X002FBA 00:2FBA 70 70 CA; ld [HL],B
	DB $70                                ; 0X002FBB 00:2FBB 70 CA 2F; ld [HL],B
    
;*****************************************
;* 
;*****************************************
Data_0_2FBC:
	DW D_0_2FCA                                ; 0X002FBC 00:2FBC CA 2F D0; jp Z,Addr_00D02F ;00:D02F
	DW D_0_2FD0                                ; 0X002FBE 00:2FBE D0 2F D6; ret NC
	DW D_0_2FD6                                ; 0X002FC0 00:2FC0 D6 2F EE; sub $2F
	DW D_0_2FEE                              ;*; 0X002FC2 00:2FC2 EE 2F 06; xor $2F
	DW D_0_3006                                ; 0X002FC4 00:2FC4 06 30 0C; ld B, $30
	DW D_0_300C                                ; 0X002FC6 00:2FC6 0C 30 12; inc C
	DW D_0_3012                                ; 0X002FC8 00:2FC8 12 30 38; ld [DE],A
;*****************************************
D_0_2FCA:
	DB $38,$03                                ; 0X002FCB 00:2FCB 03 58 03; inc BC
	DB $58,$03                                ; 0X002FCD 00:2FCD 03 88 03; inc BC
	DB $88,$03                                ; 0X002FCF 00:2FCF 03 88 03; inc BC
;*****************************************
D_0_2FD0:
	DB $88,$03                                ; 0X002FD1 00:2FD1 03 58 03; inc BC
	DB $58,$03                                ; 0X002FD3 00:2FD3 03 38 03; inc BC
	DB $38,$03                              ;*; 0X002FD5 00:2FD5 03 48 04; inc BC
;*****************************************
D_0_2FD6:
	DB $48,$04                                ; 0X002FD7 00:2FD7 04 78 04; inc B
	DB $78,$04                                ; 0X002FD9 00:2FD9 04 68 04; inc B
	DB $68,$04                                ; 0X002FDB 00:2FDB 04 98 04; inc B
	DB $98,$04                                ; 0X002FDD 00:2FDD 04 B8 04; inc B
	DB $B8,$04                                ; 0X002FDF 00:2FDF 04 D8 04; inc B
	DB $D8,$04                                ; 0X002FE1 00:2FE1 04 08 05; inc B
	DB $08,$05                                ; 0X002FE3 00:2FE3 05 28 05; dec B
	DB $28,$05                                ; 0X002FE5 00:2FE5 05 68 05; dec B
	DB $68,$05                                ; 0X002FE7 00:2FE7 05 90 05; dec B
	DB $90,$05                                ; 0X002FE9 00:2FE9 05 B8 05; dec B
	DB $B8,$05                                ; 0X002FEB 00:2FEB 05 E8 05; dec B
	DB $E8,$05                                ; 0X002FED 00:2FED 05 E8 05; dec B
;*****************************************
D_0_2FEE:
	DB $E8,$05                              ;*; 0X002FEF 00:2FEF 05 B8 05; dec B
	DB $B8,$05                              ;*; 0X002FF1 00:2FF1 05 90 05; dec B
	DB $90,$05                              ;*; 0X002FF3 00:2FF3 05 68 05; dec B
	DB $68,$05                              ;*; 0X002FF5 00:2FF5 05 28 05; dec B
	DB $28,$05                              ;*; 0X002FF7 00:2FF7 05 08 05; dec B
	DB $08,$05                              ;*; 0X002FF9 00:2FF9 05 D8 04; dec B
	DB $D8,$04                              ;*; 0X002FFB 00:2FFB 04 B8 04; inc B
	DB $B8,$04                              ;*; 0X002FFD 00:2FFD 04 98 04; inc B
	DB $98,$04                              ;*; 0X002FFF 00:2FFF 04 68 04; inc B
	DB $68,$04                              ;*; 0X003001 00:3001 04 78 04; inc B
	DB $78,$04                              ;*; 0X003003 00:3003 04 48 04; inc B
	DB $48,$04                              ;*; 0X003005 00:3005 04 D8 03; inc B
;*****************************************
D_0_3006:
	DB $D8,$03                                ; 0X003007 00:3007 03 00 04; inc BC
	DB $00,$04                                ; 0X003009 00:3009 04 30 04; inc B
	DB $30,$04                                ; 0X00300B 00:300B 04 F8 06; inc B
;*****************************************
D_0_300C:
	DB $F8,$06                                ; 0X00300D 00:300D 06 28 07; ld B, $28
	DB $28,$07                                ; 0X00300F 00:300F 07 48 07; RLCA
	DB $48,$07                                ; 0X003011 00:3011 07 68 02; RLCA
;*****************************************
D_0_3012:
	DB $68,$02                                ; 0X003013 00:3013 02 88 02; ld [BC],A
	DB $88,$02                                ; 0X003015 00:3015 02 D8 02; ld [BC],A
	DB $D8,$02                                ; 0X003017 00:3017 02 08 03; ld [BC],A
	DB $08,$03                                ; 0X003019 00:3019 03 20 03; inc BC
	DB $20,$03                                ; 0X00301B 00:301B 03 88 03; inc BC
	DB $88,$03                                ; 0X00301D 00:301D 03 A8 03; inc BC
	DB $A8,$03                                ; 0X00301F 00:301F 03 2E 30; inc BC
    
;*****************************************
;* 
;*****************************************
Data_0_3020:
	DW D_0_302E                                ; 0X003020 00:3020 2E 30 32; ld L,$30
	DW D_0_3032                                ; 0X003022 00:3022 32 30 36; ld [HL-],A
	DW D_0_3036                                ; 0X003024 00:3024 36 30 43; ld [HL],$30
	DW D_0_3043                              ;*; 0X003026 00:3026 43 30 50; ld B,E
	DW D_0_3050                                ; 0X003028 00:3028 50 30 54; ld D,B
	DW D_0_3054                                ; 0X00302A 00:302A 54 30 58; ld D,H
	DW D_0_3058                                ; 0X00302C 00:302C 58 30 40; ld E,B
;*****************************************
D_0_302E:
	DB $40                                ; 0X00302E 00:302E 40 60 50; ld B,B
	DB $60                                ; 0X00302F 00:302F 60 50 FF; ld H,B
	DB $50                                ; 0X003030 00:3030 50 FF 50; ld D,B
	DB $FF                                ; 0X003031 00:3031 FF 50 60; rst $38
;*****************************************
D_0_3032:
	DB $50                                ; 0X003032 00:3032 50 60 40; ld D,B
	DB $60                                ; 0X003033 00:3033 60 40 FF; ld H,B
	DB $40                              ;*; 0X003034 00:3034 40 FF 60; ld B,B
	DB $FF                              ;*; 0X003035 00:3035 FF 60 40; rst $38
;*****************************************
D_0_3036:
	DB $60                                ; 0X003036 00:3036 60 40 70; ld H,B
	DB $40                                ; 0X003037 00:3037 40 70 78; ld B,B
	DB $70                                ; 0X003038 00:3038 70 78 60; ld [HL],B
	DB $78                                ; 0X003039 00:3039 78 60 70; ld A,B
	DB $60                                ; 0X00303A 00:303A 60 70 78; ld H,B
	DB $70                                ; 0X00303B 00:303B 70 78 70; ld [HL],B
	DB $78                                ; 0X00303C 00:303C 78 70 78; ld A,B
	DB $70                                ; 0X00303D 00:303D 70 78 78; ld [HL],B
	DB $78                                ; 0X00303E 00:303E 78 78 70; ld A,B
	DB $78                                ; 0X00303F 00:303F 78 70 60; ld A,B
	DB $70                                ; 0X003040 00:3040 70 60 FF; ld [HL],B
	DB $60                                ; 0X003041 00:3041 60 FF 60; ld H,B
	DB $FF                              ;*; 0X003042 00:3042 FF 60 70; rst $38
;*****************************************
D_0_3043:
	DB $60                              ;*; 0X003043 00:3043 60 70 78; ld H,B
	DB $70                              ;*; 0X003044 00:3044 70 78 78; ld [HL],B
	DB $78                              ;*; 0X003045 00:3045 78 78 70; ld A,B
	DB $78                              ;*; 0X003046 00:3046 78 70 78; ld A,B
	DB $70                              ;*; 0X003047 00:3047 70 78 70; ld [HL],B
	DB $78                              ;*; 0X003048 00:3048 78 70 60; ld A,B
	DB $70                              ;*; 0X003049 00:3049 70 60 78; ld [HL],B
	DB $60                              ;*; 0X00304A 00:304A 60 78 70; ld H,B
	DB $78                              ;*; 0X00304B 00:304B 78 70 40; ld A,B
	DB $70                              ;*; 0X00304C 00:304C 70 40 60; ld [HL],B
	DB $40                              ;*; 0X00304D 00:304D 40 60 FF; ld B,B
	DB $60                              ;*; 0X00304E 00:304E 60 FF 48; ld H,B
	DB $FF                              ;*; 0X00304F 00:304F FF 48 50; rst $38
;*****************************************
D_0_3050:
	DB $48                                ; 0X003050 00:3050 48 50 38; ld C,B
	DB $50                                ; 0X003051 00:3051 50 38 FF; ld D,B
	DB $38                                ; 0X003052 00:3052 38 FF 70; jr C,Addr_003053
	DB $FF                                ; 0X003053 00:3053 FF 70 78; rst $38
;*****************************************
D_0_3054:
	DB $70                                ; 0X003054 00:3054 70 78 60; ld [HL],B
	DB $78                                ; 0X003055 00:3055 78 60 FF; ld A,B
	DB $60                                ; 0X003056 00:3056 60 FF 60; ld H,B
	DB $FF                                ; 0X003057 00:3057 FF 60 40; rst $38
;*****************************************
D_0_3058:
	DB $60                                ; 0X003058 00:3058 60 40 50; ld H,B
	DB $40                                ; 0X003059 00:3059 40 50 40; ld B,B
	DB $50                                ; 0X00305A 00:305A 50 40 78; ld D,B
	DB $40                                ; 0X00305B 00:305B 40 78 60; ld B,B
	DB $78                                ; 0X00305C 00:305C 78 60 50; ld A,B
	DB $60                                ; 0X00305D 00:305D 60 50 FF; ld H,B
	DB $50                                ; 0X00305E 00:305E 50 FF 36; ld D,B
	DB $FF                                ; 0X00305F 00:305F FF 36 01; rst $38
    
;*****************************************
;* 48   
;*****************************************
SCR_48: 
	scrFunc_36 $01                                
	scrFunc_GotoSrc SCR_0_2EA9                                
        
;*****************************************
;* 49   
;*****************************************
SCR_49: 
	scrFunc_36 $02                                
	scrFunc_GotoSrc SCR_0_2EA9                                
    
;*****************************************
;* 4A   
;*****************************************
SCR_4a:  
	scrFunc_36 $03                                
	scrFunc_GotoSrc SCR_0_2EA9                                
    
;*****************************************
;* 4B   
;*****************************************
SCR_4b:  
	scrFunc_36 $04                                
	scrFunc_GotoSrc SCR_0_2EA9                                
    
;*****************************************
;* 4C   
;*****************************************
SCR_4c:  
	scrFunc_36 $05                                
	scrFunc_GotoSrc SCR_0_2EA9                                
    
;*****************************************
;* 4D  
;*****************************************
SCR_4d:  
	scrFunc_36 $06                                
	scrFunc_GotoSrc SCR_0_2EA9                                
    
;*****************************************
;* 3C      
;*****************************************
SCR_3c: 
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $0E,$08                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $13                                
	scrFunc_1A                                
	scrFunc_MemSet $04,$01,$FFE3                                
	scrFunc_MemSet $00,$01,$FFE4                                
SCR_0_3097:	
	scrFunc_03 Addr_00309D  ;---                          
	scrFunc_GotoSrc SCR_0_3097                                
        
;*****************************************
;* 
;*****************************************
Addr_00309D:
	ldh A,[$FFE0]                     
	and A                                 
	jr NZ,Addr_0030D9                     
Addr_0030A2:
	ldh A,[$FFDB]                     
	ld B,A                                
	ldh A,[$FFE3]                     
	ldh [$FFDB],A                     
	ldh A,[$FFDA]                     
	ld C,A                                
	ld A,$04                              
	ldh [$FFDA],A                     
	ldh A,[$FFCB]                     
	ld D,A                                
	add A,$08                             
	ldh [$FFCB],A                     
	push BC                               
	push DE                               
	ldh A,[$FFE4]                     
	ldh [$FFE0],A                     
	call F_Addr_004DBE ;01:4DBE             
	ldh A,[$FFE0]                     
	ldh [$FFE4],A                     
	pop DE                                
	pop BC                                
	ldh A,[$FFDB]                     
	ldh [$FFE3],A                     
	ld A,B                                
	ldh [$FFDB],A                     
	ld A,C                                
	ldh [$FFDA],A                     
	ld A,D                                
	ldh [$FFCB],A                     
	ldh A,[$FFE0]                     
	and A                                 
	jr NZ,Addr_0030E5                     
	ret                                   
Addr_0030D9:
	call F_Addr_002E44 ;01:2E44             
	jr NC,Addr_0030A2                     
	ld A,$04                              
	ldh [$FFE3],A                     
	xor A                                 
	ldh [$FFE4],A                     
Addr_0030E5:
	ld HL,$FFE2                           
	ld A,[HL]                             
	cp $80                                
	ret Z                                 
	inc [HL]                              
	ld A,$04                              
	ldh [$FFD2],A                     
	ld [$C9D2],A ;01:C9D2                 
	ldh A,[$FFD4]                     
	ld [$C9D3],A ;01:C9D3                 
	call F_Addr_0016B0 ;01:16B0             
	ld A,[$C90E] ;01:C90E                 
	and $07                               
	ret NZ                                
	ld A,$50                              
	jp F_Addr_0002E7 ;01:02E7               
    
;*****************************************
;* 
;*****************************************
SCR_3d: ; 3D  ?????? 
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $08,$20                                
	scrFunc_36 $00                                
	scrFunc_2C $F8                                
	scrFunc_1E $01                                
	scrFunc_1F $32                                
	scrFunc_26                                
	scrFunc_1A                                
	scrFunc_Call Addr_003130                                
	scrFunc_IF_NZ SCR_0_312F                              
SCR_0_311F:	
	scrFunc_03 Addr_003130                                
	scrFunc_IF_NZ SCR_0_3128                                
	scrFunc_GotoSrc SCR_0_311F                                
SCR_0_3128:	
	scrFunc_PlaySnd $5C                                
SCR_0_312A:	
	scrFunc_17                                
	scrFunc_0D $40,SCR_0_312A                                
SCR_0_312F:	
	scrFunc_00                                
    
;*****************************************
;* 
;*****************************************
Addr_003130:
	ldh A,[$FFE0]                     
	and A                                 
	jr Z,Addr_00313A                      
	ld A,$FF                             
	ld [$C9D8],A ;00:C9D8                             
Addr_00313A:
	ld A,[$C9F0] ;01:C9F0                 
	and A                                 
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 3E  ?????? 
;*****************************************
SCR_3e: 
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_34 $01,$10                                
	scrFunc_36 $01                                
	scrFunc_1E $01                                
	scrFunc_1F $19                                
	scrFunc_1A                                
SCR_0_3150:	
	scrFunc_Call Addr_00316E                                
	scrFunc_03 Addr_003180                                
	scrFunc_IF_NZ SCR_0_315C                                
	scrFunc_GotoSrc SCR_0_3150                                
SCR_0_315C:	
	scrFunc_2C $10                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_Call Addr_00318E                                
	scrFunc_2C $F0                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_17                                
	scrFunc_GotoSrc SCR_0_3150                                
        
;*****************************************
;* 
;*****************************************
Addr_00316E:
	ld DE,$0000                           
	ld HL,$0140                           
	call F_Addr_00275C ;01:275C             
	ret NC                                
	xor A                                 
	ld [$C9F1],A ;01:C9F1                 
	ld [$C9F0],A ;01:C9F0                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_003180:
	ldh A,[$FFE0]                     
	and A                                 
	jp Z,F_Addr_0014A9 ;01:14A9             
	ld A,[$C9B9] ;01:C9B9                 
	bit 5, A                              
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 
;*****************************************
Addr_00318E:
	ld A,[$C9F1] ;01:C9F1                 
	ld HL,Data_0_31B2                           
	rst $18                               
	ld B,A                                
	ldh A,[$FFDE]                     
	cp B                                  
	jr Z,Addr_0031A0                      
	xor A                                 
	ld [$C9F1],A ;01:C9F1                 
	ret                                   
Addr_0031A0:
	ld HL,$C9F1                           
	inc [HL]                              
	ld A,[HL]                             
	ld HL,Data_0_31B2                           
	rst $18                               
	cp $FF                                
	ret NZ                                
	ld A,$FF                              
	ld [$C9F0],A ;01:C9F0                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
Data_0_31B2:
	DB $03                                
	DB $03                                
	DB $01                                
	DB $01                                
	DB $01                                
	DB $01                                
	DB $02                                
	DB $FF                                
    
;*****************************************
;* 3F  ??????  
;*****************************************
SCR_3f: 
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_34 $01,$10                                
	scrFunc_36 $02                                
	scrFunc_1E $01                                
	scrFunc_1F $1A                                
	scrFunc_1A                                
	scrFunc_GotoSrc SCR_0_3150                                
        
;*****************************************
;* 40  ?????? 
;*****************************************
SCR_40: 
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_34 $01,$10                                
	scrFunc_36 $03                                
	scrFunc_1E $01                                
	scrFunc_1F $1B                                
	scrFunc_1A                                
	scrFunc_GotoSrc SCR_0_3150                                
        
;*****************************************
;* 42   
;*****************************************
SCR_42:   
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $05,$1F                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $12                                
	scrFunc_1A                                
SCR_0_31ED:	
	scrFunc_03 Addr_0031F3                                
	scrFunc_GotoSrc SCR_0_31ED                                
        
;*****************************************
;* 
;*****************************************
Addr_0031F3:
	ldh A,[$FFE0]                     
	and A                                 
	ret Z                                 
	call F_Addr_0026AD ;01:26AD             
	ret NZ                                
	ldh A,[$FFCD]                     
	ld B,A                                
	ld A,[$C703] ;01:C703                 
	cp B                                  
	jr NC,Addr_003229                     
	ld A,[$C707] ;00:C707                             
	and $20                             
	ret NZ                             
	ld A,$FF                             
	ld [$C9D6],A ;00:C9D6                             
	ld A,[$C9EF] ;00:C9EF                             
	and A                             
	jr NZ,Addr_00324D                             
	ld HL,$C9B9                             
	bit 2, [HL]                             
	ret Z                             
	ld A,[$C709] ;00:C709                             
	and A                             
	ret Z                             
	ld HL,$FFE2                             
	dec [HL]                             
	ldh [$FFD3],A                             
	jp F_Addr_0016BA ;00:16BA                             

Addr_003229:
	ld A,[$C707] ;01:C707                 
	and $20                               
	ret Z                                 
	ld A,$FF                              
	ld [$C9D6],A ;01:C9D6                 
	ld HL,$C9B9                           
	bit 2, [HL]                           
	ret Z                                 
	ld HL,$FFE2                           
	ld A,[HL]                             
	cp $30                                
	jr Z,Addr_00324D                      
	ld A,[$C709] ;01:C709                 
	and A                                 
	ret Z                                 
	inc [HL]                              
	ldh [$FFD3],A                     
	jp F_Addr_0016BA ;01:16BA               
    
Addr_00324D:
	ld A,$FF                              
	ld [$C9D7],A ;01:C9D7                 
	ld [$C9EF],A ;01:C9EF                 
	ret                                   
    
;*****************************************
;* 43 ?????? 
;*****************************************
SCR_43: 
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_03 Addr_00327B                                
	scrFunc_34 $10,$0C                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $1E                                
	scrFunc_1A                                
SCR_0_3268:	
	scrFunc_03 Addr_00326E                                
	scrFunc_GotoSrc SCR_0_3268                                
        
;*****************************************
;* 
;*****************************************
Addr_00326E:
	ldh A,[$FFE0]                     
	and A                                 
	ret Z                                 
	ld A,[$C9B9] ;00:C9B9                             
	bit 5, A                             
	jp Z,Addr_004C4D ;01:4C4D                            
	ret                             
    
;*****************************************
;* 
;*****************************************
Addr_00327B:
	ld A,[$C915] ;01:C915                 
	and A                                 
	jp NZ,Func00_00158C ;01:158C            
	ret                                   
    
;*****************************************
;* 44 - ??????
;*****************************************
SCR_44:  
	scrFunc_2B $0C                                
	scrFunc_GotoSrc SCR_0_328A                                
    
;*****************************************
;* 41     
;*****************************************
SCR_41: 
	scrFunc_2B $F4                                
SCR_0_328A:	
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $10,$10                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $23                                
	scrFunc_1A                                
SCR_0_3299:	
	scrFunc_03 Addr_0032D1                                
	scrFunc_IF_NZ SCR_0_3299                                
SCR_0_329F:	
	scrFunc_17                                
	scrFunc_Call Addr_0032BA                                
	scrFunc_Call Addr_0032E0                                
	scrFunc_Call Addr_0032EE                                
	scrFunc_10 SCR_0_32AF                                
	scrFunc_GotoSrc SCR_0_329F                                
SCR_0_32AF:	
	scrFunc_2C $08                                
	scrFunc_2B $00                                
SCR_0_32B3:	
	scrFunc_Call Addr_002149                                
	scrFunc_17                                
	scrFunc_GotoSrc SCR_0_32B3                                
        
;*****************************************
;* 
;*****************************************
Addr_0032BA:
	ld A,[$C90E] ;01:C90E                 
	and $07                               
	ret NZ                                
	ld A,$51                              
	call F_Addr_0002E7 ;01:02E7             
	ld HL,$FFD0                           
	ld A,[HL]                             
	cp $23                                
	jr Z,Addr_0032CF                      
	dec [HL]                              
	ret                                   
Addr_0032CF:
	inc [HL]                              
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_0032D1:
	ldh A,[$FFE0]                     
	and A                                 
	jp Z,Addr_001FA4 ;01:1FA4             
	call F_Addr_002E44 ;01:2E44             
	jp C,Addr_001FA0 ;01:1FA0             
	jp Addr_001FA4 ;01:1FA4               
    
;*****************************************
;* 
;*****************************************
Addr_0032E0:
	ldh A,[$FFE0]                     
	and A                                 
	ret Z                                 
	call F_Addr_002E44 ;01:2E44             
	ret NC                                
	ldh A,[$FFD3]                     
	ld [$C9D1],A ;01:C9D1                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_0032EE:
	ldh A,[$FFDB]                     
	dec A                                 
	ld B,A                                
	ldh A,[$FFCD]                     
	add A,B                               
	ld B,A                                
	ldh A,[$FFCB]                     
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $7F                                
	jp Z,Addr_001FA9 ;01:1FA9             
	cp $80                                
	jp Z,Addr_001FA9 ;01:1FA9             
	ldh A,[$FFDB]                     
	dec A                                 
	ld B,A                                
	ldh A,[$FFCD]                     
	sub B                                 
	ld B,A                                
	ldh A,[$FFCB]                     
	ld C,A                                
	call F_Addr_001E49 ;01:1E49             
	cp $7F                                
	jp Z,Addr_001FA9 ;01:1FA9             
	cp $80                                
	jp Z,Addr_001FA9 ;01:1FA9             
	jp Addr_001FAD ;01:1FAD               
    
;*****************************************
;* 45 - ??????
;*****************************************
SCR_45: 
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $10,$10                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $29                                
	scrFunc_1A                                
SCR_0_3330:	
	scrFunc_03 Addr_0032D1                                
	scrFunc_IF_NZ SCR_0_3330                                
	scrFunc_Delay $1E                                
SCR_0_3338:	
	scrFunc_03 Addr_00333E                                
	scrFunc_GotoSrc SCR_0_3338                                
        
;*****************************************
;* 
;*****************************************
Addr_00333E:
	ld HL,$FFD2                           
	inc [HL]                              
	ldh A,[$FFE0]                     
	and A                                 
	jp Z,F_Addr_0016B0 ;01:16B0             
	call F_Addr_002E44 ;01:2E44             
	jp NC,F_Addr_0016B0 ;01:16B0            
	ldh A,[$FFD2]                     
	ld [$C9D2],A ;01:C9D2                 
	ldh A,[$FFD4]                     
	ld [$C9D3],A ;01:C9D3                 
	jp F_Addr_0016B0 ;01:16B0               
    
;*****************************************
;* 60 
;*****************************************
SCR_60: 
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $08,$08                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $0B                                
	scrFunc_1A                                
SCR_0_336A:	
	scrFunc_03 Addr_00338D                                
	scrFunc_IF_NZ SCR_0_336A                                
SCR_0_3370:	
	scrFunc_2A $01                                
	scrFunc_Delay $04                                
	scrFunc_2A $FF                                
	scrFunc_Delay $04                                
	scrFunc_0D $08,SCR_0_3370                                
	scrFunc_Call Addr_003396                                
	scrFunc_MemSet $04,$01,$FFCA                                
	scrFunc_2C $08                                
SCR_0_3386:	
	scrFunc_17                                
	scrFunc_Call Addr_002149                                
	scrFunc_GotoSrc SCR_0_3386                                
        
;*****************************************
;* 
;*****************************************
Addr_00338D:
	ldh A,[$FFE0]                     
	and A                                 
	jp Z,Addr_001FA4 ;01:1FA4             
	jp Addr_001FA0 ;01:1FA0               
    
;*****************************************
;* 
;*****************************************
Addr_003396:
	ldh A,[$FFE0]                     
	and A                                 
	ret Z                                 
	ld HL,$C9B9                         
	res 7, [HL]                         
	ret                                 
    
;*****************************************
;* 61    ??????
;*****************************************
SCR_61: 
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_34 $05,$08                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $0C                                
	scrFunc_1A                                
SCR_0_33AF:	
	scrFunc_Call Addr_002C0E                                
	scrFunc_03 Addr_0033B8                                
	scrFunc_GotoSrc SCR_0_33AF                                
        
;*****************************************
;* 
;*****************************************
Addr_0033B8:
	ldh A,[$FFDE]                     
	ld B,A                                
	ld C,$00                              
	ld HL,$C9E7                           
	add HL,BC                             
	ld A,[HL]                             
	and A                                 
	jr Z,Addr_0033CB                      
	ldh [$FFD2],A                     
	call F_Addr_0016B0 ;01:16B0             
	ret                                   
Addr_0033CB:
	ldh A,[$FFE0]                     
	and A                                 
	jr NZ,Addr_0033DE                     
Addr_0033D0:
	ldh A,[$FFDE]                     
	ld B,A                                
	ld C,$00                              
	ld HL,$C9E2                           
	add HL,BC                             
	xor A                                 
	ld [HL],A                             
	ldh [$FFD2],A                     
	ret                                   
Addr_0033DE:
	ldh A,[$FFCB]                     
	cp $60                                
	jr NC,Addr_0033D0                     
	ld A,$08                              
	ldh [$FFD2],A                     
	ld [$C9D2],A ;01:C9D2                 
	ldh A,[$FFD4]                     
	ld [$C9D3],A ;01:C9D3                 
	ldh A,[$FFDE]                     
	ld B,A                                
	ld C,$00                              
	ld HL,$C9E2                           
	add HL,BC                             
	ld A,$F8                              
	ld [HL],A                             
	call F_Addr_0016B0 ;01:16B0             
	ld A,[$C90E] ;01:C90E                 
	and $0F                               
	ret NZ                                
	ld A,$51                              
	jp F_Addr_0002E7 ;01:02E7               
    
;*****************************************
;* 63  ??????
;*****************************************
SCR_63:   
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_34 $05,$08                                
	scrFunc_36 $01                                
	scrFunc_1E $01                                
	scrFunc_1F $0C                                
	scrFunc_1A                                
SCR_0_3419:	
	scrFunc_Call Addr_002C8D                                
	scrFunc_03 Addr_0033B8                                
	scrFunc_GotoSrc SCR_0_3419                                
        
;*****************************************
;* 64  ?????? 
;*****************************************
SCR_64:  
	scrFunc_MemSet $02,$01,$FFDD                                
	scrFunc_34 $05,$08                                
	scrFunc_36 $02                                
	scrFunc_1E $01                                
	scrFunc_1F $0C                                
	scrFunc_1A                                
SCR_0_3431:	
	scrFunc_Call Addr_002CAF                                
	scrFunc_03 Addr_0033B8                                
	scrFunc_GotoSrc SCR_0_3431                                
    
;*****************************************
;* 62 ?
;*****************************************
SCR_62:  
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $08,$05                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $2A                                
	scrFunc_2B $F8                                
	scrFunc_1A                                
SCR_0_344B:	
	scrFunc_03 Addr_00338D                                
	scrFunc_IF_NZ SCR_0_344B                                
SCR_0_3451:	
	scrFunc_Call F_Addr_002046                                
	scrFunc_10 SCR_0_345A                                
	scrFunc_Call F_Addr_002129                                
SCR_0_345A:	
	scrFunc_Call Addr_003465                                
	scrFunc_Call Addr_00347C                                
	scrFunc_01                                
	scrFunc_18                                
	scrFunc_GotoSrc SCR_0_3451                                
        
;*****************************************
;* 
;*****************************************
Addr_003465:
	ld A,[$C90E] ;01:C90E                 
	and $07                               
	ret NZ                                
	ld A,$51                              
	call F_Addr_0002E7 ;01:02E7             
	ld HL,$FFD0                           
	ld A,[HL]                             
	cp $2A                                
	jr Z,Addr_00347A                      
	dec [HL]                              
	ret                                   
Addr_00347A:
	inc [HL]                              
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_00347C:
	ldh A,[$FFE0]                     
	and A                                 
	ret Z                                 
	ldh A,[$FFD3]                     
	ld [$C9D1],A ;01:C9D1                 
	ret                                   

;*****************************************
;* 73 ???
;*****************************************
SCR_73: 
	scrFunc_22                                
;*****************************************
;* 68  ??
;*****************************************
SCR_68: 
	scrFunc_13 SCR_0_349F                                
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_MemSet $01,$01,$C91C                                
	scrFunc_34 $06,$10                                
	scrFunc_36 $00                                
	scrFunc_1F $23                                
	scrFunc_1A                                
	scrFunc_GotoSrc SCR_0_1F98                                
SCR_0_349F:	
	scrFunc_MemSet $01,$01,$C9F2                                
	scrFunc_Call Addr_00216C                                
	scrFunc_GotoSrc SCR_0_1F98                                

;*****************************************
;* ?????
;*****************************************
SCR_74: 
	scrFunc_22                              
;*****************************************
;* 69 
;*****************************************
SCR_69:  
	scrFunc_13 SCR_0_34BE                                
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $06,$10                                
	scrFunc_36 $00                                
	scrFunc_1F $25                                
	scrFunc_1A                                
	scrFunc_GotoSrc SCR_0_1F98                                
SCR_0_34BE:	
	scrFunc_MemSet $02,$01,$C9F2                                
	scrFunc_Call Addr_00216C                                
	scrFunc_GotoSrc SCR_0_1F98                                

;*****************************************
;* ????
;*****************************************
SCR_75: 
	scrFunc_22                              
;*****************************************
;* 6A 
;*****************************************
SCR_6a: 
	scrFunc_13 SCR_0_34DD                                
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $06,$10                                
	scrFunc_36 $00                                
	scrFunc_1F $25                                
	scrFunc_1A                                
	scrFunc_GotoSrc SCR_0_1F98                                
SCR_0_34DD:	
	scrFunc_MemSet $03,$01,$C9F2                                
	scrFunc_Call Addr_00216C                                
	scrFunc_GotoSrc SCR_0_1F98                                

;*****************************************
;* 76 
;*****************************************
SCR_76: 
	scrFunc_22                                
;*****************************************
;* 6B 
;*****************************************
SCR_6b: 
	scrFunc_13 SCR_0_34FC                                
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $06,$10                                
	scrFunc_36 $00                                
	scrFunc_1F $25                                
	scrFunc_1A                                
	scrFunc_GotoSrc SCR_0_1F98                                
SCR_0_34FC:	
	scrFunc_MemSet $04,$01,$C9F2                                
	scrFunc_Call Addr_00216C                                
	scrFunc_GotoSrc SCR_0_1F98                                

;*****************************************
;* 
;*****************************************
SCR_77: ;????
	scrFunc_22                              
;*****************************************
;* 6C 
;*****************************************
SCR_6c: 
	scrFunc_13 SCR_0_351B                                
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $06,$10                                
	scrFunc_36 $00                                
	scrFunc_1F $25                                
	scrFunc_1A                                
	scrFunc_GotoSrc SCR_0_1F98                                
SCR_0_351B:	
	scrFunc_MemSet $05,$01,$C9F2                                
	scrFunc_Call Addr_00216C                                
	scrFunc_GotoSrc SCR_0_1F98                                

;*****************************************
;* 78 ?
;*****************************************
SCR_78: 
	scrFunc_22                                
;*****************************************
; 6D ?  
SCR_6d: 
	scrFunc_Call Addr_00354B                                
	scrFunc_13 SCR_0_353D                                
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $06,$10                                
	scrFunc_36 $00                                
	scrFunc_1F $26                                
	scrFunc_1A                                
	scrFunc_GotoSrc SCR_0_1F98                                
SCR_0_353D:	
	scrFunc_MemSet $06,$01,$C9F2                                
	scrFunc_Call Addr_00216C                                
	scrFunc_Call Addr_003558                                
	scrFunc_GotoSrc SCR_0_1F98                                
        
;*****************************************
;* 
;*****************************************
Addr_00354B:
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	ld HL,Data_0_3563                           
	rst $20                               
	ld A,[DE]                             
	and A                                 
	jp NZ,Func00_00158C ;01:158C            
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_003558:
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	ld HL,Data_0_3563                           
	rst $20                               
	ld A,$FF                              
	ld [DE],A                             
	ret                                   
    
;*****************************************
;* 
;*****************************************
Data_0_3563:
	DW MEM_FERRULE_1                                ; 0X003563 00:3563 1D C9 1E; dec E
	DW MEM_FERRULE_2                                ; 0X003565 00:3565 1E C9 1E; ld E,$C9
	DW MEM_FERRULE_2                              ;*; 0X003567 00:3567 1E C9 1F; ld E,$C9
	DW MEM_FERRULE_3                                ; 0X003569 00:3569 1F C9 14; RRA
    
;*****************************************
;* 72  ?
;*****************************************
SCR_72:
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_34 $08,$10                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1A                                
SCR_0_3578:    
	scrFunc_1F $2C                                
	scrFunc_03 Addr_00359C                                
	scrFunc_IF_NZ SCR_0_358B                                
	scrFunc_1F $2D                                
	scrFunc_03 Addr_00359C                                
	scrFunc_IF_NZ SCR_0_358B                              
	scrFunc_GotoSrc SCR_0_3578                                
SCR_0_358B:	
	scrFunc_1F $2E                                
	scrFunc_01                                
	scrFunc_1F $2F                                
	scrFunc_03 Addr_0035A3                                
SCR_0_3593:	
	scrFunc_1F $2E                                
	scrFunc_01                                
	scrFunc_1F $2F                                
	scrFunc_01                                
	scrFunc_GotoSrc SCR_0_3593                                
        
;*****************************************
;* 
;*****************************************
Addr_00359C:
	ld A,[$C9EF] ;01:C9EF                 
	and A                                 
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 
;*****************************************
Addr_0035A3:
	ld A,$E0                              
	ldh [$FF95],A                     
	ld A,$60                              
	ldh [$FF94],A                     
	ld A,$05                              
	call F_Addr_001F5C ;01:1F5C             
	ld B, $04                             
	ld DE,SCR_0_2178                           
	call F_Addr_00149B ;01:149B             
	ldh A,[$FF94]                     
	add A,$10                             
	ldh [$FF94],A                     
	ld A,$05                              
	call F_Addr_001F5C ;01:1F5C             
	ld B, $04                             
	ld DE,SCR_0_2178                           
	call F_Addr_00149B ;01:149B             
	ldh A,[$FF95]                     
	add A,$10                             
	ldh [$FF95],A                     
	ldh A,[$FF94]                     
	sub $10                               
	ldh [$FF94],A                     
	ld A,$05                              
	call F_Addr_001F5C ;01:1F5C             
	ld B, $04                             
	ld DE,SCR_0_2178                           
	call F_Addr_00149B ;01:149B             
	ldh A,[$FF94]                     
	add A,$10                             
	ldh [$FF94],A                     
	ld A,$05                              
	call F_Addr_001F5C ;01:1F5C             
	ld B, $04                             
	ld DE,SCR_0_2178                           
	jp F_Addr_00149B ;01:149B               
    
        
;*****************************************
;* 
;*****************************************
Addr_00362F:
	ld A,[$C919] ;01:C919                 
	and A                                 
	jp F_Addr_0014A9 ;01:14A9               
    
    
;*****************************************
;* 
;*****************************************
Addr_00370B:
	ld HL,$FFD2                           
	bit 7, [HL]                           
	jp NZ,Addr_002157 ;01:2157            
	call F_Addr_002172 ;01:2172             
	ld HL,$FFD2                           
	ld A,[HL]                             
	cp $40                                
	ret NC                                
	inc [HL]                              
	inc [HL]                              
	ret                                   
    
;*****************************************
;*   
;*****************************************
Addr_003720:
	ld A,$10                              
	ld [$C92F],A ;01:C92F                 
	xor A                                 
	ld [$C92D],A ;01:C92D                 
	ld [$C92E],A ;01:C92E                 
	ld [$C930],A ;01:C930                 
Addr_00372F:
	ld DE,$C92C                           
	ld HL,$C930                           
	call F_Addr_000697 ;01:0697             
	jp F_Addr_000DC0 ;01:0DC0               
    
;*****************************************
;* 
;*****************************************
SCR_0_373B:
	scrFunc_13 SCR_0_3743                                
	scrFunc_1F $1A                                
	scrFunc_GotoSrc SCR_0_36D8                                
SCR_0_3743:	
	scrFunc_PlaySnd $26                                
	scrFunc_Call Addr_003749                                
	scrFunc_00                                
    
;*****************************************
;*  n  
;*****************************************
Addr_003749:
	ld A,$01                              
	ld [$C92E],A ;01:C92E                 
	xor A                                 
	ld [$C92D],A ;01:C92D                 
	ld [$C92F],A ;01:C92F                 
	ld [$C930],A ;01:C930                 
	jr Addr_00372F                        
    
;*****************************************
;* 
;*****************************************
SCR_0_375A:
	scrFunc_13 SCR_0_3762                                
	scrFunc_1F $1B                                
	scrFunc_GotoSrc SCR_0_36D8                                
SCR_0_3762:	
	scrFunc_PlaySnd $26                                
	scrFunc_Call Addr_003768                                
	scrFunc_00                                
    
;*****************************************
;*  n  
;*****************************************
Addr_003768:
	ld A,$05                              
	ld [$C92E],A ;01:C92E                 
	xor A                                 
	ld [$C92D],A ;01:C92D                 
	ld [$C92F],A ;01:C92F                 
	ld [$C930],A ;01:C930                 
	jr Addr_00372F                        
    
;*****************************************
;* 
;*****************************************
SCR_0_3779:
	scrFunc_Call Addr_003790                                
	scrFunc_IF_NZ SCR_0_3782                                
	scrFunc_GotoSrc SCR_0_373B                              
SCR_0_3782:	
	scrFunc_13 SCR_0_378A                                
	scrFunc_1F $1D                                
	scrFunc_GotoSrc SCR_0_36D8                                
SCR_0_378A:	
	scrFunc_PlaySnd $26                                
	scrFunc_Call Addr_003798   ;Addr_003798                 
	scrFunc_00                                
    
;*****************************************
;* 
;*****************************************
Addr_003790:
	ld A,[$C913] ;01:C913                 
	cp $02                                
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 
;*****************************************
Addr_003798:
	ld A,[$C910] ;01:C910                 
	ld HL,MEM_LIFE                           
	cp [HL]                               
	ret Z                                 
	inc [HL]                              
	ld A,[$C910] ;01:C910                 
	cp [HL]                               
	jp Z,F_Addr_0011E3 ;01:11E3             
	inc [HL]                              
	jp F_Addr_0011E3 ;01:11E3               
    
;*****************************************
;* 
;*****************************************
SCR_0_37AC:
	scrFunc_13 SCR_0_37B6                                
	scrFunc_1E $01                                
	scrFunc_1F $37                                
	scrFunc_GotoSrc SCR_0_36D8                                
SCR_0_37B6:	
	scrFunc_PlaySnd $26                                
	scrFunc_Call Addr_0037BC  ;Addr_0037BC                  
	scrFunc_00                                
    
;*****************************************
;* 
;*****************************************
Addr_0037BC:
	ld HL,MEM_GLOBAL_LIFE                           
	ld A,[HL]                             
	cp $0A                                
	ret NC                                
	inc [HL]                              
	jp F_Addr_00128D ;01:128D               
    
    
;*****************************************
;* 
;*****************************************
Addr_00389E:
	ld HL,$C9ED                           
	set 0, [HL]                           
	ret                                   
    
    
;*****************************************
;* 
;*****************************************
Addr_003979:
	ld A,[$C9F2] ;01:C9F2                 
	and A                                 
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 
;*****************************************
SCR_0_3980:
	scrFunc_13 SCR_0_39A2                                
	scrFunc_MemSet $0D,$01,$FFCA                                
	scrFunc_1E $01                                
	scrFunc_1F $14 ;    SPR_S1                                 
	scrFunc_08 SCR_0_36EE                                
SCR_0_398F:	
	scrFunc_1F $14                                
	scrFunc_Delay $08                                
	scrFunc_1F $15                              
	scrFunc_Delay $08                              
	scrFunc_1F $16                              
	scrFunc_Delay $08                              
	scrFunc_1F $17                              
	scrFunc_Delay $08                              
	scrFunc_GotoSrc SCR_0_398F                              
SCR_0_39A2:	
	scrFunc_Call Addr_002244                                
	scrFunc_Call Addr_003C25                                
	scrFunc_PlaySnd $0C                                
	scrFunc_1B                                
	scrFunc_Call Addr_00216C                                
	scrFunc_MemSet $01,$01,$C9CF                                
	scrFunc_Call Addr_0039CB                                
	scrFunc_Delay $9B                                
	scrFunc_Call Addr_003C1D                                
	scrFunc_Delay $04                                
	scrFunc_Call Addr_0039DD                                
	scrFunc_MemSet $08,$01,$C9F2                                
	scrFunc_MemSet $00,$01,$C9CF                                
	scrFunc_00                                
    
;*****************************************
;*  n  
;*****************************************
Addr_0039CB:
	ld A,$01                              
	ld [$C92D],A ;01:C92D                 
	xor A                                 
	ld [$C92E],A ;01:C92E                 
	ld [$C92F],A ;01:C92F                 
	ld [$C930],A ;01:C930
	jp Addr_00372F ;01:372F               
    
;*****************************************
;* 
;*****************************************
Addr_0039DD:
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	ld HL,Data_0_3B68                           
	rst $18                               
	ld B,A                                
	ld A,[$C923] ;01:C923                 
	or B                                  
	ld [$C923],A ;01:C923                 
	ret                                   
    
;*****************************************
;*   ???
;*****************************************
SCR_0_39ED:
	scrFunc_13 SCR_0_3A0F                                
	scrFunc_MemSet $0D,$01,$FFCA                                
	scrFunc_1E $01                                
	scrFunc_1F $1F                                
	scrFunc_08 SCR_0_36EE                                
SCR_0_39FC:	
	scrFunc_1F $1F                              
	scrFunc_Delay $08                              
	scrFunc_1F $20                              
	scrFunc_Delay $08                              
	scrFunc_1F $21                              
	scrFunc_Delay $08                              
	scrFunc_1F $22                              
	scrFunc_Delay $08                              
	scrFunc_GotoSrc SCR_0_39FC  
    
SCR_0_3A0F:	
	scrFunc_Call Addr_002244                                
	scrFunc_Call Addr_003C25                                
	scrFunc_PlaySnd $0C                                
	scrFunc_1B                                
	scrFunc_Call Addr_00216C                                
	scrFunc_MemSet $01,$01,$C9CF                                
	scrFunc_Call Addr_0039CB ;                                  
	scrFunc_Delay $9B                                
	scrFunc_Call Addr_003C1D                                
	scrFunc_Delay $04                                
	scrFunc_Call Addr_0039DD                                
	scrFunc_MemSet $0E,$01,$C9F2                                
	scrFunc_MemSet $00,$01,$C9CF                                
	scrFunc_00                                
SCR_0_3A38:	
	scrFunc_13 SCR_0_3A48                                
	scrFunc_MemSet $0D,$01,$FFCA                                
	scrFunc_1F $27                                
SCR_0_3A42:	
	scrFunc_08 SCR_0_36EE                                
	scrFunc_GotoSrc SCR_0_1F98                                
SCR_0_3A48:	
	scrFunc_Call Addr_002244                                
	scrFunc_Call Addr_003C25                                
	scrFunc_PlaySnd $0C                                
	scrFunc_1B                                
	scrFunc_Call Addr_00216C                                
	scrFunc_MemSet $01,$01,$C9CF                                
	scrFunc_Call Addr_003A6C                                
	scrFunc_Delay $9B                                
	scrFunc_Call Addr_003C1D                                
	scrFunc_Delay $04                                
	scrFunc_Call Addr_003A7D                                
	scrFunc_MemSet $00,$01,$C9CF                                
	scrFunc_00                                
    
    
    
;*****************************************
;* 
;*****************************************
Addr_003A6C:
	ld HL,$C910                           
	ld A,[HL]                             
	cp $0A                                
	ret NC                                
	inc [HL]                              
	inc [HL]                              
	ld HL,MEM_LIFE                           
	inc [HL]                              
	inc [HL]                              
	jp F_Addr_0011E3 ;01:11E3               
    
;*****************************************
;* 
;*****************************************
Addr_003A7D:
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	ld HL,Data_0_3B68                           
	rst $18                               
	ld B,A                                
	ld A,[$C924] ;01:C924                 
	or B                                  
	ld [$C924],A ;01:C924                 
	ld A,$0A                              
	ld [$C9F2],A ;01:C9F2                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
SCR_0_3A92:
	scrFunc_13 SCR_0_3A9F                                
	scrFunc_MemSet $0D,$01,$FFCA                                
	scrFunc_1F $24                                
	scrFunc_GotoSrc SCR_0_3A42                                
SCR_0_3A9F:	
	scrFunc_Call Addr_002244                                
	scrFunc_Call Addr_003C25                                
	scrFunc_PlaySnd $0C                                
	scrFunc_1B                                
	scrFunc_Call Addr_00216C                                
	scrFunc_MemSet $01,$01,$C9CF                                
	scrFunc_Delay $9B                                
	scrFunc_Call Addr_003C1D                                
	scrFunc_Delay $04                                
	scrFunc_Call Addr_003B4C                                
	scrFunc_Call Addr_003BF1                                
	scrFunc_IF_NZ SCR_0_3AC3                                
	scrFunc_GotoSrc SCR_0_3BDF                              
SCR_0_3AC3:	
	scrFunc_27 $F0,$FF  ;$FFF0 ????????????????????????????????????????/                             
	scrFunc_28 $80,$00                                
	scrFunc_01                                
    scrFunc_PlaySnd $4F                                
SCR_0_3ACC:	
	scrFunc_Call Addr_003B31                                
	scrFunc_Delay $04                                
	scrFunc_Call Addr_003B3F                                
	scrFunc_Delay $04                                
	scrFunc_0D $0C,SCR_0_3ACC                                
	scrFunc_05 $07,SCR_0_3B70                                
	scrFunc_Delay $3C                                
	scrFunc_MemSet $00,$01,$C9CF                                
	scrFunc_Delay $78                                
	scrFunc_2B $08                                
	scrFunc_2C $00                                
	scrFunc_34 $06,$10                                
	scrFunc_1E $01                                
	scrFunc_1A                                
	scrFunc_22                                
SCR_0_3AF2:	
	scrFunc_1F $03                                
	scrFunc_08 SCR_0_1F8F                                
	scrFunc_1F $04                                
	scrFunc_08 SCR_0_1F8F                                
	scrFunc_1F $03                                
	scrFunc_08 SCR_0_1F8F                                
	scrFunc_1F $05                                
	scrFunc_08 SCR_0_1F8F                                
	scrFunc_0D $03,SCR_0_3AF2                                
SCR_0_3B0A:	
	scrFunc_1F $06                                
	scrFunc_Delay $08                                
	scrFunc_PlaySnd $21                                
	scrFunc_1F $03                                
	scrFunc_Delay $08                                
	scrFunc_0D $04,SCR_0_3B0A                                
	scrFunc_MemSet $FF,$01,$C9EC                                
	scrFunc_13 SCR_0_3B26                                
	scrFunc_Call F_Addr_002172                                
	scrFunc_GotoSrc SCR_0_1F98                                
SCR_0_3B26:	
	scrFunc_MemSet $07,$01,$C9F2                                
	scrFunc_Call Addr_00216C                                
	scrFunc_GotoSrc SCR_0_1F98                                
        
;*****************************************
;* 
;*****************************************
Addr_003B31:
	ld A,[MEM_WINDOW_Y] ;01:D592                 
	sub $04                               
	ld [MEM_WINDOW_Y],A ;01:D592                 
	ld A,$FF                              
	ld [$C9DC],A ;01:C9DC                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_003B3F:
	ld A,[MEM_WINDOW_Y] ;01:D592                 
	add A,$04                             
	ld [MEM_WINDOW_Y],A ;01:D592                 
	xor A                                 
	ld [$C9DC],A ;01:C9DC                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_003B4C:
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	ld HL,Data_0_3B68                           
	rst $18                               
	ld B,A                                
	ld A,[$C921] ;01:C921                 
	or B                                  
	ld [$C921],A ;01:C921                 
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	inc A                                 
	ld [$C922],A ;01:C922                 
	ld A,$09                              
	ld [$C9F2],A ;01:C9F2                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
Data_0_3B68:
	DB $01                                ; 0X003B68 00:3B68 01 02 04; ld BC, $0402
	DB $02                                ; 0X003B69 00:3B69 02 04 08; ld [BC],A
	DB $04                                ; 0X003B6A 00:3B6A 04 08 10; inc B
	DB $08                                ; 0X003B6B 00:3B6B 08 10 20; ld [$2010],SP ;00:2010
	DB $10                                ; 0X003B6C 00:3B6C 10 20 40; STOP 0
	DB $20                                ; 0X003B6D 00:3B6D 20 40 80; jr NZ,Addr_003BAF
	DB $40                              ;*; 0X003B6E 00:3B6E 40 80 14; ld B,B
	DB $80                              ;*; 0X003B6F 00:3B6F 80 14 03; add A,B
    
;*****************************************
;* 
;*****************************************
SCR_0_3B70:    
	scrFunc_MemSet $03,$01,$FFDD                                
	scrFunc_27 $38,$00                                
	scrFunc_28 $60,$00                                
	scrFunc_34 $08,$20                                
	scrFunc_36 $00                                
	scrFunc_1E $01                                
	scrFunc_1F $01                                
	scrFunc_2C $08                                
	scrFunc_26                                
	scrFunc_1A                                
SCR_0_3B88:	
	scrFunc_17                                
	scrFunc_0D $40,SCR_0_3B88                                
SCR_0_3B8D:	
	scrFunc_Call Addr_003BA0                                
	scrFunc_03 Addr_003BAA                                
	scrFunc_IF_NZ SCR_0_3B99                                
	scrFunc_GotoSrc SCR_0_3B8D                                
SCR_0_3B99:	
	scrFunc_05 $04,SCR_0_2BE7                                
	scrFunc_GotoSrc SCR_0_2178                                
        
;*****************************************
;* 
;*****************************************
Addr_003BA0:
	ldh A,[$FFE0]                     
	and A                                 
	ret Z                                 
	ld A,$FF                              
	ld [$C9D8],A ;00:C9D8                               
	ret                             
    
;*****************************************
;* 
;*****************************************
Addr_003BAA:
	ld A,[$C9EC] ;01:C9EC                 
	and A                                 
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 
;*****************************************
SCR_0_3BB1:
	scrFunc_13 SCR_0_3BBE                                
	scrFunc_MemSet $0D,$01,$FFCA                                
	scrFunc_1F $24                                
	scrFunc_GotoSrc SCR_0_3A42                                
SCR_0_3BBE:	
	scrFunc_Call Addr_002244                                
	scrFunc_Call Addr_003C25                                
	scrFunc_PlaySnd $0C                                
	scrFunc_1B                                
	scrFunc_Call Addr_00216C                                
	scrFunc_MemSet $01,$01,$C9CF                                
	scrFunc_Delay $9B                                
	scrFunc_Call Addr_003C1D                                
	scrFunc_Delay $04                                
	scrFunc_Call Addr_003B4C                                
	scrFunc_Call Addr_003BF1                                
	scrFunc_IF_NZ SCR_0_3BEB                                
SCR_0_3BDF:	
	scrFunc_Call Addr_003BFB                                
	scrFunc_Delay $3C                                
	scrFunc_Call F_FadeOut_0010B3                                
	scrFunc_PlaySnd $00                                
	scrFunc_State $07                                
SCR_0_3BEB:	
	scrFunc_MemSet $00,$01,$C9CF                                
	scrFunc_00                                
    
;*****************************************
;* 
;*****************************************
Addr_003BF1:
	ld A,[$C921] ;01:C921                 
	and $1F                               
	cp $1F                                
	jp F_Addr_0014A9 ;01:14A9               
    
;*****************************************
;* 
;*****************************************
Addr_003BFB:
	xor A                                 
	ld [$C91C],A ;05:C91C                 
	ld [$C9CD],A ;05:C9CD                 
	ld [$C9CE],A ;05:C9CE                 
	ld [$C9C9],A ;05:C9C9                 
	ld [$C9CA],A ;05:C9CA                 
	ld [$C9CC],A ;05:C9CC                 
	ld [$C919],A ;05:C919                 
	ld [$C91A],A ;05:C91A                 
	ld B, $FF                             
	ld HL,MEM_C100                           
	call CLEARMEMSMALL ;05:096A             
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_003C1D:
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	add A,$03                             
	jp F_Addr_0002E7 ;01:02E7               
    
;*****************************************
;* 
;*****************************************
Addr_003C25:
	xor A                                 
	ld [$C9CD],A ;01:C9CD                 
	ld [$C9CE],A ;01:C9CE                 
	ld [$C9C9],A ;01:C9C9                 
	ld [$C9CA],A ;01:C9CA                 
	ld [$C9CC],A ;01:C9CC                 
	ld [$C805],A ;01:C805                 
	ld A,[$C700] ;01:C700                 
	res 7, A                              
	ld [$C700],A ;01:C700                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
SCR_0_3C41:
	scrFunc_13 SCR_0_3C49                              
	scrFunc_1F $1B                              
	scrFunc_GotoSrc SCR_0_3A42                              
SCR_0_3C49:	
	scrFunc_PlaySnd $26                              
	scrFunc_Call Addr_003C76                              
	scrFunc_Call Addr_003768                              
	scrFunc_00                              
SCR_0_3C52:	
	scrFunc_13 SCR_0_3C6D                                
	scrFunc_1F $28                                
	scrFunc_08 SCR_0_36EE                                
SCR_0_3C5A:	
	scrFunc_1F $29                              
	scrFunc_Delay $08                              
	scrFunc_1F $2A                              
	scrFunc_Delay $08                              
	scrFunc_1F $2B                              
	scrFunc_Delay $08                              
	scrFunc_1F $28                              
	scrFunc_Delay $1E                              
	scrFunc_GotoSrc SCR_0_3C5A                              
SCR_0_3C6D:	
	scrFunc_PlaySnd $26                                
	scrFunc_Call Addr_003C76                                
	scrFunc_Call Addr_0039CB                                
	scrFunc_00                                
    
;*****************************************
;* 
;*****************************************
Addr_003C76:
	ld A,[MEM_CURRENT_LEVEL] ;01:C900                 
	ld HL,Data_0_3B68                           
	rst $18                               
	ld B,A                                
	ld A,[$C920] ;01:C920                 
	or B                                  
	ld [$C920],A ;01:C920                 
	ld A,$03                              
	ld [$C91C],A ;01:C91C                 
	ret                                   
    
;*****************************************
;* 
;*****************************************
SCR_0_3C8B:
	scrFunc_13 SCR_0_3CA6                                
	scrFunc_1F $2C                                
	scrFunc_08 SCR_0_36EE                                
SCR_0_3C93:	
	scrFunc_1F $2D                                
	scrFunc_Delay $08                                
	scrFunc_1F $2E                                
	scrFunc_Delay $08                                
	scrFunc_1F $2F                                
	scrFunc_Delay $08                                
	scrFunc_1F $2C                              
	scrFunc_Delay $1E                              
	scrFunc_GotoSrc SCR_0_3C93                              
SCR_0_3CA6:	
	scrFunc_PlaySnd $26                                
	scrFunc_Call Addr_003C76                                
	scrFunc_Call Addr_0039CB                                
	scrFunc_00                                
    
;*****************************************
;* 
;*****************************************
SCR_0_3CAF:	
	scrFunc_13 SCR_0_3CCA                                
	scrFunc_1F $30                                
	scrFunc_08 SCR_0_36EE                                
SCR_0_3CB7:	
	scrFunc_1F $31                              
	scrFunc_Delay $08                              
	scrFunc_1F $32                              
	scrFunc_Delay $08                              
	scrFunc_1F $33                              
	scrFunc_Delay $08                              
	scrFunc_1F $30                              
	scrFunc_Delay $1E                              
	scrFunc_GotoSrc SCR_0_3CB7                              
SCR_0_3CCA:	
	scrFunc_PlaySnd $26                                
	scrFunc_Call Addr_003C76                                
	scrFunc_Call Addr_0039CB                                
	scrFunc_00                                
    
;*****************************************
;* 
;*****************************************
SCR_0_3CD3:	
	scrFunc_13 SCR_0_3CEE                                
	scrFunc_1F $36                                
	scrFunc_08 SCR_0_36EE                                
SCR_0_3CDB:	
	scrFunc_1F $37                              
	scrFunc_Delay $08                              
	scrFunc_1F $38                              
	scrFunc_Delay $08                              
	scrFunc_1F $39                              
	scrFunc_Delay $08                              
	scrFunc_1F $36                              
	scrFunc_Delay $1E                              
	scrFunc_GotoSrc SCR_0_3CDB                              
SCR_0_3CEE:	
	scrFunc_PlaySnd $26                                
	scrFunc_Call Addr_003C76                                
	scrFunc_Call Addr_0039CB                                
	scrFunc_00                                
    
;*****************************************
;* 
;*****************************************
SCR_0_3CF7:	
	scrFunc_13 SCR_0_3D0A                                
	scrFunc_1F $34                                
	scrFunc_08 SCR_0_36EE                                
SCR_0_3CFF:	
	scrFunc_1F $35                                
	scrFunc_Delay $08                                
	scrFunc_1F $34                              
	scrFunc_Delay $08                              
	scrFunc_GotoSrc SCR_0_3CFF                              
SCR_0_3D0A:	
	scrFunc_PlaySnd $26                                
	scrFunc_Call Addr_003C76                                
	scrFunc_Call Addr_0039CB                                
	scrFunc_00                                
    
;*****************************************
;* 
;*****************************************
SCR_0_3D13:	
	scrFunc_13 SCR_0_3D33                                
	scrFunc_1F $3A                                
	scrFunc_MemSet $1B,$01,$FF49                                
	scrFunc_08 SCR_0_36EE                                
SCR_0_3D20:	
	scrFunc_1F $3B                                
	scrFunc_Delay $08                                
	scrFunc_1F $3C                              
	scrFunc_Delay $08                              
	scrFunc_1F $3D                              
	scrFunc_Delay $08                              
	scrFunc_1F $3A                              
	scrFunc_Delay $1E                              
	scrFunc_GotoSrc SCR_0_3D20                              
SCR_0_3D33:	
	scrFunc_PlaySnd $26                                
	scrFunc_MemSet $00,$01,$C917                                
	scrFunc_Call Addr_003C76                                
	scrFunc_Call Addr_0039CB                                
	scrFunc_00                                
    
;*****************************************
;* SETUP BOSS TILE
;*****************************************
SetupBossTile:
	ld A,BANK_14                              
	call SWITHBANK1 ;01:108F             
	ld HL,Data_7_7BE8;Data_7_4026                           
	ld A,[MEM_CURRENT_LEVEL] ;07:C900                 
	rst $20                               
	ld L,E                                
	ld H,D                                
	call SetupTile ;07:05ED

	ld HL,Data_BossPallete;Data_7_4026                           
	ld A,[MEM_CURRENT_LEVEL] ;07:C900                 
	rst $20                               
	ld L,E                                
	ld H,D                                
	call SetupPalDat ;07:05ED

	jp F_Addr_00109B ;07:109B               
    
;*****************************************
;* 
;*****************************************
SCR_0_3D58:
	scrFunc_PlaySnd $29                                
SCR_0_3D5A:     
	scrFunc_2C $D8                                
	scrFunc_Call Addr_003D66                                
SCR_0_3D5F:	
	scrFunc_17                                
	scrFunc_Call Addr_002149                                
	scrFunc_GotoSrc SCR_0_3D5F                                
        
;*****************************************
;* 
;*****************************************
Addr_003D66:
	ld HL,$FFDD                           
	set 2, [HL]                           
	ldh A,[$FFD1]                     
	and $20                               
	ld A,$F8                              
	jr NZ,Addr_003D75                     
	ld A,$08                              
Addr_003D75:
	ldh [$FFD3],A                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_003D78:
	ldh A,[$FFCD]                     
	ld D,A                                
	add A,$28                             
	ld B,A                                
	ldh A,[$FFCD]                     
	sub $28                               
	jr Addr_003D9A                        
    
;*****************************************
;* 
;*****************************************
Addr_003D84:
	ldh A,[$FFCD]                     
	ld D,A                                
	add A,$32                             
	ld B,A                                
	ldh A,[$FFCD]                     
	sub $32                               
	jr Addr_003D9A                        
    
;*****************************************
;* 
;*****************************************
Addr_003D90:
	ldh A,[$FFCD]                     
	ld D,A                                
	add A,$46                             
	ld B,A                                
	ldh A,[$FFCD]                     
	sub $46                               
    
Addr_003D9A:
	ld C,A                                
	ld A,[$C703] ;01:C703                 
	cp D                                  
	jr NC,Addr_003DA5                     
	cp C                                  
	jp F_Addr_0014A9 ;01:14A9               
    
Addr_003DA5:
	cp B                                  
	jp C,Addr_001FAD ;01:1FAD             
	jp Addr_001FA9 ;01:1FA9               
    
;*****************************************
;* 
;*****************************************
Addr_003DAC:
	ld HL,$FFD1                           
	ldh A,[$FFCD]                     
	cp $D0                                
	jr NC,Addr_003DBF                     
	ld B,A                                
	ld A,[$C703] ;01:C703                 
	cp B                                  
	jr NC,Addr_003DBF                     
	res 5, [HL]                           
	ret                                   
Addr_003DBF:
	set 5, [HL]                           
	ret                                   
    
;*****************************************
;* 
;*****************************************
Addr_003DC2:
	ldh A,[$FFD1]                     
	bit 5, A                              
	jr NZ,Addr_003DD2                     
	ldh A,[$FFD3]                     
	bit 7, A                              
	ret NZ                                
Addr_003DCD:
	cpl                                   
	inc A                                 
	ldh [$FFD3],A                     
	ret                                   
Addr_003DD2:
	ldh A,[$FFD3]                     
	bit 7, A                              
	jr NZ,Addr_003DCD                     
	ret                                   
    
    
    
       


;*****************************************
;* 
;*****************************************
F_Addr_0018CA:
	ld A,BANK_14                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;01:2000  
    
	ld HL,Data_5_519E                           
	ld A,[MEM_CURRENT_LEVEL] ;05:C900                 
	rst $20                               
	ld L,E                                
	ld H,D                                
	ld A,[HL+]                            
	ld [$CA0B],A ;WIDTH                
	ld A,[HL+]                            
	ld [$CA0C],A ;  ;HEIGHT                
	ld A,[HL+]   ;BLOCS SETS                         
	push AF   
  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;  
	ld DE,MEM_C200         ;       DB00                   
Addr_0018EA:            ;
	ld A,[HL+]          ;                       
	cp $FF              ; $FF                   
	jr Z,Addr_0018F3    ;                  
	ld [DE],A           ;                  
	inc DE              ;                  
	jr Addr_0018EA      ;  
   ;;;;;;;;;;;;;;;;;;;;;;;; 
Addr_0018F3:
	ld DE,MEM_C280         ;       DB80                 
Addr_0018F6:            ;
	ld A,[HL+]          ;                  
	cp $FF              ; $FF                     
	jr Z,Addr_0018FF    ;                  
	ld [DE],A           ;                  
	inc DE              ;                  
	jr Addr_0018F6      ;                  
Addr_0018FF:
    ld A,BANK_16                              
    ldh [MEM_CURRENT_BANK],A                     
    ld [$2000],A ;01:2000                 
	
    ld HL,BLOCKS_COLOR;Data_5_55C0                           
	pop AF              ; BLOCS SETS                  
	rst $20             ; 
   ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;; 
	ld HL,MEM_D000         ;      D700-DAFF MEM_D000_C
    ld BC,$400*2          ; 
Addr_00190A:            ;  
	ld A,[DE]           ;                  
	inc DE              ;                  
	ld [HL+],A          ; 
    dec BC              ;
	ld A,B              ;
	or C                ;
	jr NZ,Addr_00190A   ;                  
	ret                 ;                  


;*****************************************
;* 
;*****************************************
F_Addr_001B9C:
	push HL                               
	ldh A,[$FF94]                     
	SRL A                                 
	SRL A                                 
	SRL A                                 
	SRL A                                 
	ld B,A                                
	ldh A,[$FF95]                     
	and $F0                               
	add A,B                               
	ld HL,MEM_C300                           
	add A,L                               
	ld [$CA3D],A ;01:CA3D                 
	ld A,H                                
	adc A,$00                             
	ld [$CA3E],A ;01:CA3E                 
	pop HL                                
	ret                                   


;*****************************************
;* 
;*****************************************
F_Addr_001E49:
	ld A,C                                
	cp $E0                                
	jr NC,.L_001E77                     
	cp $90                                
	jr NC,.L_001E7D                     
	cp $10                                
	jr C,.L_001E7D                      
	sub $10                               
	ld C,A                                
	ld A,[LVLPOS_XL] ;03:C0AB                 
	ld H,A                                
	ld A,[LVLPOS_YL] ;03:C0A9                 
	ld L,A                                
	ld A,B                                
	add A,H                               
	swap A                                
	and $0F                               
	ld B,A                                
	ld A,C                                
	add A,L                               
	and $F0                               
	ld HL,MEM_C400                           
	add A,L                               
	add A,B                               
	ld L,A                                
	ld A,[HL]                             
	ld [$CA41],A ;03:CA41                 
	ret                                   
    
.L_001E77:
	ld A,$A0                              
	ld [$CA41],A ;03:CA41                 
	ret                                   
    
.L_001E7D:
	ld A,$00                              
	ld [$CA41],A ;03:CA41                 
	ret                                   


;*****************************************
;* CopyBlock
;* DE < Dest
;* BC <     MEM_D000 
;* 
;*****************************************
CopyBlock:
	push HL                               
	sla C                                 
	RL B                                  
	sla C                                 
	RL B    

	ld HL,MEM_D000                           
	add HL,BC  
	add HL,BC 
    
	ld A,[HL+]                            
	ld [DE],A                             
	inc DE                                
	ld A,[HL+]                            
	ld [DE],A                             
	inc DE                                
	ld A,[HL+]                            
	ld [DE],A                             
	inc DE                                
	ld A,[HL+]                            
	ld [DE],A                             
	inc DE 
    
	ld A,[HL+]                            
	ld [DE],A                             
	inc DE                                
	ld A,[HL+]                            
	ld [DE],A                             
	inc DE                                
	ld A,[HL+]                            
	ld [DE],A                             
	inc DE                                
	ld A,[HL+]                            
	ld [DE],A                             
	inc DE 
    
	pop HL 

	ret                                   


;*****************************************
;* 
;*****************************************
F_Addr_001EDA:
	ld A,[$C9F4] ;03:C9F4                 
	ld B,A                                
	ld A,[LVLPOS_YL] ;03:C0A9                 
	add A,B                               
	sub $10                               
	and $F0                               
	ldh [$FF95],A                     
	ld A,[$C9F3] ;03:C9F3                 
	ld B,A                                
	ld A,[LVLPOS_XL] ;03:C0AB                 
	add A,B                               
	and $F0                               
	ldh [$FF94],A                     
	call F_Addr_0003EC ;03:03EC             
	call F_Addr_001B9C ;03:1B9C             
	ld A,[$CA3D] ;03:CA3D                 
	ld L,A                                
	ld A,[$CA3E] ;03:CA3E                 
	ld H,A                                
	ld A,[HL]                             
	inc H                                 
	ld [HL],A                             
	ld C,A                                
	ld B, $00  

    ld DE,MEM_CB00                           
	call CopyBlock ;03:1B12   ;;;   

	ld HL,MEM_CB00 
    LD C,$02
	call DrawBlock ;03:04D6    
    
Addr_001F1C:
	ld A,[LVLPOS_YL] ;03:C0A9                 
	ld B,A                                
	ldh A,[$FF95]                     
	sub B                                 
	add A,$20                             
	ldh [$FFA8],A                     
	ld A,[LVLPOS_XL] ;03:C0AB                 
	ld B,A                                
	ldh A,[$FF94]                     
	sub B                                 
	add A,$08                             
	ldh [$FFAA],A                     
	xor A                                 
	ldh [$FFA9],A                     
	ldh [$FFAB],A                     
	ldh [$FFAD],A                     
	ldh A,[$FFD1]                     
	and $20                               
	ldh [$FFAC],A                     
	ret                                   
    
;*****************************************
;* 
;*****************************************
F_Addr_001F40:
	push AF                               
	ld A,[$C9F4] ;01:C9F4                 
	ld B,A                                
	ld A,[LVLPOS_YL] ;01:C0A9                 
	add A,B                               
	sub $10                               
	and $F0                               
	ldh [$FF95],A                     
	ld A,[$C9F3] ;01:C9F3                 
	ld B,A                                
	ld A,[LVLPOS_XL] ;01:C0AB                 
	add A,B                               
	and $F0                               
	ldh [$FF94],A                     
	pop AF                                
F_Addr_001F5C:
	push AF                               
	call F_Addr_0003EC ;01:03EC             
	call F_Addr_001B9C ;01:1B9C             
	ld A,[$CA3D] ;01:CA3D                 
	ld L,A                                
	ld A,[$CA3E] ;01:CA3E                 
	ld H,A                                
	inc H                                 
	pop AF                                
	ld [HL],A                             
	ld C,A                                
	ld B, $00                             
	ld A,$02                              

    ld DE,MEM_CB00                           
	call CopyBlock ;01:1B12 ;;;  .    


	ld HL,MEM_CB00 
    LD C,$02
	call DrawBlock ;01:04D6             
	jr Addr_001F1C                        

;************************************************
;*
;************************************************
F_Addr_0003EC:
	push DE                               ; 
	push HL                               ; 
	ld H,$00                              ; 
	ldh A,[$FF95]                         ; 
	and $F8                               ; 
	ld L,A                                ; 
	sla L                                 ; 
	RL H                                  ; 
	sla L                                 ; 
	RL H                                  ; 
	ld DE,SCRN9800                        ; 
	add HL,DE                             ; 
	ldh A,[$FF94]                         ; 
	SRL A                                 ; 
	SRL A                                 ; 
	SRL A                                 ; 
	ld E,A                                ; 
	ld D,$00                              ; 
	add HL,DE                             ; 
	ld A,H                                ; 
	ldh [$FF96],A                         ; 
	ld A,L                                ; 
	ldh [$FF97],A                         ; 
	pop HL                                ; 
	pop DE                                ; 
	ret                                   ; 

;*****************************************
;* 
;*****************************************
F_Addr_001A65:
	ld A,L                                
	ldh [$FF95],A                     
	ld A,E                                
	ldh [$FF94],A                     
	call F_Addr_001B9C ;01:1B9C             
    call F_Addr_0003EC ;01:03EC ;   .             
	call F_Addr_001B2D ;01:1B2D             
	call F_Addr_001B76 ;01:1B76             
	ld A,[$CA0D] ;02:CA0D                 
	ld C,A                                
	ld B, $00                             
	add HL,BC  
    
	ld DE,MEM_CB00 
	ld B, $08                             
.L_001A83:
        push BC                               
        push DE                               
            ld A,[$CA3D] ;02:CA3D                 
            ld E,A                                
            ld A,[$CA3E] ;02:CA3E                 
            ld D,A                                
            ld A,[HL]                             
            ld C,A                                
            ld [DE],A                             
            inc D                                 
            ld [DE],A                             
            ld A,E                                
            add A,$10                             
            ld [$CA3D],A ;02:CA3D                 
        pop DE                                
        ld B, $00                             
        call CopyBlock ;       
        ld A,L                                
        add A,$0A                             
        ld L,A                                
        jr NC,.L_001AA5                     
        inc H                                 
.L_001AA5:
        pop BC                                
	dec B                                 
	jr NZ,.L_001A83 
    
    
	call F_Addr_001C07 ;02:1C07 -  ! ;       


	; ldh A,[R_LCDC]                     
	; bit 0, A  ;  gbc   .  . ,                             
	; jr NZ,.L_001AC2   
    
	ld HL,MEM_CB00 
    LD C,$10
	call DrawBlock ;  2*10 
    
    ret
    
; .L_001AC2:
	; ld B, $10                             
	; ld DE,MEM_CB00                           
	; ld HL,$C501                           
	; ld A,[HL]                             
	; add A,$20                             
	; cp $32                                
	; jr C,.L_001ADA                      
	; xor A                                 
	; ld [$C500],A ;01:C500                 
	; ld C,$01                              
	; call F_Delay_00036C ;01:036C wait            
; .L_001ADA:
	; ld A,$01                              
	; ld [$C500],A ;01:C500                 
	; ld A,[HL+]                            
	; add A,L                               
	; ld L,A                                
	; jr NC,L_001AE5                     
	; inc H                              
; L_001AE5:
        ; ldh A,[$FF96]                     
        ; ld [HL+],A                            
        ; ldh A,[$FF97]                     
        ; ld [HL+],A                            
        ; ld A,$02                              
        ; ld [HL+],A                            
        ; ld A,[DE]                             
        ; ld [HL+],A                            
        ; inc DE                                
        ; ld A,[DE]                             
        ; ld [HL+],A                            
        ; inc DE                                
        ; ld A,[$FF97] ;                        
        ; add A,$20                             
        ; ld [$FF97],A ;                        
        ; jr NC,.L_001B02                     
        ; ld A,[$FF96] ;                        
        ; inc A                                 
        ; and $9B                               
        ; ld [$FF96],A ;                      
; .L_001B02:
	; dec B                                 
	; jr NZ,L_001AE5 
    
	; xor A                                 
	; ld [HL],A                             
	; ld A,L                                
	; dec A                                 
	; dec A                                 
	; ld [$C501],A ;              
	; xor A                                 
	; ld [$C500],A ;                 
	; ret                                   

;*****************************************
;* 
;*****************************************
F_Addr_001C9F:
	push DE                               
	ld A,[HL+]                            
	push HL                               
	cp $E0                             
	jr NC,.L_001CD8                     
	ld B, $0D                             
	cp $68                                
	jr NC,.L_001CBA                     
	ld B, $0C                             
	cp $60                                
	jr NC,.L_001CBA                     
	ld B, $0B                             
	cp $20                                
	jr NC,.L_001CBA                     
	ld B, $0A                             
.L_001CBA:
	ld HL,Data_1_5D4E                           
	rst $20                               
	ldh A,[$FFA8]                     
	add A,$10                             
	ldh [$FFA8],A                     
	ldh A,[$FFA9]                     
	adc A,$00                             
	ldh [$FFA9],A                     
	xor A                                 
	ldh [$FFAC],A                     
	ld A,[$CA46] ;01:CA46                 
	ldh [$FFAD],A                     
	call F_Addr_00149B ;01:149B             
	pop HL                                
	pop DE                                
	ret                                   
    
.L_001CD8:
	ld B,A                                
	cp $E4                                
	jr NC,.L_001CE5                     
	ld A,[$C91A] ;01:C91A                 
	and A                                 
	jr Z,L_001D32                      
	jr .L_001CF3                        
.L_001CE5:
	cp $FB                                
	jr Z,.L_001CED                      
	cp $FC                                
	jr NZ,.L_001CF3                     
.L_001CED:
	ld A,[$C9EE] ;01:C9EE                 
	and A                                 
	jr Z,L_001D32                      
.L_001CF3:
	ld A,B                                
	and $1F                               
	ld HL,Data_0_1D35                           
	rst $18                               
	push AF                               
	ldh A,[$FFA8]                     
	ld B,A                                
	ld A,[LVLPOS_YL] ;01:C0A9                 
	add A,B                               
	ldh [$FF95],A                     
	ldh A,[$FFAA]                     
	ld B,A                                
	ld A,[LVLPOS_XL] ;01:C0AB                 
	add A,B                               
	ldh [$FF94],A                     
	call F_Addr_001B9C ;01:1B9C             
	ld A,[$CA3D] ;01:CA3D                 
	ld L,A                                
	ld A,[$CA3E] ;01:CA3E                 
	ld H,A                                
	pop AF                                
	inc H                                 
	ld [HL],A                             
	ld C,A                                
	ld HL,MEM_CB00;+$80                           
	ldh A,[$FF95]                     
	and $70                               
	SRL A                                 
	SRL A                                 
	ld E,A                                
	ld D,$00                              
	add HL,DE 
    add HL,DE
	ld E,L                                
	ld D,H                                
	ld B, $00                             
	call CopyBlock ;01:1B12 ;;; 

L_001D32:
	pop HL                                
	pop DE                                
	ret                                   

;*****************************************
;* 	$9F80  [$FF96] [$FF97]                       
;* 	HL < Data_0_0E4C 
;* 	C < HEIGHT
;*****************************************
DrawBlock:
	ldh A,[$FF96]                         
	or $98                                
	ld D,A                                
	ldh A,[$FF97]                         
	ld E,A  
    
.L_D_1:    
    WaitForVRAM
    di
    ld A,$00                                
	ldh [R_VBK],A 
    ld A,[HL+]
    ld [DE],A
    ei
    WaitForVRAM
    di
    ld A,$01                                
	ldh [R_VBK],A 
    ld A,[HL+]
    ld [DE],A
    ei
    inc DE
    
    WaitForVRAM
    di
    ld A,$00                                
	ldh [R_VBK],A 
    ld A,[HL+]
    ld [DE],A
    ei
    WaitForVRAM
    di
    ld A,$01                                
	ldh [R_VBK],A 
    ld A,[HL+]
    ld [DE],A
    ei
    dec DE
    
	ld A,E                        
	add A,$20                             
	ld E,A 
	jr NC,.L_C_2                       
	ld A,D                        
	inc A                                 
	and $9F                               
	ld D,A                        
.L_C_2:
    
	dec C                                 
	jr NZ,.L_D_1                   
    
    ld A,$00                                
	ldh [R_VBK],A 
    RET


















;*****************************************
;* 
;*****************************************
	DB $EA                              ;*; 0X0008C1 00:08C1 EA 06 00; ld [$0006],A ;00:0006
	DB $06                              ;*; 0X0008C2 00:08C2 06 00 3E; ld B, $00
	DB $00                              ;*; 0X0008C3 00:08C3 00 3E 80; nop
	DB $3E                              ;*; 0X0008C4 00:08C4 3E 80 EA; ld A,$80
	DB $80                              ;*; 0X0008C5 00:08C5 80 EA 04; add A,B
	DB $EA                              ;*; 0X0008C6 00:08C6 EA 04 00; ld [$0004],A ;00:0004
	DB $04                              ;*; 0X0008C7 00:08C7 04 00 AF; inc B
	DB $00                              ;*; 0X0008C8 00:08C8 00 AF EA; nop
	DB $AF                              ;*; 0X0008C9 00:08C9 AF EA 05; xor A
	DB $EA                              ;*; 0X0008CA 00:08CA EA 05 00; ld [$0005],A ;00:0005
	DB $05                              ;*; 0X0008CB 00:08CB 05 00 3E; dec B
	DB $00                              ;*; 0X0008CC 00:08CC 00 3E 03; nop
	DB $3E                              ;*; 0X0008CD 00:08CD 3E 03 EA; ld A,$03
	DB $03                              ;*; 0X0008CE 00:08CE 03 EA 07; inc BC
	DB $EA                              ;*; 0X0008CF 00:08CF EA 07 00; ld [$0007],A ;00:0007
	DB $07                              ;*; 0X0008D0 00:08D0 07 00 3E; RLCA
	DB $00                              ;*; 0X0008D1 00:08D1 00 3E 07; nop
	DB $3E                              ;*; 0X0008D2 00:08D2 3E 07 EA; ld A,$07
	DB $07                              ;*; 0X0008D3 00:08D3 07 EA 07; RLCA
	DB $EA                              ;*; 0X0008D4 00:08D4 EA 07 00; ld [$0007],A ;00:0007
	DB $07                              ;*; 0X0008D5 00:08D5 07 00 F0; RLCA
	DB $00                              ;*; 0X0008D6 00:08D6 00 F0 FF; nop
	DB $F0                              ;*; 0X0008D7 00:08D7 F0 FF F6; ldh A,[R_IE]
	DB $FF                              ;*; 0X0008D8 00:08D8 FF F6 04; rst $38
	DB $F6                              ;*; 0X0008D9 00:08D9 F6 04 E0; or $04
	DB $04                              ;*; 0X0008DA 00:08DA 04 E0 FF; inc B
	DB $E0                              ;*; 0X0008DB 00:08DB E0 FF C9; ldh [R_IE],A
	DB $FF                              ;*; 0X0008DC 00:08DC FF C9 F0; rst $38
	DB $C9                              ;*; 0X0008DD 00:08DD C9 F0 F1; ret
    
D_0008DE:    
	DB $F0                              ;*; 0X0008DE 00:08DE F0 F1 F2; ldh A,[$FFF1]
	DB $F1                              ;*; 0X0008DF 00:08DF F1 F2 F3; pop AF
	DB $F2                                ; 0X0008E0 00:08E0 F2 F3 F4; ld A,[$FF00+C]
	DB $F3                                ; 0X0008E1 00:08E1 F3 F4 F5; di
	DB $F4                                ; 0X0008E2 00:08E2 F4 F5 F6;
	DB $F5                                ; 0X0008E3 00:08E3 F5 F6 F7; push AF
	DB $F6                                ; 0X0008E4 00:08E4 F6 F7 F8; or $F7
	DB $F7                              ;*; 0X0008E5 00:08E5 F7 F8 F9; rst $30
	DB $F8                              ;*; 0X0008E6 00:08E6 F8 F9 01; ld HL,SP+$-7
	DB $F9                              ;*; 0X0008E7 00:08E7 F9 01 02; ld SP,HL
	DB $01                              ;*; 0X0008E8 00:08E8 01 02 03; ld BC, $0302
	DB $02                              ;*; 0X0008E9 00:08E9 02 03 04; ld [BC],A
	DB $03                              ;*; 0X0008EA 00:08EA 03 04 05; inc BC
	DB $04                              ;*; 0X0008EB 00:08EB 04 05 06; inc B
	DB $05                              ;*; 0X0008EC 00:08EC 05 06 31; dec B
	DB $06                              ;*; 0X0008ED 00:08ED 06 31 FF; ld B, $31


Addr_7A_T1:
    push AF
    push BC
    push DE
    push HL 
    
	ld A,$00                              
        ld [LVLPOS_XL],A ;04:C0AB                 
	ld A,$00                              
        ld [LVLPOS_XH],A ;04:C0AC                 
	ld A,$00                              
        ld [LVLPOS_YL],A ;04:C0A9                 
	ld A,$02                              
        ld [LVLPOS_YH],A ;04:C0AA  

	ld A,$50                              
        ld [$C703],A ;X                 
	ld A,$80                              
        ld [$C701],A ;Y                

    call L_000F24;F_Addr_000F8F
    
	ld A,BANK_01                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;01:2000  
    
    pop HL
    pop DE
    pop BC
    pop AF
	RET              

Addr_7A_T2:
    push AF
    push BC
    push DE
    push HL 
    
	ld A,$80                              
        ld [LVLPOS_XL],A ;04:C0AB                 
	ld A,$07                              
        ld [LVLPOS_XH],A ;04:C0AC                 
	ld A,$80                              
        ld [LVLPOS_YL],A ;04:C0A9                 
	ld A,$02                             
        ld [LVLPOS_YH],A ;04:C0AA  

	ld A,$81                              
        ld [$C703],A ;X                 
	ld A,$80                              
        ld [$C701],A ;Y                

    call L_000F24;F_Addr_000F8F
    
	ld A,BANK_01                              
	ldh [MEM_CURRENT_BANK],A                     
	ld [$2000],A ;01:2000  
    
    pop HL
    pop DE
    pop BC
    pop AF
	RET              


;$80 LVLPOS_XL               
;$07 LVLPOS_XH                
;$80 LVLPOS_YL                
;$02 LVLPOS_YH 
;$81 X                 
;$80 Y                




